@@ -17,16 +17,15 @@ modules:
 
 isort:skip_file
 """
-
-
-from functools import partial
 from toolz import compose
-from phidl import quickplot as plot
-from phidl.device_layout import Group, Path
+from functools import partial
+from phidl.device_layout import Group
+from gdsfactory.path import Path
+
 
 # NOTE: import order matters. Only change the order if you know what you are doing
 from gdsfactory.component import Component, ComponentReference
-from gdsfactory.config import CONFIG, call_if_func
+from gdsfactory.config import CONFIG, CONF, call_if_func
 from gdsfactory.port import Port
 from gdsfactory.cell import cell
 from gdsfactory.cell import cell_without_validator
@@ -34,15 +33,13 @@ from gdsfactory.cell import clear_cache
 from gdsfactory.tech import LAYER
 from gdsfactory.show import show
 from gdsfactory.read.import_gds import import_gds
-from gdsfactory.cross_section import CrossSection
+from gdsfactory.cross_section import CrossSection, Section
 from gdsfactory.types import Label
 
 from gdsfactory import cross_section
 from gdsfactory import asserts
 from gdsfactory import components
 from gdsfactory import routing
-from gdsfactory import klive
-from gdsfactory import port
 from gdsfactory import types
 from gdsfactory import path
 from gdsfactory import snap
@@ -55,9 +52,9 @@ from gdsfactory import functions
 from gdsfactory import export
 from gdsfactory import geometry
 from gdsfactory import mask
-from gdsfactory import sweep
 from gdsfactory import add_ports
 from gdsfactory import write_cells
+from gdsfactory import add_pins
 
 from gdsfactory.tech import TECH
 from gdsfactory.add_tapers import add_tapers
@@ -66,19 +63,30 @@ from gdsfactory.add_padding import (
     add_padding_container,
     get_padding_points,
 )
-from gdsfactory.add_pins import add_pins, add_pins_to_references
 from gdsfactory.fill import fill_rectangle
 from gdsfactory.pack import pack
 from gdsfactory.grid import grid, grid_with_text
+from gdsfactory.pdk import (
+    Pdk,
+    get_component,
+    get_cross_section,
+    get_layer,
+    get_active_pdk,
+    get_cell,
+)
+from gdsfactory.get_factories import get_cells
+from gdsfactory.cross_section import get_cross_section_factories
 
 
 c = components
 
-__all__ = [
+__all__ = (
     "CONFIG",
+    "CONF",
     "Component",
     "ComponentReference",
     "CrossSection",
+    "Section",
     "compose",
     "Group",
     "LAYER",
@@ -89,7 +97,6 @@ __all__ = [
     "add_padding",
     "add_padding_container",
     "add_pins",
-    "add_pins_to_references",
     "add_ports",
     "add_tapers",
     "add_termination",
@@ -109,26 +116,26 @@ __all__ = [
     "grid",
     "grid_with_text",
     "import_gds",
-    "klive",
     "layers",
     "mask",
     "pack",
     "path",
     "partial",
-    "plot",
-    "port",
     "read",
     "routing",
     "show",
     "snap",
     "tech",
     "types",
-    "sweep",
     "write_cells",
     "Label",
-]
-__version__ = "3.9.8"
-
-
-if __name__ == "__main__":
-    print(__all__)
+    "Pdk",
+    "get_active_pdk",
+    "get_component",
+    "get_cross_section",
+    "get_cell",
+    "get_cells",
+    "get_layer",
+    "get_cross_section_factories",
+)
+__version__ = "5.15.2"
