@@ -3,6 +3,7 @@ from typing import Callable, List, Optional, Tuple
 
 import numpy as np
 
+import gdsfactory as gf
 from gdsfactory.add_labels import get_input_label_text_loopback
 from gdsfactory.cell import cell
 from gdsfactory.component import Component
@@ -17,38 +18,42 @@ from gdsfactory.routing.utils import (
     check_ports_have_equal_spacing,
     direction_ports_from_list_ports,
 )
-from gdsfactory.types import ComponentFactory, CrossSectionFactory, Label
+from gdsfactory.types import ComponentSpec, CrossSectionSpec, Label, PortsDict
 
 
 @cell
 def add_grating_couplers(
-    component: Component,
-    grating_coupler: ComponentFactory = grating_coupler_te,
+    component: ComponentSpec = straight_function,
+    grating_coupler: ComponentSpec = grating_coupler_te,
     layer_label: Tuple[int, int] = (200, 0),
     gc_port_name: str = "o1",
     get_input_labels_function: Callable[..., List[Label]] = get_input_labels,
-    select_ports: Callable = select_ports_optical,
+    select_ports: Callable[..., PortsDict] = select_ports_optical,
     component_name: Optional[str] = None,
 ) -> Component:
     """Returns new component with grating couplers and labels.
 
     Args:
-        component: to add grating_couplers
-        grating_coupler: grating_coupler function
-        layer_label: for label
-        gc_port_name: where to add label
-        get_input_labels_function: function to get label
-        select_ports: for selecting optical_ports
+        component: to add grating_couplers.
+        grating_coupler: grating_coupler spec.
+        layer_label: for label.
+        gc_port_name: where to add label.
+        get_input_labels_function: function to get label.
+        select_ports: for selecting optical_ports.
+        component_name: optional component name.
 
     """
 
     c = Component()
+    component = gf.get_component(component)
+
     c.component = component
-    component_name = component_name or component.info_child.name
+    component_name = component_name or component.metadata_child.get("name")
     c.add_ref(component)
-    grating_coupler = (
-        grating_coupler() if callable(grating_coupler) else grating_coupler
-    )
+    grating_coupler = gf.get_component(grating_coupler)
+
+    c.info["polarization"] = grating_coupler.info["polarization"]
+    c.info["wavelength"] = grating_coupler.info["wavelength"]
 
     io_gratings = []
     optical_ports = select_ports(component.ports)
@@ -74,43 +79,48 @@ def add_grating_couplers(
 
 @cell
 def add_grating_couplers_with_loopback_fiber_single(
-    component: Component,
-    grating_coupler: ComponentFactory = grating_coupler_te,
-    layer_label: Tuple[int, int] = (200, 0),
+    component: ComponentSpec = straight_function,
+    grating_coupler: ComponentSpec = grating_coupler_te,
+    layer_label: Optional[Tuple[int, int]] = (200, 0),
     gc_port_name: str = "o1",
     get_input_labels_function: Callable[..., List[Label]] = get_input_labels,
     get_input_label_text_loopback_function: Callable = get_input_label_text_loopback,
-    select_ports: Callable = select_ports_optical,
+    select_ports: Callable[..., PortsDict] = select_ports_optical,
     with_loopback: bool = True,
-    cross_section: CrossSectionFactory = strip,
+    cross_section: CrossSectionSpec = strip,
     component_name: Optional[str] = None,
-    fiber_spacing: float = 50.0,
     loopback_xspacing: float = 5.0,
-    straight: ComponentFactory = straight_function,
+    straight: ComponentSpec = straight_function,
     rotation: int = 90,
 ) -> Component:
-    """
-    Returns component with all ports terminated with grating couplers
+    """Returns new component with all ports terminated with grating couplers.
 
     Args:
-        component:
-        grating_coupler:
-        layer_label:
-        gc_port_name:
+        component: to add grating_couplers.
+        grating_coupler: grating_coupler spec function, string or dict.
+        layer_label: optional layer_label for the ports.
+        gc_port_name: grating_coupler port name.
+        get_input_labels_function: function to get grating_coupler labels.
         get_input_label_text_loopback_function:
-        with_loopback: adds a reference loopback
-        rotation: 90 for North South devices, 0 for East-West
-
+        select_ports: function to select ports.
+        with_loopback: adds a reference loopback.
+        cross_section: for routing.
+        component_name: optional component name.
+        loopback_xspacing: in um.
+        straight: straight spec.
+        rotation: in degrees, 90 for North South devices, 0 for East-West.
     """
 
     c = Component()
+    component = gf.get_component(component)
+
     c.component = component
     c.add_ref(component)
-    grating_coupler = (
-        grating_coupler() if callable(grating_coupler) else grating_coupler
-    )
+    grating_coupler = gf.get_component(grating_coupler)
+    c.info["polarization"] = grating_coupler.info["polarization"]
+    c.info["wavelength"] = grating_coupler.info["wavelength"]
 
-    component_name = component_name or component.info_child.name
+    component_name = component_name or component.metadata_child.get("name")
 
     io_gratings = []
     optical_ports = select_ports(component.ports)
@@ -121,6 +131,7 @@ def add_grating_couplers_with_loopback_fiber_single(
         gc_ref.connect(gc_port, port)
         io_gratings.append(gc_ref)
         c.add(gc_ref)
+        c.add_port(name=port.name, port=port)
 
     labels = get_input_labels_function(
         io_gratings,
@@ -136,15 +147,19 @@ def add_grating_couplers_with_loopback_fiber_single(
 
     if with_loopback:
 
-        if rotation in [0, 180]:
+        if rotation in {0, 180}:
             length = abs(p2.x - p1.x)
-            wg = c << straight(length=length, cross_section=cross_section)
+            wg = c << gf.get_component(
+                straight, length=length, cross_section=cross_section
+            )
             wg.rotate(rotation)
             wg.xmin = p2.x
             wg.ymin = c.ymax + grating_coupler.ysize / 2 + loopback_xspacing
         else:
             length = abs(p2.y - p1.y)
-            wg = c << straight(length=length, cross_section=cross_section)
+            wg = c << gf.get_component(
+                straight, length=length, cross_section=cross_section
+            )
             wg.rotate(rotation)
             wg.ymin = p1.y
             wg.xmin = c.xmax + grating_coupler.ysize / 2 + loopback_xspacing
@@ -154,28 +169,34 @@ def add_grating_couplers_with_loopback_fiber_single(
         gci.connect(gc_port_name, wg.ports["o1"])
         gco.connect(gc_port_name, wg.ports["o2"])
 
-        port = wg.ports["o2"]
-        text = get_input_label_text_loopback_function(
-            port=port, gc=grating_coupler, gc_index=0, component_name=component_name
-        )
+        p1 = c.add_port(name="loopback1", port=wg.ports["o1"])
+        p2 = c.add_port(name="loopback2", port=wg.ports["o2"])
+        p1.port_type = "loopback"
+        p2.port_type = "loopback"
 
-        c.add_label(
-            text=text,
-            position=port.midpoint,
-            anchor="o",
-            layer=layer_label,
-        )
+        if layer_label and get_input_labels_function:
+            port = wg.ports["o2"]
+            text = get_input_label_text_loopback_function(
+                port=port, gc=grating_coupler, gc_index=0, component_name=component_name
+            )
 
-        port = wg.ports["o1"]
-        text = get_input_label_text_loopback_function(
-            port=port, gc=grating_coupler, gc_index=1, component_name=component_name
-        )
-        c.add_label(
-            text=text,
-            position=port.midpoint,
-            anchor="o",
-            layer=layer_label,
-        )
+            c.add_label(
+                text=text,
+                position=port.center,
+                anchor="o",
+                layer=layer_label,
+            )
+
+            port = wg.ports["o1"]
+            text = get_input_label_text_loopback_function(
+                port=port, gc=grating_coupler, gc_index=1, component_name=component_name
+            )
+            c.add_label(
+                text=text,
+                position=port.center,
+                anchor="o",
+                layer=layer_label,
+            )
 
     c.copy_child_info(component)
     return c
@@ -183,55 +204,62 @@ def add_grating_couplers_with_loopback_fiber_single(
 
 @cell
 def add_grating_couplers_with_loopback_fiber_array(
-    component: Component,
-    grating_coupler: ComponentFactory = grating_coupler_te,
-    excluded_ports: None = None,
+    component: ComponentSpec = straight_function,
+    grating_coupler: ComponentSpec = grating_coupler_te,
+    excluded_ports: Optional[List[str]] = None,
     grating_separation: float = 127.0,
     bend_radius_loopback: Optional[float] = None,
     gc_port_name: str = "o1",
     gc_rotation: int = -90,
     straight_separation: float = 5.0,
-    bend: ComponentFactory = bend_euler,
-    straight: ComponentFactory = straight_function,
+    bend: ComponentSpec = bend_euler,
+    straight: ComponentSpec = straight_function,
     layer_label: Tuple[int, int] = (200, 0),
     layer_label_loopback: Optional[Tuple[int, int]] = None,
     component_name: Optional[str] = None,
     with_loopback: bool = True,
     nlabels_loopback: int = 2,
     get_input_labels_function: Callable = get_input_labels,
-    cross_section: CrossSectionFactory = strip,
+    cross_section: CrossSectionSpec = strip,
     select_ports: Callable = select_ports_optical,
     **kwargs,
 ) -> Component:
     """Returns a component with grating_couplers and loopback.
 
     Args:
-        component:
-        grating_coupler:
-        excluded_ports:
-        grating_separation:
-        bend_radius_loopback:
-        gc_port_name:
-        gc_rotation:
-        straight_separation:
-        bend:
-        straight:
-        layer_label:
-        component_name:
-        with_loopback: If True, add compact loopback alignment ports
-        nlabels_loopback: number of ports to label (0: no labels, 1: first port, 2: both ports)
-        cross_section:
-        **kwargs: cross_section settings
+        component: to add grating_couplers.
+        grating_coupler: grating_coupler.
+        excluded_ports: list of ports to exclude.
+        grating_separation: in um.
+        bend_radius_loopback: um.
+        gc_port_name: optional grating coupler name.
+        gc_rotation: grating coupler rotation in degrees.
+        straight_separation: in um.
+        bend: bend spec.
+        straight: straight spec.
+        layer_label: for testing label.
+        layer_label_loopback: for testing label alignment loopback.
+        component_name: optional component name.
+        with_loopback: If True, add compact loopback alignment ports.
+        nlabels_loopback: number of ports to label
+            (0: no labels, 1: first port, 2: both ports).
+        get_input_labels_function: for getting test labels.
+        cross_section: CrossSectionSpec.
+        select_ports: function to select ports.
+        kwargs: cross_section settings.
     """
-    x = cross_section(**kwargs)
-    bend_radius_loopback = bend_radius_loopback or x.info["radius"]
+    component = gf.get_component(component)
+    x = gf.get_cross_section(cross_section, **kwargs)
+    bend_radius_loopback = bend_radius_loopback or x.radius
     excluded_ports = excluded_ports or []
-    gc = grating_coupler() if callable(grating_coupler) else grating_coupler
+    gc = gf.get_component(grating_coupler)
 
     direction = "S"
-    component_name = component_name or component.info_child.name
+    component_name = component_name or component.metadata_child.get("name")
     c = Component()
     c.component = component
+    c.info["polarization"] = gc.info["polarization"]
+    c.info["wavelength"] = gc.info["wavelength"]
 
     c.add_ref(component)
 
@@ -249,9 +277,8 @@ def add_grating_couplers_with_loopback_fiber_array(
     grating_separation_extracted = check_ports_have_equal_spacing(optical_ports)
     if grating_separation_extracted != grating_separation:
         raise ValueError(
-            "Grating separation must be {}. Got {}".format(
-                grating_separation, grating_separation_extracted
-            )
+            f"Grating separation must be {grating_separation}. "
+            f"Got {grating_separation_extracted}"
         )
 
     # Add grating references
@@ -276,16 +303,16 @@ def add_grating_couplers_with_loopback_fiber_array(
         x0 = min(xs) - grating_separation
         x1 = max(xs) + grating_separation
 
-        gca1, gca2 = [
+        gca1, gca2 = (
             gc.ref(position=(x, y0), rotation=gc_rotation, port_id=gc_port_name)
             for x in [x0, x1]
-        ]
+        )
 
         gsi = gc.size_info
         port0 = gca1.ports[gc_port_name]
         port1 = gca2.ports[gc_port_name]
-        p0 = port0.position
-        p1 = port1.position
+        p0 = port0.center
+        p1 = port1.center
         a = bend_radius_loopback + 0.5
         b = max(2 * a, grating_separation / 2)
         y_bot_align_route = -gsi.width - straight_separation
@@ -302,8 +329,8 @@ def add_grating_couplers_with_loopback_fiber_array(
                 p1,
             ]
         )
-        bend90 = bend(
-            radius=bend_radius_loopback, cross_section=cross_section, **kwargs
+        bend90 = gf.get_component(
+            bend, radius=bend_radius_loopback, cross_section=cross_section, **kwargs
         )
         loopback_route = round_corners(
             points=points,
@@ -344,8 +371,6 @@ def add_grating_couplers_with_loopback_fiber_array(
 
 
 if __name__ == "__main__":
-    import gdsfactory as gf
-
     # from gdsfactory.add_labels import get_optical_text
     # c = gf.components.grating_coupler_elliptical_te()
     # print(c.wavelength)
@@ -353,8 +378,8 @@ if __name__ == "__main__":
     # c = gf.components.straight()
     c = gf.components.mzi_phase_shifter()
     c = add_grating_couplers_with_loopback_fiber_single(component=c, rotation=0)
-    # c = gf.c.spiral_inner_io()
+    # c = gf.components.spiral_inner_io()
     # c = add_grating_couplers_with_loopback_fiber_array(component=c)
     # c = add_grating_couplers(c)
 
-    c.show()
+    c.show(show_ports=True)
