@@ -1,11 +1,12 @@
 from functools import partial
 from typing import List, Optional
 
+import gdsfactory as gf
 from gdsfactory.cell import cell
 from gdsfactory.component import Component
 from gdsfactory.components.taper import taper as taper_function
 from gdsfactory.port import Port
-from gdsfactory.types import ComponentFactory
+from gdsfactory.types import ComponentSpec
 
 terminator_function = partial(taper_function, width2=0.1)
 
@@ -14,22 +15,22 @@ terminator_function = partial(taper_function, width2=0.1)
 def add_termination(
     component: Component,
     ports: Optional[List[Port]] = None,
-    terminator: ComponentFactory = terminator_function,
+    terminator: ComponentSpec = terminator_function,
     port_name: Optional[str] = None,
     port_type: str = "optical",
     **kwargs
 ) -> Component:
-    """Returns component with all or some ports terminated
+    """Returns component with all or some ports terminated.
 
     Args:
-        component:
-        ports: optional list of ports to terminate (defaults to all)
-        terminator: factory for the terminator
-        port_name: for the terminator to connect to the component ports
-        port_type: of the ports that you want to terminate
-        **kwargs: for the ports you want to terminate (orientation, width)
+        component: to add terminator.
+        ports: optional list of ports to terminate (defaults to all).
+        terminator: factory for the terminator.
+        port_name: for the terminator to connect to the component ports.
+        port_type: of the ports that you want to terminate.
+        **kwargs: for the ports you want to terminate (orientation, width).
     """
-    terminator = terminator() if callable(terminator) else terminator
+    terminator = gf.get_component(terminator)
     port_name = port_name or terminator.get_ports_list()[0].name
 
     c = Component()
@@ -51,8 +52,6 @@ def add_termination(
 
 
 if __name__ == "__main__":
-    import gdsfactory as gf
-
     c = gf.components.straight_heater_metal(length=50)
     cc = add_termination(component=c, orientation=0)
-    cc.show()
+    cc.show(show_ports=True)
