@@ -1,5 +1,12 @@
+"""Each component factory component returns a component.
+Make sure your components get imported here so the PDK registers them.
+"""
+
+import sys
+
+from gdsfactory.components.add_fidutials import add_fidutials, add_fidutials_offsets
 from gdsfactory.components.align import add_frame, align_wafer
-from gdsfactory.components.array import array
+from gdsfactory.components.array_component import array
 from gdsfactory.components.array_with_fanout import (
     array_with_fanout,
     array_with_fanout_2d,
@@ -20,13 +27,11 @@ from gdsfactory.components.bend_s import bend_s
 from gdsfactory.components.C import C
 from gdsfactory.components.cavity import cavity
 from gdsfactory.components.cdc import cdc
+from gdsfactory.components.cdsem_all import cdsem_all
 from gdsfactory.components.circle import circle
 from gdsfactory.components.compass import compass
 from gdsfactory.components.component_lattice import component_lattice
 from gdsfactory.components.component_sequence import component_sequence
-from gdsfactory.components.contact import contact, contact_heater_m3, contact_slab_m3
-from gdsfactory.components.contact_slot import contact_slot, contact_slot_m1_m2
-from gdsfactory.components.contact_with_offset import contact_with_offset
 from gdsfactory.components.copy_layers import copy_layers
 from gdsfactory.components.coupler import coupler
 from gdsfactory.components.coupler90 import coupler90, coupler90circular
@@ -61,22 +66,26 @@ from gdsfactory.components.cutback_component import (
 from gdsfactory.components.dbr import dbr
 from gdsfactory.components.dbr_tapered import dbr_tapered
 from gdsfactory.components.delay_snake import delay_snake
-from gdsfactory.components.delay_snake2 import delay_snake2, test_delay_snake2_length
-from gdsfactory.components.delay_snake3 import delay_snake3, test_delay_snake3_length
+from gdsfactory.components.delay_snake2 import delay_snake2
+from gdsfactory.components.delay_snake3 import delay_snake3
+from gdsfactory.components.delay_snake_sbend import delay_snake_sbend
 from gdsfactory.components.dicing_lane import dicing_lane
 from gdsfactory.components.die import die
-from gdsfactory.components.die_bbox import big_square, die_bbox
+from gdsfactory.components.die_bbox import die_bbox
+from gdsfactory.components.die_bbox_frame import die_bbox_frame
 from gdsfactory.components.disk import disk
+from gdsfactory.components.edge_coupler_array import (
+    edge_coupler_array,
+    edge_coupler_array_with_loopback,
+    edge_coupler_silicon,
+)
 from gdsfactory.components.ellipse import ellipse
 from gdsfactory.components.extend_ports_list import extend_ports_list
 from gdsfactory.components.extension import extend_port, extend_ports
 from gdsfactory.components.fiber import fiber
 from gdsfactory.components.fiber_array import fiber_array
 from gdsfactory.components.grating_coupler_array import grating_coupler_array
-from gdsfactory.components.grating_coupler_circular import (
-    grating_coupler_circular,
-    grating_coupler_circular_arbitrary,
-)
+from gdsfactory.components.grating_coupler_circular import grating_coupler_circular
 from gdsfactory.components.grating_coupler_elliptical import (
     ellipse_arc,
     grating_coupler_elliptical,
@@ -129,6 +138,7 @@ from gdsfactory.components.mzi import mzi, mzi1x2_2x2, mzi2x2_2x2, mzi_coupler
 from gdsfactory.components.mzi_arm import mzi_arm
 from gdsfactory.components.mzi_arms import mzi_arms
 from gdsfactory.components.mzi_lattice import mzi_lattice
+from gdsfactory.components.mzi_pads_center import mzi_pads_center
 from gdsfactory.components.mzi_phase_shifter import (
     mzi_phase_shifter,
     mzi_phase_shifter_top_heater_metal,
@@ -136,10 +146,17 @@ from gdsfactory.components.mzi_phase_shifter import (
 from gdsfactory.components.mzit import mzit
 from gdsfactory.components.mzit_lattice import mzit_lattice
 from gdsfactory.components.nxn import nxn
-from gdsfactory.components.pad import pad, pad_array, pad_array90, pad_array270
+from gdsfactory.components.pack_doe import generate_doe, pack_doe, pack_doe_grid
+from gdsfactory.components.pad import (
+    pad,
+    pad_array,
+    pad_array0,
+    pad_array90,
+    pad_array180,
+    pad_array270,
+)
 from gdsfactory.components.pad_gsg import pad_gsg_open, pad_gsg_short
 from gdsfactory.components.pads_shorted import pads_shorted
-from gdsfactory.components.pcm_optical import pcm_optical
 from gdsfactory.components.ramp import ramp
 from gdsfactory.components.rectangle import rectangle
 from gdsfactory.components.rectangle_with_slits import rectangle_with_slits
@@ -147,23 +164,22 @@ from gdsfactory.components.resistance_meander import resistance_meander
 from gdsfactory.components.resistance_sheet import resistance_sheet
 from gdsfactory.components.ring import ring
 from gdsfactory.components.ring_double import ring_double
+from gdsfactory.components.ring_double_heater import ring_double_heater
 from gdsfactory.components.ring_single import ring_single
 from gdsfactory.components.ring_single_array import ring_single_array
 from gdsfactory.components.ring_single_dut import ring_single_dut, taper2
+from gdsfactory.components.ring_single_heater import ring_single_heater
 from gdsfactory.components.seal_ring import seal_ring
 from gdsfactory.components.spiral import spiral
 from gdsfactory.components.spiral_circular import spiral_circular
+from gdsfactory.components.spiral_double import spiral_double
 from gdsfactory.components.spiral_external_io import spiral_external_io
 from gdsfactory.components.spiral_inner_io import (
     spiral_inner_io,
     spiral_inner_io_fiber_single,
 )
 from gdsfactory.components.splitter_chain import splitter_chain
-from gdsfactory.components.splitter_tree import (
-    splitter_tree,
-    test_splitter_tree_ports,
-    test_splitter_tree_ports_no_sbend,
-)
+from gdsfactory.components.splitter_tree import splitter_tree
 from gdsfactory.components.straight import straight
 from gdsfactory.components.straight_array import straight_array
 from gdsfactory.components.straight_heater_doped_rib import straight_heater_doped_rib
@@ -176,7 +192,6 @@ from gdsfactory.components.straight_heater_metal import (
     straight_heater_metal_90_90,
     straight_heater_metal_undercut,
     straight_heater_metal_undercut_90_90,
-    test_ports,
 )
 from gdsfactory.components.straight_pin import straight_pin, straight_pn
 from gdsfactory.components.straight_pin_slot import straight_pin_slot
@@ -184,6 +199,7 @@ from gdsfactory.components.straight_rib import straight_rib, straight_rib_tapere
 from gdsfactory.components.switch_tree import switch_tree
 from gdsfactory.components.taper import (
     taper,
+    taper_sc_nc,
     taper_strip_to_ridge,
     taper_strip_to_ridge_trenches,
 )
@@ -201,204 +217,28 @@ from gdsfactory.components.taper_from_csv import (
     taper_w12_l200,
 )
 from gdsfactory.components.taper_parabolic import taper_parabolic
-from gdsfactory.components.text import githash, text
+from gdsfactory.components.text import text, text_lines
 from gdsfactory.components.text_rectangular import (
     text_rectangular,
     text_rectangular_multi_layer,
 )
-from gdsfactory.components.triangle import triangle
+from gdsfactory.components.triangles import triangle, triangle2, triangle4
 from gdsfactory.components.verniers import verniers
 from gdsfactory.components.version_stamp import pixel, qrcode, version_stamp
 from gdsfactory.components.via import via, via1, via2, viac
+from gdsfactory.components.via_corner import via_corner
 from gdsfactory.components.via_cutback import via_cutback
+from gdsfactory.components.via_stack import (
+    via_stack,
+    via_stack_heater_m3,
+    via_stack_slab_m3,
+)
+from gdsfactory.components.via_stack_slot import via_stack_slot, via_stack_slot_m1_m2
+from gdsfactory.components.via_stack_with_offset import via_stack_with_offset
 from gdsfactory.components.waveguide_template import strip
 from gdsfactory.components.wire import wire_corner, wire_straight
 from gdsfactory.components.wire_sbend import wire_sbend
-
-factory = dict(
-    C=C,
-    L=L,
-    add_frame=add_frame,
-    align_wafer=align_wafer,
-    array=array,
-    array_with_fanout=array_with_fanout,
-    array_with_fanout_2d=array_with_fanout_2d,
-    array_with_via=array_with_via,
-    array_with_via_2d=array_with_via_2d,
-    awg=awg,
-    bbox=bbox,
-    bend_circular=bend_circular,
-    bend_circular180=bend_circular180,
-    bend_circular_heater=bend_circular_heater,
-    bend_euler=bend_euler,
-    bend_euler180=bend_euler180,
-    bend_euler_s=bend_euler_s,
-    bend_straight_bend=bend_straight_bend,
-    bend_port=bend_port,
-    bend_s=bend_s,
-    cavity=cavity,
-    copy_layers=copy_layers,
-    cdc=cdc,
-    circle=circle,
-    compass=compass,
-    compensation_path=compensation_path,
-    component_lattice=component_lattice,
-    component_sequence=component_sequence,
-    coupler=coupler,
-    coupler90=coupler90,
-    coupler90bend=coupler90bend,
-    coupler90circular=coupler90circular,
-    coupler_adiabatic=coupler_adiabatic,
-    coupler_asymmetric=coupler_asymmetric,
-    coupler_full=coupler_full,
-    coupler_ring=coupler_ring,
-    coupler_straight=coupler_straight,
-    coupler_symmetric=coupler_symmetric,
-    cross=cross,
-    crossing=crossing,
-    crossing45=crossing45,
-    crossing_arm=crossing_arm,
-    crossing_etched=crossing_etched,
-    crossing_from_taper=crossing_from_taper,
-    cutback_bend=cutback_bend,
-    cutback_bend180=cutback_bend180,
-    cutback_bend180circular=cutback_bend180circular,
-    cutback_bend90=cutback_bend90,
-    cutback_bend90circular=cutback_bend90circular,
-    cutback_component=cutback_component,
-    cutback_component_mirror=cutback_component_mirror,
-    dicing_lane=dicing_lane,
-    dbr=dbr,
-    dbr_tapered=dbr_tapered,
-    delay_snake=delay_snake,
-    delay_snake2=delay_snake2,
-    delay_snake3=delay_snake3,
-    die=die,
-    die_bbox=die_bbox,
-    disk=disk,
-    ellipse=ellipse,
-    extend_port=extend_port,
-    extend_ports=extend_ports,
-    extend_ports_list=extend_ports_list,
-    fiber=fiber,
-    fiber_array=fiber_array,
-    grating_coupler_array=grating_coupler_array,
-    grating_coupler_elliptical=grating_coupler_elliptical,
-    grating_coupler_circular=grating_coupler_circular,
-    grating_coupler_circular_arbitrary=grating_coupler_circular_arbitrary,
-    grating_coupler_elliptical_te=grating_coupler_elliptical_te,
-    grating_coupler_elliptical_tm=grating_coupler_elliptical_tm,
-    grating_coupler_elliptical_arbitrary=grating_coupler_elliptical_arbitrary,
-    grating_coupler_elliptical_lumerical=grating_coupler_elliptical_lumerical,
-    grating_coupler_elliptical_trenches=grating_coupler_elliptical_trenches,
-    grating_coupler_loss_fiber_array4=grating_coupler_loss_fiber_array4,
-    grating_coupler_loss_fiber_array=grating_coupler_loss_fiber_array,
-    grating_coupler_loss_fiber_single=grating_coupler_loss_fiber_single,
-    grating_coupler_te=grating_coupler_te,
-    grating_coupler_tm=grating_coupler_tm,
-    grating_coupler_tree=grating_coupler_tree,
-    grating_coupler_rectangular=grating_coupler_rectangular,
-    grating_coupler_rectangular_arbitrary=grating_coupler_rectangular_arbitrary,
-    grating_coupler_rectangular_arbitrary_slab=grating_coupler_rectangular_arbitrary_slab,
-    hline=hline,
-    litho_calipers=litho_calipers,
-    litho_steps=litho_steps,
-    logo=logo,
-    loop_mirror=loop_mirror,
-    loss_deembedding_ch12_34=loss_deembedding_ch12_34,
-    loss_deembedding_ch13_24=loss_deembedding_ch13_24,
-    loss_deembedding_ch14_23=loss_deembedding_ch14_23,
-    mmi1x2=mmi1x2,
-    mmi2x2=mmi2x2,
-    mzi=mzi,
-    mzi2x2_2x2=mzi2x2_2x2,
-    mzi1x2_2x2=mzi1x2_2x2,
-    mzi_coupler=mzi_coupler,
-    mzi_arm=mzi_arm,
-    mzi_arms=mzi_arms,
-    mzi_lattice=mzi_lattice,
-    mzi_phase_shifter=mzi_phase_shifter,
-    mzi_phase_shifter_top_heater_metal=mzi_phase_shifter_top_heater_metal,
-    mzit=mzit,
-    mzit_lattice=mzit_lattice,
-    nxn=nxn,
-    pad=pad,
-    pad_gsg_short=pad_gsg_short,
-    pad_gsg_open=pad_gsg_open,
-    pad_array=pad_array,
-    pads_shorted=pads_shorted,
-    pcm_optical=pcm_optical,
-    pixel=pixel,
-    qrcode=qrcode,
-    ramp=ramp,
-    rectangle=rectangle,
-    rectangle_with_slits=rectangle_with_slits,
-    resistance_meander=resistance_meander,
-    resistance_sheet=resistance_sheet,
-    ring=ring,
-    ring_double=ring_double,
-    ring_single=ring_single,
-    ring_single_array=ring_single_array,
-    ring_single_dut=ring_single_dut,
-    spiral=spiral,
-    spiral_circular=spiral_circular,
-    spiral_external_io=spiral_external_io,
-    spiral_inner_io=spiral_inner_io,
-    spiral_inner_io_fiber_single=spiral_inner_io_fiber_single,
-    splitter_chain=splitter_chain,
-    splitter_tree=splitter_tree,
-    staircase=staircase,
-    straight=straight,
-    straight_array=straight_array,
-    straight_heater_doped_rib=straight_heater_doped_rib,
-    straight_heater_doped_strip=straight_heater_doped_strip,
-    straight_heater_metal=straight_heater_metal,
-    straight_heater_metal_90_90=straight_heater_metal_90_90,
-    straight_heater_metal_undercut=straight_heater_metal_undercut,
-    straight_heater_metal_undercut_90_90=straight_heater_metal_undercut_90_90,
-    straight_heater_meander=straight_heater_meander,
-    straight_pin=straight_pin,
-    straight_pn=straight_pn,
-    straight_pin_slot=straight_pin_slot,
-    straight_rib=straight_rib,
-    straight_rib_tapered=straight_rib_tapered,
-    switch_tree=switch_tree,
-    taper_cross_section_linear=taper_cross_section_linear,
-    taper_cross_section_sine=taper_cross_section_sine,
-    taper=taper,
-    taper_parabolic=taper_parabolic,
-    taper2=taper2,
-    taper_0p5_to_3_l36=taper_0p5_to_3_l36,
-    taper_from_csv=taper_from_csv,
-    taper_strip_to_ridge=taper_strip_to_ridge,
-    taper_strip_to_ridge_trenches=taper_strip_to_ridge_trenches,
-    taper_w10_l100=taper_w10_l100,
-    taper_w10_l150=taper_w10_l150,
-    taper_w10_l200=taper_w10_l200,
-    taper_w11_l200=taper_w11_l200,
-    taper_w12_l200=taper_w12_l200,
-    text=text,
-    text_rectangular=text_rectangular,
-    text_rectangular_multi_layer=text_rectangular_multi_layer,
-    triangle=triangle,
-    verniers=verniers,
-    version_stamp=version_stamp,
-    via=via,
-    viac=viac,
-    via1=via1,
-    via2=via2,
-    via_cutback=via_cutback,
-    contact=contact,
-    contact_slot=contact_slot,
-    contact_slot_m1_m2=contact_slot_m1_m2,
-    contact_heater_m3=contact_heater_m3,
-    contact_slab_m3=contact_slab_m3,
-    contact_with_offset=contact_with_offset,
-    wire_corner=wire_corner,
-    wire_sbend=wire_sbend,
-    wire_straight=wire_straight,
-    seal_ring=seal_ring,
-)
+from gdsfactory.get_factories import get_cells
 
 _factory_passives = dict(
     bend_circular=bend_circular,
@@ -431,11 +271,11 @@ _factory_passives = dict(
     mmi2x2=mmi2x2,
 )
 __all__ = [
-    "factory",
     "C",
     "L",
+    "add_fidutials",
+    "add_fidutials_offsets",
     "add_frame",
-    "align",
     "align_wafer",
     "array",
     "array_with_fanout",
@@ -452,13 +292,24 @@ __all__ = [
     "bend_euler_s",
     "bend_port",
     "bend_s",
-    "big_square",
+    "bend_straight_bend",
     "cavity",
+    "cdsem_all",
     "circle",
     "compass",
     "compensation_path",
     "component_lattice",
     "component_sequence",
+    "edge_coupler_silicon",
+    "edge_coupler_array",
+    "edge_coupler_array_with_loopback",
+    "via_stack",
+    "via_stack_heater_m3",
+    "via_stack_slab_m3",
+    "via_stack_slot",
+    "via_stack_slot_m1_m2",
+    "via_stack_with_offset",
+    "copy_layers",
     "coupler",
     "coupler90",
     "coupler90bend",
@@ -475,7 +326,6 @@ __all__ = [
     "crossing_arm",
     "crossing_etched",
     "crossing_from_taper",
-    "crossing_waveguide",
     "cutback_bend",
     "cutback_bend180",
     "cutback_bend180circular",
@@ -488,33 +338,38 @@ __all__ = [
     "delay_snake",
     "delay_snake2",
     "delay_snake3",
+    "delay_snake_sbend",
     "die",
+    "dicing_lane",
     "die_bbox",
+    "die_bbox_frame",
     "disk",
     "ellipse",
     "ellipse_arc",
     "extend_port",
     "extend_ports",
     "extend_ports_list",
-    "extension",
     "fiber",
     "fiber_array",
-    "githash",
+    "text_lines",
+    "generate_doe",
     "grating_coupler_array",
+    "grating_coupler_circular",
     "grating_coupler_elliptical",
     "grating_coupler_elliptical_arbitrary",
     "grating_coupler_elliptical_lumerical",
-    "grating_coupler_circular",
     "grating_coupler_elliptical_te",
     "grating_coupler_elliptical_tm",
     "grating_coupler_elliptical_trenches",
-    "grating_coupler_functions",
-    "grating_coupler_loss",
+    "grating_coupler_loss_fiber_array",
+    "grating_coupler_loss_fiber_array4",
+    "grating_coupler_loss_fiber_single",
+    "grating_coupler_rectangular",
+    "grating_coupler_rectangular_arbitrary",
+    "grating_coupler_rectangular_arbitrary_slab",
     "grating_coupler_te",
     "grating_coupler_tm",
     "grating_coupler_tree",
-    "grating_coupler_rectangular",
-    "grating_coupler_rectangular_arbitrary",
     "grating_taper_points",
     "grating_tooth_points",
     "hline",
@@ -526,10 +381,14 @@ __all__ = [
     "loss_deembedding_ch12_34",
     "loss_deembedding_ch13_24",
     "loss_deembedding_ch14_23",
-    "text_rectangular",
     "mmi1x2",
     "mmi2x2",
     "mzi",
+    "mzi_arms",
+    "mzi_pads_center",
+    "mzi1x2_2x2",
+    "mzi2x2_2x2",
+    "mzi_coupler",
     "mzi_arm",
     "mzi_lattice",
     "mzi_phase_shifter",
@@ -537,26 +396,39 @@ __all__ = [
     "mzit",
     "mzit_lattice",
     "nxn",
-    "pcm_optical",
+    "pack_doe_grid",
+    "pack_doe",
     "pad",
     "pad_array",
-    "pad_array90",
+    "pad_array0",
+    "pad_array180",
     "pad_array270",
+    "pad_array90",
+    "pad_gsg",
+    "pad_gsg_open",
+    "pad_gsg_short",
     "pads_shorted",
     "pixel",
     "qrcode",
     "ramp",
     "rectangle",
+    "rectangle_with_slits",
     "resistance_meander",
+    "resistance_sheet",
     "ring",
     "ring_double",
+    "ring_double_heater",
     "ring_single",
+    "ring_single_heater",
     "ring_single_array",
     "ring_single_dut",
+    "seal_ring",
     "spiral",
     "spiral_circular",
+    "spiral_double",
     "spiral_external_io",
     "spiral_inner_io",
+    "spiral_inner_io_fiber_single",
     "splitter_chain",
     "splitter_tree",
     "staircase",
@@ -568,42 +440,52 @@ __all__ = [
     "straight_heater_metal_90_90",
     "straight_heater_metal_undercut",
     "straight_heater_metal_undercut_90_90",
+    "straight_heater_meander",
     "straight_pin",
+    "straight_pin_slot",
     "straight_pn",
     "straight_rib",
+    "straight_rib_tapered",
     "strip",
+    "switch_tree",
     "taper",
     "taper2",
     "taper_0p5_to_3_l36",
     "taper_from_csv",
+    "taper_parabolic",
     "taper_strip_to_ridge",
     "taper_strip_to_ridge_trenches",
+    "taper_sc_nc",
     "taper_w10_l100",
     "taper_w10_l150",
     "taper_w10_l200",
     "taper_w11_l200",
     "taper_w12_l200",
-    "test_delay_snake2_length",
-    "test_delay_snake3_length",
-    "test_ports",
-    "test_splitter_tree_ports",
-    "test_splitter_tree_ports_no_sbend",
     "text",
+    "text_rectangular",
+    "text_rectangular_multi_layer",
     "triangle",
+    "triangle2",
+    "triangle4",
     "verniers",
     "version_stamp",
     "via",
-    "viac",
     "via1",
     "via2",
     "via_cutback",
-    "contact",
-    "contact_heater_m3",
-    "contact_slab_m3",
-    "contact_with_offset",
-    "waveguide_template",
-    "wire",
+    "viac",
+    "via_corner",
     "wire_corner",
     "wire_sbend",
     "wire_straight",
 ]
+
+cells = get_cells(sys.modules[__name__])
+
+
+if __name__ == "__main__":
+    print(len(cells.keys()))
+
+    print("cells")
+    for i in cells.keys():
+        print(i)
