@@ -4,7 +4,7 @@ import gdsfactory as gf
 from gdsfactory.cell import cell
 from gdsfactory.component import Component
 from gdsfactory.components.rectangle import rectangle
-from gdsfactory.types import Layer
+from gdsfactory.types import ComponentSpec, LayerSpec
 
 
 @cell
@@ -12,11 +12,21 @@ def align_wafer(
     width: float = 10.0,
     spacing: float = 10.0,
     cross_length: float = 80.0,
-    layer: Tuple[int, int] = (1, 0),
+    layer: LayerSpec = "WG",
     layer_cladding: Optional[Tuple[int, int]] = None,
     square_corner: str = "bottom_left",
 ) -> Component:
-    """Returns cross inside a frame to align wafer."""
+    """Returns cross inside a frame to align wafer.
+
+    Args:
+        width: in um.
+        spacing: in um.
+        cross_length: for the cross.
+        layer: for the cross.
+        layer_cladding: optional.
+        square_corner: bottom_left, bottom_right, top_right, top_left.
+    """
+    layer = gf.get_layer(layer)
     c = Component()
     cross = gf.components.cross(length=cross_length, width=width, layer=layer)
     c.add_ref(cross)
@@ -62,21 +72,22 @@ def align_wafer(
 
 @cell
 def add_frame(
-    component: Component = rectangle,
+    component: ComponentSpec = rectangle,
     width: float = 10.0,
     spacing: float = 10.0,
-    layer: Layer = (1, 0),
+    layer: LayerSpec = "WG",
 ) -> Component:
     """Returns component with a frame around it.
 
     Args:
-        component: Component to frame
-        width: of the frame
-        spacing: of component to frame
-
+        component: Component to frame.
+        width: of the frame.
+        spacing: of component to frame.
+        layer: frame layer.
     """
     c = Component()
-    component = component() if callable(component) else component
+    layer = gf.get_layer(layer)
+    component = gf.get_component(component)
     cref = c.add_ref(component)
     cref.move(-c.size_info.center)
     y = (
@@ -106,4 +117,4 @@ if __name__ == "__main__":
     # c = gf.components.straight()
     # c = add_frame(component=c)
     c = align_wafer()
-    c.show()
+    c.show(show_ports=True)
