@@ -5,21 +5,22 @@ from gdsfactory.components.straight import straight
 from gdsfactory.cross_section import strip
 from gdsfactory.path import euler, extrude
 from gdsfactory.snap import snap_to_grid
-from gdsfactory.types import CrossSectionOrFactory
+from gdsfactory.types import CrossSectionSpec
 
 
 @gf.cell
 def bend_euler(
-    angle: int = 90,
+    angle: float = 90.0,
     p: float = 0.5,
     with_arc_floorplan: bool = True,
     npoints: int = 720,
     direction: str = "ccw",
-    with_cladding_box: bool = True,
-    cross_section: CrossSectionOrFactory = strip,
+    with_bbox: bool = True,
+    cross_section: CrossSectionSpec = "strip",
     **kwargs
 ) -> Component:
     """Returns an euler bend that adiabatically transitions from straight to curved.
+
     By default, `radius` corresponds to the minimum radius of curvature of the bend.
     However, if `with_arc_floorplan` is True, `radius` corresponds to the effective
     radius of curvature (making the curve a drop-in replacement for an arc). If
@@ -30,20 +31,31 @@ def bend_euler(
     https://www.osapublishing.org/oe/fulltext.cfm?uri=oe-25-8-9150&id=362937
 
     Args:
-        angle: total angle of the curve
-        p: Proportion of the curve that is an Euler curve
+        angle: total angle of the curve.
+        p: Proportion of the curve that is an Euler curve.
         with_arc_floorplan: If False: `radius` is the minimum radius of curvature
           If True: The curve scales such that the endpoints match a bend_circular
-          with parameters `radius` and `angle`
-        npoints: Number of points used per 360 degrees
-        direction: cw (clock-wise) or ccw (counter clock-wise)
-        with_cladding_box: to avoid DRC acute angle errors in cladding
-        cross_section:
-        kwargs: cross_section settings
+          with parameters `radius` and `angle`.
+        npoints: Number of points used per 360 degrees.
+        direction: cw (clock-wise) or ccw (counter clock-wise).
+        with_bbox: add bbox_layers and bbox_offsets to avoid DRC sharp edges.
+        cross_section: specification (CrossSection, string, CrossSectionFactory dict).
+        kwargs: cross_section settings.
+
+
+    .. code::
+
+                  o2
+                  |
+                 /
+                /
+               /
+       o1_____/
+
 
     """
-    x = cross_section(**kwargs) if callable(cross_section) else cross_section
-    radius = x.info["radius"]
+    x = gf.get_cross_section(cross_section, **kwargs)
+    radius = x.radius
 
     c = Component()
     p = euler(
@@ -51,23 +63,29 @@ def bend_euler(
     )
     ref = c << extrude(p, x)
     c.add_ports(ref.ports)
-    c.info.length = snap_to_grid(p.length())
-    c.info.dy = abs(float(p.points[0][0] - p.points[-1][0]))
-    c.info.radius_min = float(snap_to_grid(p.info["Rmin"]))
-    c.info.radius = float(radius)
+    c.info["length"] = snap_to_grid(p.length())
+    c.info["dy"] = snap_to_grid(abs(float(p.points[0][0] - p.points[-1][0])))
+    c.info["radius_min"] = snap_to_grid(p.info["Rmin"])
+    c.info["radius"] = radius
+    c.info["width"] = x.width
 
-    if with_cladding_box and x.info["layers_cladding"]:
-        layers_cladding = x.info["layers_cladding"]
-        cladding_offset = x.info["cladding_offset"]
-        top = cladding_offset if angle == 180 else 0
-        points = get_padding_points(
-            component=c,
-            default=0,
-            bottom=cladding_offset,
-            right=cladding_offset,
-            top=top,
-        )
-        for layer in layers_cladding or []:
+    if x.info:
+        c.info.update(x.info)
+
+    if with_bbox:
+        padding = []
+        for offset in x.bbox_offsets:
+            top = offset if angle == 180 else 0
+            points = get_padding_points(
+                component=c,
+                default=0,
+                bottom=offset,
+                right=offset,
+                top=top,
+            )
+            padding.append(points)
+
+        for layer, points in zip(x.bbox_layers, padding):
             c.add_polygon(points, layer=layer)
 
     if direction == "cw":
@@ -97,29 +115,27 @@ def bend_euler_s(**kwargs) -> Component:
 @gf.cell
 def bend_straight_bend(
     straight_length: float = 10.0,
-    angle: int = 90,
+    angle: float = 90,
     p: float = 0.5,
     with_arc_floorplan: bool = True,
     npoints: int = 720,
     direction: str = "ccw",
-    with_cladding_box: bool = True,
-    cross_section: CrossSectionOrFactory = strip,
+    cross_section: CrossSectionSpec = strip,
     **kwargs
 ) -> Component:
     """Sbend made of 2 euler bends and straight section in between.
 
     Args:
-        straight_length:
-        angle: total angle of the curve
-        p: Proportion of the curve that is an Euler curve
+        straight_length: in um.
+        angle: total angle of the curve.
+        p: Proportion of the curve that is an Euler curve.
         with_arc_floorplan: If False: `radius` is the minimum radius of curvature
           If True: The curve scales such that the endpoints match a bend_circular
-          with parameters `radius` and `angle`
-        npoints: Number of points used per 360 degrees
-        direction: cw (clock-wise) or ccw (counter clock-wise)
-        with_cladding_box: to avoid DRC acute angle errors in cladding
-        cross_section:
-        kwargs: cross_section settings
+          with parameters `radius` and `angle`.
+        npoints: Number of points used per 360 degrees.
+        direction: cw (clock-wise) or ccw (counter clock-wise).
+        cross_section: specification (CrossSection, string, CrossSectionFactory dict).
+        kwargs: cross_section settings.
 
 
     """
@@ -130,7 +146,6 @@ def bend_straight_bend(
         with_arc_floorplan=with_arc_floorplan,
         npoints=npoints,
         direction=direction,
-        with_cladding_box=with_cladding_box,
         cross_section=cross_section,
         **kwargs
     )
@@ -145,7 +160,7 @@ def bend_straight_bend(
     return c
 
 
-def _compare_bend_euler180():
+def _compare_bend_euler180() -> None:
     """Compare 180 bend euler with 2 90deg euler bends."""
     import gdsfactory as gf
 
@@ -162,16 +177,42 @@ def _compare_bend_euler180():
     c1.show()
 
 
+def _compare_bend_euler90():
+    """Compare bend euler with 90deg circular bend."""
+    import gdsfactory as gf
+
+    c = gf.Component()
+    radius = 10
+    b1 = bend_euler(radius=radius)
+    b2 = gf.components.bend_circular(radius=radius)
+
+    print(b1.info["length"])
+    print(b2.info["length"])
+
+    c << b1
+    c << b2
+    return c
+
+
 if __name__ == "__main__":
     # c = bend_euler_s()
-    # c = bend_euler180()
+    c = bend_euler()
+    # c = bend_euler(bbox_layers=[(2, 0), (3, 0)], bbox_offsets=[3, 3])
+    c.show(show_ports=True)
+
     # c = bend_euler(direction="cw")
     # c = bend_euler(angle=270)
     # c.pprint()
     # p = euler()
-    c = bend_straight_bend()
+    # c = bend_straight_bend()
+    # c = _compare_bend_euler90()
+
+    # c = gf.Component()
+    # b1 = c << bend_euler()
+    # b2 = c << bend_euler()
+    # b2.connect("o1", b1.ports["o2"])
+    # c.show(show_ports=False)
 
-    c.show()
     # _compare_bend_euler180()
     # import gdsfactory as gf
     # c = bend_euler(radius=10)
