@@ -1,4 +1,4 @@
-from typing import Optional, Tuple
+from typing import Optional
 
 import numpy as np
 from numpy import ndarray
@@ -14,12 +14,11 @@ from gdsfactory.geometry.functions import (
     path_length,
     snap_angle,
 )
-from gdsfactory.hash_points import hash_points
-from gdsfactory.types import Coordinate, Coordinates, Number
+from gdsfactory.types import Coordinate, Coordinates, LayerSpec, Number
 
 
 def bezier_curve(t: ndarray, control_points: Coordinates) -> ndarray:
-    """Returns bezier coordinates
+    """Returns bezier coordinates.
 
     Args:
         t: 1D array of points varying between 0 and 1.
@@ -29,7 +28,7 @@ def bezier_curve(t: ndarray, control_points: Coordinates) -> ndarray:
     ys = 0.0
     n = len(control_points) - 1
     for k in range(n + 1):
-        ank = binom(n, k) * (1 - t) ** (n - k) * t ** k
+        ank = binom(n, k) * (1 - t) ** (n - k) * t**k
         xs += ank * control_points[k][0]
         ys += ank * control_points[k][1]
 
@@ -44,38 +43,32 @@ def bezier_points(control_points: Coordinates, width: Number, npoints: int = 101
 
 @gf.cell
 def bezier(
-    name: Optional[str] = None,
     width: float = 0.5,
     control_points: Coordinates = ((0.0, 0.0), (5.0, 0.0), (5.0, 2.0), (10.0, 2.0)),
     npoints: int = 201,
-    layer: Tuple[int, int] = (1, 0),
+    layer: LayerSpec = "WG",
     with_manhattan_facing_angles: bool = True,
     spike_length: float = 0.0,
     start_angle: Optional[int] = None,
     end_angle: Optional[int] = None,
     grid: float = 0.001,
 ) -> Component:
-    """Bezier bend
-    We avoid autoname for control_points
+    """Returns Bezier bend.
 
     Args:
-        name: for the cell
-        width: straight width
-        control_points: list of points
-        npoints: number of points varying between 0 and 1
-        layer: layer
-        with_manhattan_facing_angles:
-        spike_length
-        start_angle
-        end_angle
-        grid
+        width: straight width (um)
+        control_points: list of points.
+        npoints: number of points varying between 0 and 1.
+        layer: layer spec.
+        with_manhattan_facing_angles: bool.
+        spike_length: um.
+        start_angle: deg.
+        end_angle: deg.
+        grid: in um.
     """
+    layer = gf.get_layer(layer)
 
-    if name is None:
-        points_hash = hash_points(control_points)
-        name = f"bezier_w{int(width*1e3)}_{points_hash}_{layer[0]}_{layer[1]}"
-
-    c = gf.Component(name=name)
+    c = gf.Component()
     t = np.linspace(0, 1, npoints)
     path_points = bezier_curve(t, control_points)
     polygon_points = extrude_path(
@@ -98,25 +91,25 @@ def bezier(
     p0 = path_points[0]
     p1 = path_points[-1]
     c.add_polygon(polygon_points, layer=layer)
-    c.add_port(name="o1", midpoint=p0, width=width, orientation=a0, layer=layer)
-    c.add_port(name="o2", midpoint=p1, width=width, orientation=a1, layer=layer)
+    c.add_port(name="o1", center=p0, width=width, orientation=a0, layer=layer)
+    c.add_port(name="o2", center=p1, width=width, orientation=a1, layer=layer)
 
     curv = curvature(path_points, t)
     length = gf.snap.snap_to_grid(path_length(path_points))
     min_bend_radius = gf.snap.snap_to_grid(1 / max(np.abs(curv)))
 
-    c.info.start_angle = gf.snap.snap_to_grid(angles[0])
-    c.info.end_angle = gf.snap.snap_to_grid(angles[-2])
-    c.info.length = length
-    c.info.min_bend_radius = min_bend_radius
+    c.info["start_angle"] = gf.snap.snap_to_grid(angles[0])
+    c.info["end_angle"] = gf.snap.snap_to_grid(angles[-2])
+    c.info["length"] = length
+    c.info["min_bend_radius"] = min_bend_radius
     return c
 
 
 def find_min_curv_bezier_control_points(
     start_point: ndarray,
     end_point: Coordinate,
-    start_angle: int,
-    end_angle: int,
+    start_angle: float,
+    end_angle: float,
     npoints: int = 201,
     alpha: float = 0.05,
     nb_pts: int = 2,
@@ -126,7 +119,7 @@ def find_min_curv_bezier_control_points(
     def array_1d_to_cpts(a):
         xs = a[::2]
         ys = a[1::2]
-        return [(x, y) for x, y in zip(xs, ys)]
+        return list(zip(xs, ys))
 
     def objective_func(p):
         """
@@ -171,4 +164,4 @@ if __name__ == "__main__":
     # print(c.ports)
     # print(c.ports["0"].y - c.ports["1"].y)
     # c.write_gds()
-    c.show()
+    c.show(show_ports=True)
