@@ -1,17 +1,16 @@
-from typing import Tuple
-
 import numpy as np
 from numpy import cos, pi, sin
 
 import gdsfactory as gf
 from gdsfactory.component import Component
+from gdsfactory.types import LayerSpec
 
 
 @gf.cell
 def circle(
     radius: float = 10.0,
     angle_resolution: float = 2.5,
-    layer: Tuple[int, int] = gf.LAYER.WG,
+    layer: LayerSpec = "WG",
 ) -> Component:
     """Generate a circle geometry.
 
@@ -19,9 +18,7 @@ def circle(
         radius: of the circle.
         angle_resolution: number of degrees per point.
         layer: layer.
-
     """
-
     c = Component()
     t = np.linspace(0, 360, int(360 / angle_resolution) + 1) * pi / 180
     xpts = (radius * cos(t)).tolist()
@@ -32,4 +29,4 @@ def circle(
 
 if __name__ == "__main__":
     c = circle()
-    c.show()
+    c.show(show_ports=True)
