@@ -13,7 +13,7 @@ COUNTER = itertools.count()
 
 
 def gen_tmp_port_name() -> str:
-    return "{}".format(next(COUNTER))
+    return f"{next(COUNTER)}"
 
 
 def swap(straights, i, j):
@@ -30,7 +30,7 @@ def dist(i, wgs1, wgs2):
 
 
 def get_sequence_cross(
-    straights_start, straights_end, iter_max=100, symbols=("X", "-")
+    straights_start, straights_end, iter_max: int = 100, symbols=("X", "-")
 ):
     """
     Args:
@@ -67,36 +67,33 @@ def get_sequence_cross(
 
         swaps = []
         i = 0
-        total_dist = 0
+        # total_dist = 0
+
         while i < N - 1:
             a = wgs[i]
             b = wgs[i + 1]
             d1 = dist(a, wgs, straights_end)
             d2 = dist(b, wgs, straights_end)
-            total_dist += abs(d1) + abs(d2)
+            # total_dist += abs(d1) + abs(d2)
 
-            """
             # The equality cases are very important:
             # if one straight needs to cross, then even if the other one is
             # already at the right place, it must swap to allow the other one
             # to cross
-            """
 
-            if d1 >= 0 and d2 <= 0 and not (d1 == 0 and d2 == 0):
+            if d1 >= 0 and d2 <= 0 and (d1 != 0 or d2 != 0):
                 wgs = swap(wgs, i, i + 1)
                 swaps += [X, X]
                 i += 1
-                # We cannot swap twice the same straight on the same iteration, so we
-                # skip the next straight by incrementing
-
-                # Edge case: Cannot swap if only one wg left so it has to be a straight
-                if i == N - 2:
-                    swaps += [S]
             else:
                 # Edge case if only one wg remain it is straight
                 swaps += [S]
-                if i == N - 2:
-                    swaps += [S]
+            # We cannot swap twice the same straight on the same iteration, so we
+            # skip the next straight by incrementing
+
+            # Edge case: Cannot swap if only one wg left so it has to be a straight
+            if i == N - 2:
+                swaps += [S]
             i += 1
 
         sequence.append(swaps)
@@ -115,16 +112,13 @@ def component_sequence_to_str(sequence):
 
     for i in range(M):
         j = M - 1 - i
-        line = ""
-        for col in sequence:
-            line += col[j]
-        line += "\n"
+        line = "".join(col[j] for col in sequence) + "\n"
         component_txt_lattice += line
 
     return component_txt_lattice
 
 
-def get_sequence_cross_str(straights_start, straights_end, iter_max=100):
+def get_sequence_cross_str(straights_start, straights_end, iter_max: int = 100):
     seq = get_sequence_cross(
         straights_start, straights_end, iter_max=iter_max, symbols=["X", "-"]
     )
@@ -140,14 +134,17 @@ def component_lattice(
         CXX
         C-X
         """,
-    components: Dict[str, Component] = None,
+    symbol_to_component: Dict[str, Component] = None,
     grid_per_unit: int = 1000,
-    name: str = "lattice",
 ) -> Component:
-    """
-    Returns a lattice Component of N inputs and outputs with components at given locations
-    Columns must have components with the same x spacing between ports input/output ports
-    Lines must have components with the same y spacing between input and output ports
+    """Return a lattice Component of N inputs and outputs
+    Columns must have components with the same x spacing between input/output ports
+    Lines must have components with the same y spacing between input/output ports
+
+    Args:
+        lattice: ASCII map with character:
+        symbol_to_component:
+        grid_per_unit:
 
     Lattice example:
 
@@ -165,27 +162,28 @@ def component_lattice(
       from gdsfactory.components.crossing_waveguide import crossing45
       from gdsfactory.components.crossing_waveguide import compensation_path
 
-      components =  {
+      symbol_to_component =  {
             "C": gf.routing.fanout2x2(component=gf.components.coupler(), port_spacing=40.0),
             "X": crossing45(port_spacing=40.0),
             "-": compensation_path(crossing45=crossing45(port_spacing=40.0)),
       }
-      c = gf.components.component_lattice(components=components)
+      c = gf.components.component_lattice(symbol_to_component=symbol_to_component)
       c.plot()
 
     """
-    components = components or {
+    x = crossing45(port_spacing=40)
+    symbol_to_component = symbol_to_component or {
         "C": gf.routing.fanout2x2(component=coupler(), port_spacing=40.0),
-        "X": crossing45(port_spacing=40.0),
-        "-": compensation_path(crossing45=crossing45(port_spacing=40.0)),
+        "X": x,
+        "-": compensation_path(x),
     }
 
     # Find y spacing and check that all components have same y spacing
-
     y_spacing = None
-    for component in components.values():
-        component = gf.call_if_func(component)
-        component.auto_rename_ports_orientation()
+    for component in symbol_to_component.values():
+        component = gf.get_component(component)
+        # component = component.copy()
+        # component.auto_rename_ports_orientation()
 
         for direction in ["W", "E"]:
             ports_dir = get_ports_facing(component.ports, direction)
@@ -202,14 +200,15 @@ def component_lattice(
                     )
 
     a = y_spacing
-    columns, columns_to_length = parse_lattice(lattice, components)
+    columns, columns_to_length = parse_lattice(lattice, symbol_to_component)
     keys = sorted(columns.keys())
 
-    components_to_nb_input_ports = {}
-    for c in components.keys():
-        components_to_nb_input_ports[c] = len(get_ports_facing(components[c], "W"))
+    components_to_nb_input_ports = {
+        c: len(get_ports_facing(symbol_to_component[c], "W"))
+        for c in symbol_to_component.keys()
+    }
 
-    component = gf.Component(name)
+    component = gf.Component()
     x = 0
     for i in keys:
         col = columns[i]
@@ -223,13 +222,17 @@ def component_lattice(
                 skip = 0
                 continue
 
-            if c in components.keys():
+            if c in symbol_to_component.keys():
                 # Compute the number of ports to skip: They will already be
                 # connected since they belong to this component
 
                 nb_inputs = components_to_nb_input_ports[c]
                 skip = nb_inputs - 1
-                _cmp = components[c].ref((x, y), port_id="oW{}".format(skip))
+
+                ports_cw = symbol_to_component[c].get_ports_list(clockwise=True)
+                _cmp = symbol_to_component[c].ref((x, y), port_id=ports_cw[skip].name)
+
+                # _cmp = symbol_to_component[c].ref((x, y), port_id="oW{}".format(skip))
                 component.add(_cmp)
 
                 if i == 0:
@@ -243,37 +246,46 @@ def component_lattice(
                         component.add_port(gen_tmp_port_name(), port=_p)
 
             else:
+                symbols = list(symbol_to_component.keys())
                 raise ValueError(
-                    f"symbol {c} not in components dict {components.keys()}"
+                    f"symbol {c!r} not in symbol_to_component dict {symbols}"
                 )
 
             j += 1
         x += L
 
+    component.auto_rename_ports()
     return component
 
 
 def parse_lattice(
-    lattice: str, components: Dict[str, Component]
+    lattice: str, symbol_to_component: Dict[str, Component]
 ) -> Tuple[Dict[int, List[str]], Dict[int, float64]]:
-    """extract each column"""
+    """Extract each column.
+
+    Args:
+        lattice:
+        symbol_to_component:
+    """
     lines = lattice.replace(" ", "").split("\n")
     columns = {}
     columns_to_length = {}
     for line in lines:
         if len(line) > 0:
-            i = 0
-            for c in line:
+            for i, c in enumerate(line):
                 if i not in columns.keys():
                     columns[i] = []
 
                 columns[i].append(c)
-                if c in components.keys():
-                    cmp = components[c]
-                    # columns_to_length[i] = cmp.ports["o2"].x - cmp.ports["o1"].x
-                    columns_to_length[i] = cmp.ports["oE0"].x - cmp.ports["oW0"].x
+                if c in symbol_to_component:
+                    cmp = symbol_to_component[c]
+                    pcw = cmp.get_ports_list(clockwise=True)
+                    pccw = cmp.get_ports_list(clockwise=False)
 
-                i += 1
+                    # columns_to_length[i] = cmp.ports["oE0"].x - cmp.ports["oW0"].x
+                    columns_to_length[i] = (
+                        cmp.ports[pccw[0].name].x - cmp.ports[pcw[0].name].x
+                    )
 
     return columns, columns_to_length
 
@@ -284,9 +296,9 @@ if __name__ == "__main__":
         "X": crossing45(port_spacing=40.0),
         "-": compensation_path(crossing45=crossing45(port_spacing=40.0)),
     }
-    c = gf.components.component_lattice(components=components_dict)
+    c = gf.components.component_lattice(symbol_to_component=components_dict)
     # c= gf.routing.fanout2x2(component=gf.components.coupler(), port_spacing=40.0)
     # c= crossing45(port_spacing=40.0)
     # c = compensation_path(crossing45=crossing45(port_spacing=40.0))
-    c.pprint()
-    c.show()
+    c.pprint_ports()
+    c.show(show_ports=True)
