@@ -3,17 +3,20 @@ from typing import Dict, Optional, Tuple
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import ComponentOrFactory
+from gdsfactory.types import ComponentSpec
 
 
 class SequenceGenerator:
     def __init__(
-        self, start_sequence="IL", repeated_sequence="ASASBSBS", end_sequence="LO"
-    ):
-        """sequence generator.
+        self,
+        start_sequence: str = "IL",
+        repeated_sequence: str = "ASASBSBS",
+        end_sequence: str = "LO",
+    ) -> None:
+        """Sequence generator.
+
         Main use case: any type of cascade of components with repeating patterns
         such as serpentine, cutbacks etc...
-
         Component sequences have two ports by default.
         it adds aliases for the components forming the sequence.
         They use the component local name and append a suffix index starting from 1,
@@ -48,13 +51,11 @@ def _parse_component_name(name: str) -> Tuple[str, bool]:
     If the component name has more than one character and starts with "!"
     then we need to flip along the axis given by the input port angle
     """
-    if len(name) != 1 and name[0] == "!":
-        return name[1:], True
-    return name, False
+    return (name[1:], True) if len(name) != 1 and name[0] == "!" else (name, False)
 
 
 def _flip_ref(c_ref, port_name):
-    a = c_ref.ports[port_name].angle
+    a = c_ref.ports[port_name].orientation
     if a in [0, 180]:
         c_ref.reflect_v(port_name)
     else:
@@ -65,7 +66,7 @@ def _flip_ref(c_ref, port_name):
 @gf.cell
 def component_sequence(
     sequence: str,
-    symbol_to_component: Dict[str, Tuple[ComponentOrFactory, str, str]],
+    symbol_to_component: Dict[str, Tuple[ComponentSpec, str, str]],
     ports_map: Optional[Dict[str, Tuple[str, str]]] = None,
     port_name1: str = "o1",
     port_name2: str = "o2",
@@ -74,17 +75,17 @@ def component_sequence(
     """Returns component from a ASCII sequence and a dictionary to interpret each symbol
 
     Args:
-        sequence: a string or a list of symbols
-        symbol_to_component: maps symbols to (component, input, output)
-        ports_map: (optional) extra port mapping using the convention
+        sequence: a string or a list of symbols.
+        symbol_to_component: maps symbols to (component, input, output).
+        ports_map: (optional) extra port mapping using the convention.
             {port_name: (alias_name, port_name)}
-        port_name1: input port_name
-        port_name2: output port_name
-        start_orientation:
+        port_name1: input port_name.
+        port_name2: output port_name.
+        start_orientation: in degrees.
 
     Returns:
-        component containing the sequence of sub-components
-        instantiated and connected together in the sequence order
+        component: containing the sequence of sub-components
+            instantiated and connected together in the sequence order.
 
     .. plot::
         :include-source:
@@ -104,8 +105,8 @@ def component_sequence(
         }
 
         # Each character in the sequence represents a component
-        sequence = "AB-H-H-H-H-BA"
-        c = gf.components.component_sequence(sequence=sequence, symbol_to_component=symbol_to_component)
+        s = "AB-H-H-H-H-BA"
+        c = gf.components.component_sequence(sequence=s, symbol_to_component=symbol_to_component)
         c.plot()
 
     """
@@ -126,8 +127,8 @@ def component_sequence(
     # To generate unique aliases for each instance
     counters = {k: count(start=1) for k in symbol_to_component.keys()}
 
-    def _next_id(name):
-        return "{}{}".format(name, next(counters[name]))
+    def _next_id(name) -> str:
+        return f"{name}{next(counters[name])}"
 
     component = Component()
 
@@ -155,7 +156,7 @@ def component_sequence(
         s, do_flip = _parse_component_name(s)
 
         component_i, input_port, next_port = symbol_to_component[s]
-        component_i = component_i() if callable(component_i) else component_i
+        component_i = gf.get_component(component_i)
         ref = component.add_ref(component_i, alias=_next_id(s))
 
         if do_flip:
@@ -210,5 +211,5 @@ if __name__ == "__main__":
     c = gf.components.component_sequence(
         sequence=sequence, symbol_to_component=symbol_to_component_map
     )
-    c.show()
+    c.show(show_ports=True)
     c.pprint()
