@@ -7,9 +7,9 @@ from gdsfactory.components.coupler90 import coupler90 as coupler90function
 from gdsfactory.components.coupler_straight import (
     coupler_straight as coupler_straight_function,
 )
-from gdsfactory.cross_section import strip
+from gdsfactory.components.straight import straight as straight_function
 from gdsfactory.snap import assert_on_2nm_grid
-from gdsfactory.types import ComponentFactory, CrossSectionFactory
+from gdsfactory.types import ComponentSpec, CrossSectionSpec
 
 
 @gf.cell
@@ -17,10 +17,12 @@ def coupler_ring(
     gap: float = 0.2,
     radius: float = 5.0,
     length_x: float = 4.0,
-    coupler90: ComponentFactory = coupler90function,
-    bend: Optional[ComponentFactory] = None,
-    coupler_straight: ComponentFactory = coupler_straight_function,
-    cross_section: CrossSectionFactory = strip,
+    coupler90: ComponentSpec = coupler90function,
+    bend: Optional[ComponentSpec] = None,
+    straight: ComponentSpec = straight_function,
+    coupler_straight: ComponentSpec = coupler_straight_function,
+    cross_section: CrossSectionSpec = "strip",
+    bend_cross_section: Optional[CrossSectionSpec] = None,
     **kwargs
 ) -> Component:
     r"""Coupler for ring.
@@ -30,10 +32,11 @@ def coupler_ring(
         radius: of the bends.
         length_x: length of the parallel coupled straight waveguides.
         coupler90: straight coupled to a 90deg bend.
-        bend: factory for bend
+        bend: bend spec.
         coupler_straight: two parallel coupled straight waveguides.
-        cross_section:
-        kwargs: cross_section settings
+        cross_section: cross_section spec.
+        bend_cross_section: optional bend cross_section spec.
+        kwargs: cross_section settings for bend and coupler.
 
     .. code::
 
@@ -52,19 +55,22 @@ def coupler_ring(
     assert_on_2nm_grid(gap)
 
     # define subcells
-    coupler90_component = (
-        coupler90(
-            gap=gap, radius=radius, bend=bend, cross_section=cross_section, **kwargs
-        )
-        if callable(coupler90)
-        else coupler90
+    coupler90_component = gf.get_component(
+        coupler90,
+        gap=gap,
+        radius=radius,
+        bend=bend,
+        cross_section=cross_section,
+        bend_cross_section=bend_cross_section,
+        **kwargs
     )
-    coupler_straight_component = (
-        coupler_straight(
-            gap=gap, length=length_x, cross_section=cross_section, **kwargs
-        )
-        if callable(coupler_straight)
-        else coupler_straight
+    coupler_straight_component = gf.get_component(
+        coupler_straight,
+        gap=gap,
+        length=length_x,
+        cross_section=cross_section,
+        straight=straight,
+        **kwargs
     )
 
     # add references to subcells
@@ -78,19 +84,19 @@ def coupler_ring(
     cbl.reflect(p1=(0, y), p2=(1, y))
     cbl.connect(port="o2", destination=cs.ports["o2"])
 
-    c.absorb(cbl)
-    c.absorb(cbr)
-    c.absorb(cs)
-
     c.add_port("o1", port=cbl.ports["o3"])
     c.add_port("o2", port=cbl.ports["o4"])
     c.add_port("o3", port=cbr.ports["o3"])
     c.add_port("o4", port=cbr.ports["o4"])
+
+    c.add_ports(cbl.get_ports_list(port_type="electrical"), prefix="cbl")
+    c.add_ports(cbr.get_ports_list(port_type="electrical"), prefix="cbr")
     c.auto_rename_ports()
     return c
 
 
 if __name__ == "__main__":
 
-    c = coupler_ring(width=1, layer=(2, 0))
+    # c = coupler_ring(width=1, layer=(2, 0), length_x=20)
+    c = coupler_ring(cross_section="strip_heater_metal", length_x=20)
     c.show(show_subports=True)
