@@ -1,29 +1,26 @@
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.straight import straight as straight_function
-from gdsfactory.types import ComponentFactory
+from gdsfactory.types import ComponentSpec
 
 
 @gf.cell
 def coupler_straight(
     length: float = 10.0,
     gap: float = 0.27,
-    straight: ComponentFactory = straight_function,
+    straight: ComponentSpec = straight_function,
     **kwargs
 ) -> Component:
     """Coupler_straight with two parallel straights.
 
     Args:
-        length: of straight
-        gap: between straights
-        straight: straight waveguide function
-        kwargs:  cross_section settings
+        length: of straight.
+        gap: between straights.
+        straight: straight waveguide function.
+        kwargs: cross_section settings.
     """
     component = Component()
-
-    straight_component = (
-        straight(length=length, **kwargs) if callable(straight) else straight
-    )
+    straight_component = gf.get_component(straight, length=length, **kwargs)
 
     top = component << straight_component
     bot = component << straight_component
@@ -31,7 +28,7 @@ def coupler_straight(
     # bot.ymax = 0
     # top.ymin = gap
 
-    top.movey(straight_component.info.width + gap)
+    top.movey(straight_component.info["width"] + gap)
 
     component.add_port("o1", port=bot.ports["o1"])
     component.add_port("o2", port=top.ports["o1"])
@@ -42,5 +39,5 @@ def coupler_straight(
 
 
 if __name__ == "__main__":
-    c = coupler_straight(width=1)
+    c = coupler_straight(length=2)
     c.show(show_ports=True)
