@@ -1,26 +1,26 @@
-from typing import Optional, Tuple
+from typing import Optional
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.tech import LAYER
+from gdsfactory.types import LayerSpec
 
 
 @gf.cell
 def cross(
     length: float = 10.0,
     width: float = 3.0,
-    layer: Tuple[int, int] = LAYER.WG,
+    layer: LayerSpec = "WG",
     port_type: Optional[str] = None,
 ) -> Component:
     """Returns a cross from two rectangles of length and width.
 
     Args:
-        length: float Length of the cross from one end to the other
-        width: float Width of the arms of the cross
-        layer: layer for geometry
-        port_type:
-
+        length: float Length of the cross from one end to the other.
+        width: float Width of the arms of the cross.
+        layer: layer for geometry.
+        port_type: None, optical, electrical.
     """
+    layer = gf.get_layer(layer)
     c = gf.Component()
     R = gf.components.rectangle(size=(width, length), layer=layer)
     r1 = c.add_ref(R).rotate(90)
@@ -34,7 +34,7 @@ def cross(
             width=width,
             layer=layer,
             orientation=0,
-            midpoint=(+length / 2, 0),
+            center=(+length / 2, 0),
             port_type=port_type,
         )
         c.add_port(
@@ -42,7 +42,7 @@ def cross(
             width=width,
             layer=layer,
             orientation=180,
-            midpoint=(-length / 2, 0),
+            center=(-length / 2, 0),
             port_type=port_type,
         )
         c.add_port(
@@ -50,7 +50,7 @@ def cross(
             width=width,
             layer=layer,
             orientation=90,
-            midpoint=(0, length / 2),
+            center=(0, length / 2),
             port_type=port_type,
         )
         c.add_port(
@@ -58,7 +58,7 @@ def cross(
             width=width,
             layer=layer,
             orientation=270,
-            midpoint=(0, -length / 2),
+            center=(0, -length / 2),
             port_type=port_type,
         )
         c.auto_rename_ports()
@@ -67,7 +67,7 @@ def cross(
 
 if __name__ == "__main__":
     c = cross()
-    c.show()
+    c.show(show_ports=True)
     # c.pprint_ports()
     # cc = gf.routing.add_fiber_array(component=c)
-    # cc.show()
+    # cc.show(show_ports=True)
