@@ -5,40 +5,42 @@ from gdsfactory.components.component_sequence import component_sequence
 from gdsfactory.components.straight import straight as straight_function
 from gdsfactory.components.taper import taper
 from gdsfactory.components.taper_from_csv import taper_0p5_to_3_l36
-from gdsfactory.types import ComponentFactory, Optional
+from gdsfactory.types import ComponentSpec, Optional
 
 
 @gf.cell
 def cutback_component(
-    component: ComponentFactory = taper_0p5_to_3_l36,
+    component: ComponentSpec = taper_0p5_to_3_l36,
     cols: int = 4,
     rows: int = 5,
     radius: float = 5.0,
     port1: str = "o1",
     port2: str = "o2",
-    bend180: ComponentFactory = bend_euler180,
-    straight: ComponentFactory = straight_function,
+    bend180: ComponentSpec = bend_euler180,
+    straight: ComponentSpec = straight_function,
     mirror: bool = False,
     straight_length: Optional[float] = None,
 ) -> Component:
     """Returns a daisy chain of components for measuring their loss.
 
     Args:
-        component: for cutback
-        cols
-        rows
-        radius: for bend
-        port1: name of first optical port
-        port2: name of second optical port
-        bend180: ubend
-        straight: waveguide function to connect both sides
-        mirror: Flips component. Useful when 'o2' is the port that you want to route to
-        straight_length: length of the straight section beween cutbacks
+        component: for cutback.
+        cols: number of columns.
+        rows: number of rows.
+        radius: for bend.
+        port1: name of first optical port.
+        port2: name of second optical port.
+        bend180: ubend.
+        straight: waveguide spec to connect both sides.
+        mirror: Flips component. Useful when 'o2' is the port that you want to route to.
+        straight_length: length of the straight section between cutbacks.
 
     """
-    component = component() if callable(component) else component
-    bendu = bend180(radius=radius)
-    straight_component = straight(length=straight_length or radius * 2)
+    component = gf.get_component(component)
+    bendu = gf.get_component(bend180, radius=radius)
+    straight_component = gf.get_component(
+        straight, length=straight_length or radius * 2
+    )
 
     # Define a map between symbols and (component, input port, output port)
     symbol_to_component = {
@@ -79,7 +81,7 @@ def cutback_component(
     c.copy_child_info(component)
     c.info["components"] = n
 
-    # c.info["parent_name"] = f"loopback_{component.info_child.name}_{n}"
+    # c.info["parent_name"] = f"loopback_{component.metadata_child.get('name')}_{n}"
     return c
 
 
@@ -96,4 +98,4 @@ if __name__ == "__main__":
     c = cutback_component()
     # c = cutback_component_mirror(component=component_flipped)
     # c = gf.routing.add_fiber_single(c)
-    c.show()
+    c.show(show_ports=True)
