@@ -1,4 +1,4 @@
-""" DBR gratings
+""" DBR gratings.
 wavelength = 2*period*neff
 period = wavelength/2/neff
 
@@ -11,7 +11,7 @@ import gdsfactory as gf
 from gdsfactory.cell import cell
 from gdsfactory.component import Component
 from gdsfactory.components.straight import straight as straight_function
-from gdsfactory.types import ComponentFactory
+from gdsfactory.types import ComponentSpec
 
 period = 318e-3
 w0 = 0.5
@@ -26,15 +26,38 @@ def dbr_cell(
     w2: float = w2,
     l1: float = period / 2,
     l2: float = period / 2,
-    straight: ComponentFactory = straight_function,
+    straight: ComponentSpec = straight_function,
 ) -> Component:
+    """Distributed Bragg Reflector unit cell.
+
+    Args:
+        w1: thin width in um.
+        l1: thin length in um.
+        w2: thick width in um.
+        l2: thick length in um.
+        n: number of periods.
+        straight: spec in um.
+
+    .. code::
+
+           l1      l2
+        <-----><-------->
+                _________
+        _______|
+
+          w1       w2
+        _______
+               |_________
+
+
+    """
     l1 = gf.snap.snap_to_grid(l1)
     l2 = gf.snap.snap_to_grid(l2)
     w1 = gf.snap.snap_to_grid(w1, 2)
     w2 = gf.snap.snap_to_grid(w2, 2)
     c = Component()
-    c1 = c << straight(length=l1, width=w1)
-    c2 = c << straight(length=l2, width=w2)
+    c1 = c << gf.get_component(straight, length=l1, width=w1)
+    c2 = c << gf.get_component(straight, length=l2, width=w2)
     c2.connect(port="o1", destination=c1.ports["o2"])
     c.add_port("o1", port=c1.ports["o1"])
     c.add_port("o2", port=c2.ports["o2"])
@@ -48,17 +71,17 @@ def dbr(
     l1: float = period / 2,
     l2: float = period / 2,
     n: int = 10,
-    straight: ComponentFactory = straight_function,
+    straight: ComponentSpec = straight_function,
 ) -> Component:
-    """Distributed Bragg Reflector
+    """Distributed Bragg Reflector.
 
     Args:
-        w1: thin width
-        l1: thin length
-        w2: thick width
-        l2: thick length
-        n: number of periods
-        straight: function
+        w1: thin width in um.
+        l1: thin length in um.
+        w2: thick width in um.
+        l2: thick length in um.
+        n: number of periods.
+        straight: spec in um.
 
     .. code::
 
@@ -86,7 +109,7 @@ def dbr(
     c.add_array(cell, columns=n, rows=1, spacing=(l1 + l2, 100))
     c.add_port("o1", port=cell.ports["o1"])
     p1 = c.add_port("o2", port=cell.ports["o2"])
-    p1.midpoint = [(l1 + l2) * n, 0]
+    p1.center = [(l1 + l2) * n, 0]
     return c
 
 
@@ -95,4 +118,4 @@ if __name__ == "__main__":
     # c = dbr()
     c = dbr_cell()
     c.assert_ports_on_grid()
-    c.show()
+    c.show(show_ports=True)
