@@ -6,7 +6,7 @@ from gdsfactory.components.bend_euler import bend_euler
 from gdsfactory.components.straight import straight as straight_function
 from gdsfactory.components.taper import taper as taper_function
 from gdsfactory.routing.manhattan import round_corners
-from gdsfactory.types import ComponentFactory
+from gdsfactory.types import ComponentSpec
 
 
 @gf.cell
@@ -17,24 +17,23 @@ def delay_snake(
     L0: float = 5.0,
     taper_length: float = 10.0,
     n: int = 2,
-    taper: ComponentFactory = taper_function,
-    bend: ComponentFactory = bend_euler,
-    straight: ComponentFactory = straight_function,
+    taper: ComponentSpec = taper_function,
+    bend: ComponentSpec = bend_euler,
+    straight: ComponentSpec = straight_function,
     **kwargs
 ) -> Component:
-    """Snake input facing west
-    Snake output facing east
+    """Snake input facing west output facing east.
 
     Args:
-        wg_width
-        wg_width_wide: for the wide
-        total_length:
-        L0: initial offset
-        taper_length: length of the taper
-        n: number of loops
-        taper: taper library
-        bend
-        straight
+        wg_width: waveguide width.
+        wg_width_wide: for the wide.
+        total_length: of the delay.
+        L0: initial offset.
+        taper_length: length of the taper.
+        n: number of loops.
+        taper: taper library.
+        bend: bend spec.
+        straight: straight spec.
 
     .. code::
 
@@ -51,8 +50,8 @@ def delay_snake(
 
     """
     epsilon = 0.1
-    bend90 = bend(width=wg_width, **kwargs)
-    dy = bend90.info.dy
+    bend90 = gf.get_component(bend, width=wg_width, **kwargs)
+    dy = bend90.info["dy"]
     DL = (total_length + L0 - n * (pi * dy + epsilon)) / (2 * n + 1)
     L2 = DL - L0
     assert (
@@ -72,8 +71,8 @@ def delay_snake(
 
     component = gf.Component()
     if taper:
-        _taper = taper(
-            width1=wg_width, width2=wg_width_wide, length=taper_length, **kwargs
+        _taper = gf.get_component(
+            taper, width1=wg_width, width2=wg_width_wide, length=taper_length, **kwargs
         )
     route = round_corners(
         points=path,
