@@ -1,31 +1,30 @@
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.rectangle import rectangle
-from gdsfactory.components.triangle import triangle
-from gdsfactory.tech import LAYER
-from gdsfactory.types import ComponentFactory, Float2, Layer
+from gdsfactory.components.triangles import triangle
+from gdsfactory.types import ComponentSpec, Float2, LayerSpec
 
-triangle_metal = gf.partial(triangle, layer=LAYER.M3, xtop=2)
+triangle_metal = gf.partial(triangle, layer="M3", xtop=2)
 
 
 @gf.cell
 def dicing_lane(
     size: Float2 = (50, 300),
-    marker: ComponentFactory = triangle_metal,
-    layer_dicing: Layer = (100, 0),
+    marker: ComponentSpec = triangle_metal,
+    layer_dicing: LayerSpec = "DICING",
 ) -> Component:
     """Dicing lane with triangular markers on both sides.
 
     Args:
         size: (tuple) Width and height of rectangle.
-        marker: function to generate the dicing lane markers
+        marker: function to generate the dicing lane markers.
         layer_dicing: Specific layer to put polygon geometry on.
 
     """
     c = Component()
     r = c << rectangle(size=size, layer=layer_dicing)
 
-    m = marker()
+    m = gf.get_component(marker)
 
     mbr = c << m
     mbr.xmin = r.xmax
@@ -49,4 +48,4 @@ def dicing_lane(
 
 if __name__ == "__main__":
     c = dicing_lane()
-    c.show()
+    c.show(show_ports=True)
