@@ -1,4 +1,4 @@
-from typing import Optional, Tuple
+from typing import Optional
 
 import numpy as np
 from numpy import ndarray
@@ -6,8 +6,7 @@ from numpy import ndarray
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.geometry.functions import DEG2RAD, extrude_path
-from gdsfactory.tech import LAYER
-from gdsfactory.types import Layer
+from gdsfactory.types import CrossSectionSpec, LayerSpec
 
 
 def ellipse_arc(
@@ -25,8 +24,12 @@ def ellipse_arc(
     An ellipse with a = b has zero eccentricity (is a circle)
 
     Args:
-        a: ellipse semi-major axis
-        b: semi-minor axis
+        a: ellipse semi-major axis.
+        b: semi-minor axis.
+        x0: in um.
+        theta_min: in rad.
+        theta_max: in rad.
+        angle_step: in rad.
 
     """
     theta = np.arange(theta_min, theta_max + angle_step, angle_step) * DEG2RAD
@@ -48,19 +51,14 @@ def grating_tooth_points(
     theta_max = taper_angle / 2
 
     backbone_points = ellipse_arc(ap, bp, xp, theta_min, theta_max, angle_step)
-    if spiked:
-        spike_length = width / 3
-    else:
-        spike_length = 0.0
-    points = extrude_path(
+    spike_length = width / 3 if spiked else 0.0
+    return extrude_path(
         backbone_points,
         width,
         with_manhattan_facing_angles=False,
         spike_length=spike_length,
     )
 
-    return points
-
 
 def grating_taper_points(
     a: float,
@@ -76,8 +74,7 @@ def grating_taper_points(
     port_position = np.array((x0, 0))
     p0 = port_position + (0, wg_width / 2)
     p1 = port_position + (0, -wg_width / 2)
-    points = np.vstack([p0, p1, taper_arc])
-    return points
+    return np.vstack([p0, p1, taper_arc])
 
 
 @gf.cell
@@ -88,42 +85,40 @@ def grating_coupler_elliptical(
     wavelength: float = 1.554,
     fiber_angle: float = 15.0,
     grating_line_width: float = 0.343,
-    wg_width: float = 0.5,
     neff: float = 2.638,  # tooth effective index
     nclad: float = 1.443,
-    layer: Tuple[int, int] = LAYER.WG,
-    p_start: int = 26,
     n_periods: int = 30,
     big_last_tooth: bool = False,
-    layer_slab: Optional[Tuple[int, int]] = LAYER.SLAB150,
+    layer_slab: LayerSpec = "SLAB150",
     slab_xmin: float = -1.0,
     slab_offset: float = 2.0,
-    fiber_marker_width: float = 11.0,
-    fiber_marker_layer: Optional[Layer] = gf.LAYER.TE,
+    fiber_marker_width: Optional[float] = 11.0,
+    fiber_marker_layer: LayerSpec = "TE",
     spiked: bool = True,
+    cross_section: CrossSectionSpec = "strip",
+    **kwargs,
 ) -> Component:
     r"""Grating coupler with parametrization based on Lumerical FDTD simulation.
 
     Args:
-        polarization: te or tm
-        taper_length: taper length from input
-        taper_angle: grating flare angle
-        wavelength: grating transmission central wavelength (um)
-        fiber_angle: fibre angle in degrees determines ellipticity
-        grating_line_width
-        wg_width: waveguide width
-        neff: tooth effective index
-        nclad: cladding effective index
-        layer: LAYER.WG
-        p_start: period start first grating teeth
-        n_periods: number of periods
-        big_last_tooth: adds a big_last_tooth
-        layer_slab: layer that protects the slab under the grating
-        slab_xmin: where 0 is at the start of the taper
-        fiber_marker_width: width
-        fiber_marker_layer: Optional circular marker
-        spiked: grating teeth have sharp spikes to avoid non-manhattan drc errors
-
+        polarization: te or tm.
+        taper_length: taper length from input.
+        taper_angle: grating flare angle.
+        wavelength: grating transmission central wavelength (um).
+        fiber_angle: fibre angle in degrees determines ellipticity.
+        grating_line_width: in um.
+        neff: tooth effective index.
+        nclad: cladding effective index.
+        n_periods: number of periods.
+        big_last_tooth: adds a big_last_tooth.
+        layer_slab: layer that protects the slab under the grating.
+        slab_xmin: where 0 is at the start of the taper.
+        slab_offset: in um.
+        fiber_marker_width: width in um.
+        fiber_marker_layer: fiber marker layer.
+        spiked: grating teeth have sharp spikes to avoid non-manhattan drc errors.
+        cross_section: specification (CrossSection, string or dict).
+        kwargs: cross_section settings.
 
     .. code::
 
@@ -137,10 +132,14 @@ def grating_coupler_elliptical(
             o1  ______________|
 
     """
+    xs = gf.get_cross_section(cross_section, **kwargs)
+
+    wg_width = xs.width
+    layer = xs.layer
 
     # Compute some ellipse parameters
     sthc = np.sin(fiber_angle * DEG2RAD)
-    d = neff ** 2 - nclad ** 2 * sthc ** 2
+    d = neff**2 - nclad**2 * sthc**2
     a1 = wavelength * neff / d
     b1 = wavelength / np.sqrt(d)
     x1 = wavelength * nclad * sthc / d
@@ -152,24 +151,16 @@ def grating_coupler_elliptical(
     period = a1 + x1
 
     c = gf.Component()
-    c.info.polarization = polarization
-    c.info.wavelength = wavelength
-
-    # Make each grating line
-    for p in range(p_start, p_start + n_periods + 1):
-        pts = grating_tooth_points(
-            p * a1, p * b1, p * x1, grating_line_width, taper_angle, spiked=spiked
-        )
-        c.add_polygon(pts, layer)
+    c.info["polarization"] = polarization
+    c.info["wavelength"] = wavelength
 
     # Make the taper
-    p_taper = p_start - 1
-    p_taper_eff = p_taper
-    a_taper = a1 * p_taper_eff
-    b_taper = b1 * p_taper_eff
-    x_taper = x1 * p_taper_eff
+    p = taper_length / period
+    a_taper = a1 * p
+    b_taper = b1 * p
+    x_taper = x1 * p
 
-    x_output = a_taper + x_taper - taper_length + grating_line_width / 2
+    x_output = a_taper + x_taper - taper_length
     pts = grating_taper_points(
         a=a_taper,
         b=b_taper,
@@ -180,21 +171,23 @@ def grating_coupler_elliptical(
     )
     c.add_polygon(pts, layer)
 
-    # Superimpose a tooth without spikes at end of taper to match the period.
-    pts = grating_tooth_points(
-        ap=a_taper,
-        bp=b_taper,
-        xp=x_taper,
-        width=grating_line_width,
-        taper_angle=taper_angle,
-        spiked=spiked,
-    )
-    c.add_polygon(pts, layer)
+    width = gf.snap.snap_to_grid(grating_line_width)
+    gap = gf.snap.snap_to_grid(period - grating_line_width)
+
+    xi = taper_length
+    for p in range(n_periods):
+        xi += gap + width / 2
+        p = xi / period
+        pts = grating_tooth_points(
+            p * a1, p * b1, p * x1, width, taper_angle, spiked=spiked
+        )
+        c.add_polygon(pts, layer)
+        xi += width / 2
 
-    # Add last "large tooth" after the standard grating teeth
     w = 1.0
     total_length = (
-        period * (p_start + n_periods)
+        period * n_periods
+        + taper_length
         + grating_line_width / 2
         + period
         - grating_line_width
@@ -202,6 +195,8 @@ def grating_coupler_elliptical(
     )
 
     if big_last_tooth:
+        # Add last "large tooth" after the standard grating teeth
+
         a = total_length / (1 + x1 / a1)
         b = b1 / a1 * a
         x = x1 / a1 * a
@@ -210,7 +205,7 @@ def grating_coupler_elliptical(
         c.add_polygon(pts, layer)
 
     x = np.round(taper_length + x_output, 3)
-    if fiber_marker_layer:
+    if fiber_marker_width:
         circle = gf.components.circle(
             radius=fiber_marker_width / 2, layer=fiber_marker_layer
         )
@@ -218,10 +213,9 @@ def grating_coupler_elliptical(
         circle_ref.movex(x + fiber_marker_width / 2)
 
     name = f"vertical_{polarization.lower()}"
-
     c.add_port(
         name=name,
-        midpoint=[x, 0],
+        center=(x + fiber_marker_width / 2, 0),
         width=fiber_marker_width,
         orientation=0,
         layer=fiber_marker_layer,
@@ -229,7 +223,7 @@ def grating_coupler_elliptical(
     )
 
     c.add_port(
-        name="o1", midpoint=[x_output, 0], width=wg_width, orientation=180, layer=layer
+        name="o1", center=(x_output, 0), width=wg_width, orientation=180, layer=layer
     )
 
     if layer_slab:
@@ -246,13 +240,17 @@ def grating_coupler_elliptical(
             layer_slab,
         )
 
+    if xs.add_bbox:
+        c = xs.add_bbox(c)
+    if xs.add_pins:
+        c = xs.add_pins(c)
     return c
 
 
 grating_coupler_elliptical_tm = gf.partial(
     grating_coupler_elliptical,
     grating_line_width=0.707,
-    fiber_marker_layer=gf.LAYER.TM,
+    fiber_marker_layer="TM",
     polarization="tm",
     taper_length=30,
     slab_xmin=-2,
@@ -265,11 +263,13 @@ grating_coupler_elliptical_te = grating_coupler_elliptical
 
 
 if __name__ == "__main__":
-    c = grating_coupler_elliptical_tm(taper_length=30)
-    # c = grating_coupler_elliptical_te(layer_slab=None, with_fiber_marker=False)
-    # c = grating_coupler_elliptical()
+    # c = grating_coupler_elliptical_tm(taper_length=30)
+    c = grating_coupler_elliptical_te(cladding_layers=((2, 0), (3, 0)))
+    # c = grating_coupler_elliptical(layer=(2, 0), taper_length=50, slab_xmin=-5)
     # print(c.polarization)
     # print(c.wavelength)
     # print(c.ports)
     # c.pprint()
-    c.show()
+    # c = gf.c.extend_ports(c)
+    # c = gf.routing.add_fiber_array(grating_coupler=grating_coupler_elliptical, with_loopback=False)
+    c.show(show_ports=True)
