@@ -23,15 +23,15 @@ def get_grating_period_curved(
     If you use an index matching fluid or glue, then it should be 1.45
 
     Args:
-        fiber_angle: in degrees
-        wavelength: um
-        n_slab: slab refractive index
-        n_clad: cladding refractive index
+        fiber_angle: in degrees.
+        wavelength: um.
+        n_slab: slab refractive index.
+        n_clad: cladding refractive index.
     """
 
     DEG2RAD = pi / 180
     cos_fib_angle = sin(DEG2RAD * fiber_angle)
-    n2_reduced = n_slab ** 2 - n_clad ** 2 * cos_fib_angle ** 2
+    n2_reduced = n_slab**2 - n_clad**2 * cos_fib_angle**2
     sqrt_n2_reduced = sqrt(n2_reduced)
     h_period = wavelength * (n_slab + n_clad * cos_fib_angle) / n2_reduced
     v_period = wavelength / sqrt_n2_reduced
