@@ -1,26 +1,24 @@
-from typing import Tuple
-
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.tech import LAYER
+from gdsfactory.types import LayerSpec
 
 
 @gf.cell
 def hline(
     length: float = 10.0,
     width: float = 0.5,
-    layer: Tuple[int, int] = LAYER.WG,
+    layer: LayerSpec = "WG",
     port_type: str = "optical",
 ) -> Component:
-    """Horizonal line straight, with ports on east and west sides"""
+    """Horizontal line straight, with ports on east and west sides"""
     c = gf.Component()
-    a = width / 2
     if length > 0 and width > 0:
+        a = width / 2
         c.add_polygon([(0, -a), (length, -a), (length, a), (0, a)], layer=layer)
 
     c.add_port(
         name="o1",
-        midpoint=[0, 0],
+        center=(0.0, 0.0),
         width=width,
         orientation=180,
         layer=layer,
@@ -28,19 +26,19 @@ def hline(
     )
     c.add_port(
         name="o2",
-        midpoint=[length, 0],
+        center=(length, 0.0),
         width=width,
         orientation=0,
         layer=layer,
         port_type=port_type,
     )
 
-    c.info.width = float(width)
-    c.info.length = float(length)
+    c.info["width"] = width
+    c.info["length"] = length
     return c
 
 
 if __name__ == "__main__":
     c = hline(width=10)
     print(c)
-    c.show()
+    c.show(show_ports=True)
