@@ -1,6 +1,7 @@
 from typing import Tuple
 
 import gdsfactory as gf
+from gdsfactory.types import LayerSpec
 
 
 @gf.cell
@@ -8,21 +9,22 @@ def litho_ruler(
     height: float = 2,
     width: float = 0.5,
     spacing: float = 2.0,
-    scale: Tuple[float] = (3, 1, 1, 1, 1, 2, 1, 1, 1, 1),
+    scale: Tuple[float, ...] = (3, 1, 1, 1, 1, 2, 1, 1, 1, 1),
     num_marks: int = 21,
-    layer: Tuple[int, int] = (1, 0),
-) -> gf.Component():
-    """Creates a ruler structure for lithographic measurement with marks of
-    varying scales to allow for easy reading by eye.
+    layer: LayerSpec = "WG",
+) -> gf.Component:
+    """Ruler structure for lithographic measurement.
+
+    Includes marks of varying scales to allow for easy reading by eye.
 
     adapted from phidl.geometry
 
     Args:
-        height : Height of the ruling marks.
-        width : Width of the ruling marks.
-        spacing : Center-to-center spacing of the ruling marks
-        scale : Height scale pattern of marks
-        num_marks : Total number of marks to generate
+        height: Height of the ruling marks in um.
+        width: Width of the ruling marks in um.
+        spacing: Center-to-center spacing of the ruling marks in um.
+        scale: Height scale pattern of marks.
+        num_marks: Total number of marks to generate.
         layer: Specific layer to put the ruler geometry on.
 
     """
@@ -40,4 +42,4 @@ def litho_ruler(
 
 if __name__ == "__main__":
     c = litho_ruler()
-    c.show()
+    c.show(show_ports=True)
