@@ -1,34 +1,37 @@
-from typing import List, Tuple
+from typing import Tuple
 
 import gdsfactory as gf
 from gdsfactory import components as pc
 from gdsfactory.component import Component
+from gdsfactory.types import LayerSpec
 
 
 @gf.cell
 def litho_steps(
-    line_widths: List[float] = (1.0, 2.0, 4.0, 8.0, 16.0),
+    line_widths: Tuple[float, ...] = (1.0, 2.0, 4.0, 8.0, 16.0),
     line_spacing: float = 10.0,
     height: float = 100.0,
-    layer: Tuple[int, int] = gf.LAYER.WG,
+    layer: LayerSpec = "WG",
 ) -> Component:
-    """Produces a positive + negative tone linewidth test, used for
-    lithography resolution test patterning
+    """Positive + negative tone linewidth test
+
+    used for lithography resolution test patterning
     adapted from phidl
 
     Args:
-        line_widths:
-        line_spacing:
-        height:
-        layer:
+        line_widths: in um.
+        line_spacing: in um.
+        height: in um.
+        layer: Specific layer to put the ruler geometry on.
 
     """
     D = gf.Component()
 
-    height = height / 2
+    height /= 2
     T1 = pc.text(
-        text="%s" % str(line_widths[-1]), size=height, justify="center", layer=layer
+        text=f"{str(line_widths[-1])}", size=height, justify="center", layer=layer
     )
+
     D.add_ref(T1).rotate(90).movex(-height / 10)
     R1 = pc.rectangle(size=(line_spacing, height), layer=layer)
     D.add_ref(R1).movey(-height)
@@ -44,4 +47,4 @@ def litho_steps(
 
 if __name__ == "__main__":
     c = litho_steps()
-    c.show()
+    c.show(show_ports=True)
