@@ -1,8 +1,9 @@
 import gdsfactory as gf
+from gdsfactory.cell import cell
 from gdsfactory.component import Component
 
 
-@gf.cell
+@cell
 def logo(text: str = "GDSFACTORY") -> Component:
     """Returns GDSfactory logo."""
     c = Component()
@@ -22,4 +23,4 @@ def logo(text: str = "GDSFACTORY") -> Component:
 
 if __name__ == "__main__":
     c = logo()
-    c.show()
+    c.show(show_ports=True)
