@@ -1,33 +1,30 @@
-from typing import Tuple
-
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.pad import pad as pad_function
 from gdsfactory.components.rectangle import rectangle
-from gdsfactory.tech import LAYER
-from gdsfactory.types import ComponentFactory
+from gdsfactory.types import ComponentSpec, LayerSpec
 
 
 @gf.cell
 def pads_shorted(
-    pad: ComponentFactory = pad_function,
+    pad: ComponentSpec = pad_function,
     columns: int = 8,
     pad_spacing: float = 150.0,
-    layer_metal: Tuple[int, int] = LAYER.M3,
+    layer_metal: LayerSpec = "M3",
     metal_width: float = 10,
 ) -> Component:
-    """Returns a 1D array of shorted_pads
+    """Returns a 1D array of shorted_pads.
 
     Args:
-        pad: pad function
-        columns: number of columns
-        pad_spacing:
-        layer_metal: for the short
-        metal_width: for the short
+        pad: pad spec.
+        columns: number of columns.
+        pad_spacing: in um
+        layer_metal: for the short.
+        metal_width: for the short.
 
     """
-    c = Component(name="shorted_pads")
-    pad = pad()
+    c = Component()
+    pad = gf.get_component(pad)
     for i in range(columns):
         pad_ref = c.add_ref(pad)
         pad_ref.movex(i * pad_spacing - columns / 2 * pad_spacing + pad_spacing / 2)
@@ -44,4 +41,4 @@ def pads_shorted(
 if __name__ == "__main__":
 
     c = pads_shorted(metal_width=20)
-    c.show()
+    c.show(show_ports=True)
