@@ -2,7 +2,7 @@ from typing import Optional
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.types import Layer
+from gdsfactory.types import LayerSpec
 
 
 @gf.cell
@@ -10,7 +10,7 @@ def ramp(
     length: float = 10.0,
     width1: float = 5.0,
     width2: Optional[float] = 8.0,
-    layer: Layer = (1, 0),
+    layer: LayerSpec = "WG",
 ) -> Component:
     """Return a ramp component. Based on phidl.
 
@@ -27,11 +27,19 @@ def ramp(
     ypts = [width1, width2, 0, 0]
     c = Component()
     c.add_polygon([xpts, ypts], layer=layer)
-    c.add_port(name="o1", midpoint=[0, width1 / 2], width=width1, orientation=180)
-    c.add_port(name="o2", midpoint=[length, width2 / 2], width=width2, orientation=0)
+    c.add_port(
+        name="o1", center=[0, width1 / 2], width=width1, orientation=180, layer=layer
+    )
+    c.add_port(
+        name="o2",
+        center=[length, width2 / 2],
+        width=width2,
+        orientation=0,
+        layer=layer,
+    )
     return c
 
 
 if __name__ == "__main__":
     c = ramp()
-    c.show()
+    c.show(show_ports=True)
