@@ -2,6 +2,7 @@ import gdsfactory as gf
 from gdsfactory.components.bend_euler import bend_euler
 from gdsfactory.components.coupler_ring import coupler_ring as _coupler_ring
 from gdsfactory.components.straight import straight as _straight
+from gdsfactory.types import ComponentSpec
 
 
 @gf.cell
@@ -10,26 +11,27 @@ def ring_single(
     radius: float = 10.0,
     length_x: float = 4.0,
     length_y: float = 0.6,
-    coupler_ring: gf.types.ComponentFactory = _coupler_ring,
-    straight: gf.types.ComponentFactory = _straight,
-    bend: gf.types.ComponentFactory = bend_euler,
-    cross_section: gf.types.CrossSectionFactory = gf.cross_section.strip,
+    coupler_ring: ComponentSpec = _coupler_ring,
+    straight: ComponentSpec = _straight,
+    bend: ComponentSpec = bend_euler,
+    cross_section: ComponentSpec = "strip",
     **kwargs
 ) -> gf.Component:
-    """Single bus ring made of a ring coupler (cb: bottom)
-    connected with two vertical straights (sl: left, sr: right)
+    """Returns a single ring.
+
+    ring coupler (cb: bottom) connects to two vertical straights (sl: left, sr: right),
     two bends (bl, br) and horizontal straight (wg: top)
 
     Args:
-        gap: gap between for coupler
-        radius: for the bend and coupler
-        length_x: ring coupler length
-        length_y: vertical straight length
-        coupler_ring: ring coupler function
-        straight: straight function
-        bend: 90 degrees bend function
-        cross_section:
-        **kwargs: cross_section settings
+        gap: gap between for coupler.
+        radius: for the bend and coupler.
+        length_x: ring coupler length.
+        length_y: vertical straight length.
+        coupler_ring: ring coupler spec.
+        straight: straight spec.
+        bend: 90 degrees bend spec.
+        cross_section: cross_section spec.
+        kwargs: cross_section settings.
 
 
     .. code::
@@ -45,33 +47,29 @@ def ring_single(
     """
     gf.snap.assert_on_2nm_grid(gap)
 
-    coupler_ring = gf.partial(
+    c = gf.Component()
+    cb = c << gf.get_component(
         coupler_ring,
         bend=bend,
+        straight=straight,
         gap=gap,
         radius=radius,
         length_x=length_x,
         cross_section=cross_section,
         **kwargs
     )
-
-    straight_side = gf.partial(
+    sy = gf.get_component(
         straight, length=length_y, cross_section=cross_section, **kwargs
     )
-    straight_top = gf.partial(
+    b = gf.get_component(bend, cross_section=cross_section, radius=radius, **kwargs)
+    sx = gf.get_component(
         straight, length=length_x, cross_section=cross_section, **kwargs
     )
-
-    bend = gf.partial(bend, radius=radius, cross_section=cross_section, **kwargs)
-
-    c = gf.Component()
-    cb = c << coupler_ring()
-    sl = c << straight_side()
-    sr = c << straight_side()
-    bl = c << bend()
-    br = c << bend()
-    st = c << straight_top()
-    # st.mirror(p1=(0, 0), p2=(1, 0))
+    sl = c << sy
+    sr = c << sy
+    bl = c << b
+    br = c << b
+    st = c << sx
 
     sl.connect(port="o1", destination=cb.ports["o2"])
     bl.connect(port="o2", destination=sl.ports["o2"])
@@ -88,12 +86,13 @@ def ring_single(
 
 if __name__ == "__main__":
     # c = ring_single(layer=(2, 0), cross_section_factory=gf.cross_section.pin, width=1)
+    # c = ring_single(width=2, gap=1, layer=(2, 0), radius=7, length_y=1)
+    # print(c.ports)
 
-    c = ring_single(width=2, gap=1, layer=(2, 0), radius=7, length_y=1)
-    print(c.ports)
-    c.show(show_subports=False)
+    c = gf.routing.add_fiber_array(ring_single)
+    c.show(show_ports=True)
 
     # cc = gf.add_pins(c)
     # print(c.settings)
     # print(c.settings)
-    # cc.show()
+    # cc.show(show_ports=True)
