@@ -1,24 +1,32 @@
-from typing import Dict, Tuple
+from typing import Dict, Optional, Tuple
 
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.ring_single import ring_single
-from gdsfactory.components.straight import straight
+from gdsfactory.components.straight import straight as straight_function
 from gdsfactory.types import ComponentFactory
 
+_list_of_dicts = (
+    dict(length_x=10.0, radius=5.0),
+    dict(length_x=20.0, radius=10.0),
+)
+
 
 @gf.cell
 def ring_single_array(
-    ring_function: ComponentFactory = ring_single,
-    straight_function: ComponentFactory = straight,
+    ring: ComponentFactory = ring_single,
+    straight: ComponentFactory = straight_function,
     spacing: float = 5.0,
-    list_of_dicts: Tuple[Dict[str, float], ...] = (
-        dict(length_x=10.0, radius=5.0),
-        dict(length_x=20.0, radius=10.0),
-    ),
+    list_of_dicts: Optional[Tuple[Dict[str, float], ...]] = None,
 ) -> Component:
     """Ring of single bus connected with straights.
 
+    Args:
+        ring: ring function.
+        straight: straight function.
+        spacing: between rings.
+        list_of_dicts: settings for each ring.
+
     .. code::
 
            ______               ______
@@ -30,15 +38,16 @@ def ring_single_array(
           length_x
 
     """
+    list_of_dicts = list_of_dicts or _list_of_dicts
     c = Component()
     settings0 = list_of_dicts[0]
-    ring1 = c << ring_function(**settings0)
+    ring1 = c << ring(**settings0)
 
     ring0 = ring1
-    wg = straight_function(length=spacing)
+    wg = straight(length=spacing)
 
     for settings in list_of_dicts[1:]:
-        ringi = c << ring_function(**settings)
+        ringi = c << ring(**settings)
         wgi = c << wg
         wgi.connect("o1", ring0.ports["o2"])
         ringi.connect("o1", wgi.ports["o2"])
@@ -51,4 +60,4 @@ def ring_single_array(
 
 if __name__ == "__main__":
     c = ring_single_array()
-    c.show()
+    c.show(show_ports=True)
