@@ -5,7 +5,7 @@ import picwriter.components as pc
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.waveguide_template import strip
-from gdsfactory.types import ComponentFactory, Layer
+from gdsfactory.types import ComponentSpec, LayerSpec
 
 
 @gf.cell
@@ -16,32 +16,35 @@ def spiral(
     parity: int = 1,
     port: Tuple[int, int] = (0, 0),
     direction: str = "WEST",
-    waveguide_template: ComponentFactory = strip,
-    layer: Layer = gf.LAYER.WG,
-    layer_cladding: Layer = gf.LAYER.WGCLAD,
+    waveguide_template: ComponentSpec = strip,
+    layer: LayerSpec = "WG",
+    layer_cladding: LayerSpec = "WGCLAD",
     cladding_offset: float = 3.0,
     wg_width: float = 0.5,
     radius: float = 10.0,
     **kwargs
 ) -> Component:
-    """Picwriter Spiral
+    """Spiral. Based on picwriter.
 
     Args:
-        port_spacing: distance between input/output ports
-        length: spiral length (um)
-        spacing: distance between parallel straights
-        parity: If 1 spiral on right side, if -1 spiral on left side (mirror flip)
-        port: Cartesian coordinate of the input port
-        direction: NORTH, WEST, SOUTH, EAST  or angle in radians
-        waveguide_template (WaveguideTemplate): Picwriter WaveguideTemplate function
-        layer: core layer
-        layer_cladding: cladding layer
-        cladding_offset: distance from core to cladding
-        wg_width: 0.5
-        radius: 10
-        kwargs: cross_section settings
+        port_spacing: distance between input/output ports.
+        length: spiral length (um).
+        spacing: distance between parallel straights.
+        parity: If 1 spiral on right side, if -1 spiral on left side (mirror flip).
+        port: Cartesian coordinate of the input port.
+        direction: NORTH, WEST, SOUTH, EAST  or angle in radians.
+        waveguide_template (WaveguideTemplate): Picwriter WaveguideTemplate function.
+        layer: core layer.
+        layer_cladding: cladding layer.
+        cladding_offset: distance from core to cladding.
+        wg_width: 0.5.
+        radius: 10.
+        kwargs: cross_section settings.
 
     """
+    layer = gf.get_layer(layer)
+    layer_cladding = gf.get_layer(layer_cladding)
+
     c = pc.Spiral(
         gf.call_if_func(
             waveguide_template,
@@ -65,4 +68,4 @@ def spiral(
 if __name__ == "__main__":
     c = spiral(length=10e3, port_spacing=500, radius=20, direction="NORTH")
     c = spiral(length=10e3, port_spacing=500, radius=20, direction="EAST")
-    c.show()
+    c.show(show_ports=True)
