@@ -8,6 +8,7 @@ from numpy import float64
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.snap import snap_to_grid
+from gdsfactory.types import LayerSpec
 
 
 def taper(
@@ -15,9 +16,10 @@ def taper(
     end_width: Union[float, float64],
     length: Union[float, float64],
     start_coord: Tuple[float64, float64],
-    layer: int = gf.LAYER.WG,
-    datatype: int = 0,
+    layer: LayerSpec = "WG",
 ) -> Tuple[Polygon, Tuple[float64, float64], Tuple[float64, float64]]:
+
+    layer = gf.get_layer(layer)
     s = start_coord
     top_left = (s[0], s[1] + start_width / 2.0)
     bot_left = (s[0], s[1] - start_width / 2.0)
@@ -25,7 +27,7 @@ def taper(
     bot_right = (s[0] + length, s[1] - end_width / 2.0)
     e = (s[0] + length, s[1])
     p = gds.Polygon(
-        [top_left, bot_left, bot_right, top_right], layer=layer, datatype=datatype
+        [top_left, bot_left, bot_right, top_right], layer=layer[0], datatype=layer[1]
     )
     return p, s, e
 
@@ -34,10 +36,10 @@ def straight(
     width: Union[float, float64],
     length: Union[float, float64],
     start_coord: Tuple[float64, float64],
-    layer: int = gf.LAYER.WG,
-    datatype: int = 0,
+    layer: LayerSpec = "WG",
 ) -> Tuple[Polygon, Tuple[float64, float64], Tuple[float64, float64]]:
-    t, s, e = taper(width, width, length, start_coord, layer=layer, datatype=datatype)
+    layer = gf.get_layer(layer)
+    t, s, e = taper(width, width, length, start_coord, layer=layer)
     return t, s, e
 
 
@@ -48,21 +50,19 @@ def spiral_circular(
     spacing: float = 3.0,
     min_bend_radius: float = 5.0,
     points: int = 1000,
-    layer: Tuple[int, int] = gf.LAYER.WG,
+    layer: LayerSpec = "WG",
 ) -> Component:
     """Returns a circular spiral.
 
-    FIXME, has some issues
-
     Args:
-        length: length in um
-        wg_width:
-        spacing: between straights
-        min_bend_radius:
-        points:
-        layer:
-
+        length: length in um.
+        wg_width: width.
+        spacing: between straights.
+        min_bend_radius: in um.
+        points: number of points.
+        layer: layer spec.
     """
+    layer = gf.get_layer(layer)
     wg_datatype = layer[1]
     wg_layer = layer[0]
 
@@ -86,52 +86,48 @@ def spiral_circular(
     theta_1 = np.linspace(360.0 * inner_revs, 360.0 * (revolutions - 1) + 270, points)
     theta_2 = np.linspace(360.0 * inner_revs, 360.0 * revolutions, points)
     a = np.sqrt(spacing / 180.0)
-    radii_1 = a ** 2 * theta_1
-    radii_2 = -(a ** 2) * theta_2
+    radii_1 = a**2 * theta_1
+    radii_2 = -(a**2) * theta_2
     x_1, y_1 = pol_to_rect(radii_1, theta_1)
     x_1 = np.append(x_1, x_1[-1] + 0.03)
     y_1 = np.append(y_1, y_1[-1])
 
-    p = gds.PolyPath(np.c_[x_1, y_1], wg_width, layer=wg_layer, datatype=wg_datatype)
-    ps.append(p)
     x_2, y_2 = pol_to_rect(radii_2, theta_2)
     x_2 = np.append(x_2, x_2[-1])
     y_2 = np.append(y_2, y_2[-1] - 0.03)
-    p = gds.PolyPath(np.c_[x_2, y_2], wg_width, layer=wg_layer, datatype=wg_datatype)
-    ps.append(p)
 
     start_1 = (x_1[-1], y_1[-1])
     start_2 = (x_2[-1], y_2[-1])
     end_1 = (x_1[0], y_1[0])
     end_2 = (x_2[0], y_2[0])
 
-    length_1 = np.sum(np.hypot(np.diff(x_1), np.diff(y_1)))
-    length_2 = np.sum(np.hypot(np.diff(x_2), np.diff(y_2)))
-
     # Inner bend
-    theta_inner = np.linspace(360.0 * inner_revs, 360.0 * inner_revs + 180.0, 50)
+    theta_inner = np.linspace(360.0 * inner_revs, 360.0 * inner_revs - 180.0, 50)
     radii_inner_1 = min_bend_radius
     radii_inner_2 = -min_bend_radius
-    x_1, y_1 = pol_to_rect(radii_inner_1, theta_inner)
-    x_1 -= end_1[0] / 2.0
-    y_1 -= end_1[1] / 2.0
-    x_1 = np.append(x_1, x_1[-1])
-    y_1 = np.append(y_1, y_1[-1] - 0.03)
-    p = gds.PolyPath(np.c_[x_1, y_1], wg_width, layer=wg_layer, datatype=wg_datatype)
-    ps.append(p)
-    x_2, y_2 = pol_to_rect(radii_inner_2, theta_inner)
-    x_2 -= end_2[0] / 2.0
-    y_2 -= end_2[1] / 2.0
-    x_2 = np.append(x_2, x_2[-1])
-    y_2 = np.append(y_2, y_2[-1] + 0.03)
-    p = gds.PolyPath(np.c_[x_2, y_2], wg_width, layer=wg_layer, datatype=wg_datatype)
-    ps.append(p)
-    length_3 = np.sum(np.hypot(np.diff(x_2), np.diff(y_2)))
+    x_inner_1, y_inner_1 = pol_to_rect(radii_inner_1, theta_inner)
+    x_inner_1 += end_1[0] / 2.0
+    y_inner_1 += end_1[1] / 2.0
+    x_inner_1 = np.append(x_inner_1, x_inner_1[-1])
+    y_inner_1 = np.append(y_inner_1, y_inner_1[-1])
+
+    x_inner_2, y_inner_2 = pol_to_rect(radii_inner_2, theta_inner)
+    x_inner_2 += end_2[0] / 2.0
+    y_inner_2 += end_2[1] / 2.0
+    x_inner_2 = np.append(x_inner_2, x_inner_2[-1])
+    y_inner_2 = np.append(y_inner_2, y_inner_2[-1])
+
+    # Spiral path
+    x_sp = np.concatenate([x_1[:0:-1], x_inner_1[:-1], x_inner_2[-2:0:-1], x_2])
+    y_sp = np.concatenate([y_1[:0:-1], y_inner_1[:-1], y_inner_2[-2:0:-1], y_2])
+
+    p_spiral = gds.PolyPath(
+        np.c_[x_sp, y_sp], wg_width, layer=wg_layer, datatype=wg_datatype
+    )
+    ps.append(p_spiral)
 
     # Output straight
-    p, _, e = straight(
-        wg_width, radii_1[-1], start_1, layer=wg_layer, datatype=wg_datatype
-    )
+    p, _, e = straight(wg_width, radii_1[-1], start_1, layer=layer)
     ps.append(p)
 
     # Outer bend
@@ -155,12 +151,11 @@ def spiral_circular(
         length,
         wg_width,
         (end_input[0] - wg_width / 2.0, end_input[1] + length / 2.0),
-        layer=wg_layer,
-        datatype=wg_datatype,
+        layer=layer,
     )
     ps.append(p)
 
-    length = length_1 + length_2 + length_3
+    length = np.sum(np.hypot(np.diff(x_sp), np.diff(y_sp)))
 
     # Electrode ring
     # inner_radius = min_bend_radius * 2.
@@ -169,22 +164,22 @@ def spiral_circular(
     # thickness = outer_radius - mid_radius
     # r = gds.Round((0.,0.), outer_radius, inner_radius, layer=1, max_points=1000)
 
-    ps = gds.fast_boolean(ps, None, "or")
+    ps = gds.boolean(ps, None, "or")
 
     c = gf.Component()
-    c.info.length = snap_to_grid(length)
+    c.info["length"] = snap_to_grid(length)
     c.add_polygon(ps, layer=layer)
 
     c.add_port(
         name="o1",
-        midpoint=(s[0], s[1]),
+        center=(s[0], s[1]),
         orientation=180,
         layer=layer,
         width=wg_width,
     )
     c.add_port(
         name="o2",
-        midpoint=(e[0], e[1]),
+        center=(e[0], e[1]),
         orientation=180,
         layer=layer,
         width=wg_width,
@@ -196,5 +191,5 @@ if __name__ == "__main__":
     c = spiral_circular(length=1e3)
     print(c.ports)
     print(c.ports.keys())
-    c.show()
+    c.show(show_ports=True)
     c.write_gds()
