@@ -6,28 +6,27 @@ import gdsfactory as gf
 from gdsfactory.components.bend_s import bend_s as bend_s_function
 from gdsfactory.components.mmi1x2 import mmi1x2
 from gdsfactory.components.mmi2x2 import mmi2x2
-from gdsfactory.cross_section import strip
-from gdsfactory.types import ComponentFactory, CrossSectionFactory, Float2
+from gdsfactory.types import ComponentSpec, CrossSectionSpec, Float2
 
 
 @gf.cell
 def splitter_tree(
-    coupler: ComponentFactory = mmi1x2,
+    coupler: ComponentSpec = mmi1x2,
     noutputs: int = 4,
     spacing: Float2 = (90.0, 50.0),
-    bend_s: Optional[ComponentFactory] = bend_s_function,
+    bend_s: Optional[ComponentSpec] = bend_s_function,
     bend_s_xsize: Optional[float] = None,
-    cross_section: CrossSectionFactory = strip,
+    cross_section: CrossSectionSpec = "strip",
 ) -> gf.Component:
     """Tree of power splitters.
 
     Args:
-        coupler: coupler factory
-        noutputs: number of outputs
-        spacing: x, y spacing between couplers
-        bend_s: Sbend function for termination
-        bend_s_xsize: xsize for the sbend
-        cross_section: cross_section
+        coupler: coupler factory.
+        noutputs: number of outputs.
+        spacing: x, y spacing between couplers.
+        bend_s: Sbend function for termination.
+        bend_s_xsize: xsize for the sbend.
+        cross_section: cross_section.
 
     .. code::
 
@@ -43,7 +42,7 @@ def splitter_tree(
 
     dx, dy = spacing
 
-    coupler = coupler()
+    coupler = gf.get_component(coupler)
     coupler_ports_west = coupler.get_ports_list(port_type="optical", orientation=180)
     coupler_ports_east = coupler.get_ports_list(port_type="optical", orientation=0)
 
@@ -53,21 +52,22 @@ def splitter_tree(
 
     if bend_s:
         dy_coupler_ports = abs(
-            coupler.ports[e0_port_name].midpoint[1]
-            - coupler.ports[e1_port_name].midpoint[1]
+            coupler.ports[e0_port_name].center[1]
+            - coupler.ports[e1_port_name].center[1]
         )
         bend_s_ysize = dy / 4 - dy_coupler_ports / 2
         bend_s_xsize = bend_s_xsize or dx
-        bend_s = bend_s(
+        bend_s = gf.get_component(
+            bend_s,
             cross_section=cross_section,
             size=(bend_s_xsize, bend_s_ysize),
         )
-        c.info.bend_s = bend_s.info
+        c.info["bend_s"] = bend_s.info
     cols = int(np.log2(noutputs))
     i = 0
 
     for col in range(cols):
-        ncouplers = int(2 ** col)
+        ncouplers = int(2**col)
         y0 = -0.5 * dy * 2 ** (cols - 1)
         for row in range(ncouplers):
             x = col * dx
@@ -80,11 +80,11 @@ def splitter_tree(
                     if port.name not in [e0_port_name, e1_port_name]:
                         c.add_port(name=f"{port.name}_{col}_{i}", port=port)
                         i += 1
-            if col > 0 and row % 2 == 0:
-                port_name = e0_port_name
-            if col > 0 and row % 2 == 1:
-                port_name = e1_port_name
             if col > 0:
+                if row % 2 == 0:
+                    port_name = e0_port_name
+                if row % 2 == 1:
+                    port_name = e1_port_name
                 c.add(
                     gf.routing.get_route(
                         c.aliases[f"coupler_{col-1}_{row//2}"].ports[port_name],
@@ -123,7 +123,7 @@ def splitter_tree(
     return c
 
 
-def test_splitter_tree_ports():
+def test_splitter_tree_ports() -> None:
     c = splitter_tree(
         coupler=mmi2x2,
         noutputs=4,
@@ -131,7 +131,7 @@ def test_splitter_tree_ports():
     assert len(c.ports) == 8, len(c.ports)
 
 
-def test_splitter_tree_ports_no_sbend():
+def test_splitter_tree_ports_no_sbend() -> None:
     c = splitter_tree(
         coupler=mmi2x2,
         noutputs=4,
@@ -150,17 +150,17 @@ if __name__ == "__main__":
         coupler=gf.partial(mmi2x2, gap_mmi=2.0, width_mmi=5.0),
         # noutputs=128 * 2,
         # noutputs=2 ** 3,
-        noutputs=2 ** 2,
+        noutputs=2**2,
         # bend_s=None,
         # dy=100.0,
         # layer=(2, 0),
     )
     c = splitter_tree(
-        noutputs=2 ** 2,
+        noutputs=2**2,
         # bend_length=30,
-        # bend_s=None,
+        bend_s=None,
     )
-    c.show()
+    c.show(show_ports=True)
     # print(len(c.ports))
     # for port in c.get_ports_list():
     #     print(port)
