@@ -1,14 +1,14 @@
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.straight import straight as straight_function
-from gdsfactory.types import ComponentOrFactory
+from gdsfactory.types import ComponentSpec
 
 
 @gf.cell
 def straight_array(
     n: int = 4,
     spacing: float = 4.0,
-    straigth: ComponentOrFactory = straight_function,
+    straight: ComponentSpec = straight_function,
     **kwargs
 ) -> Component:
     """Array of straights connected with grating couplers.
@@ -16,18 +16,18 @@ def straight_array(
     useful to align the 4 corners of the chip
 
     Args:
-        n: number of straights
-        spacing: edge to edge straight spacing
-        straigth: straigth straight Component or library
-        **kwargs
+        n: number of straights.
+        spacing: edge to edge straight spacing.
+        straight: straight straight Component or library.
+        kwargs: straight settings.
     """
 
     c = Component()
-    wg = straigth(**kwargs) if callable(straigth) else straigth
+    wg = gf.get_component(straight, **kwargs)
 
     for i in range(n):
         wref = c.add_ref(wg)
-        wref.y += i * (spacing + wg.info.width)
+        wref.y += i * (spacing + wg.info["width"])
         c.add_ports(wref.ports, prefix=str(i))
 
     c.auto_rename_ports()
@@ -36,5 +36,5 @@ def straight_array(
 
 if __name__ == "__main__":
     c = straight_array()
-    c.pprint_ports()
+    # c.pprint_ports()
     c.show(show_ports=True)
