@@ -35,4 +35,4 @@ switch_tree = gf.partial(splitter_tree, coupler=mzi, spacing=(500, 100))
 if __name__ == "__main__":
     # c = mzi()
     c = switch_tree(noutputs=16)
-    c.show()
+    c.show(show_ports=True)
