@@ -7,8 +7,7 @@ import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.text_rectangular import text_rectangular
 from gdsfactory.name import clean_name
-from gdsfactory.tech import LAYER
-from gdsfactory.types import Coordinate, Layer
+from gdsfactory.types import Coordinate, LayerSpec
 
 
 @gf.cell
@@ -17,16 +16,16 @@ def text(
     size: float = 10.0,
     position: Coordinate = (0, 0),
     justify: str = "left",
-    layer: Tuple[int, int] = LAYER.TEXT,
+    layer: LayerSpec = "WG",
 ) -> Component:
     """Text shapes.
 
     Args:
-        text:
-        size:
-        position:
-        justify: left, right, center
-        layer:
+        text: string.
+        size: in um.
+        position: x, y position.
+        justify: left, right, center.
+        layer: for the text.
 
     """
     scaling = size / 1000
@@ -47,7 +46,7 @@ def text(
                     label.add_polygon([xpts + xoffset, ypts + yoffset], layer=layer)
                 xoffset += (_width[ascii_val] + _indent[ascii_val]) * scaling
             else:
-                ValueError(f"[PHIDL] text(): No character with ascii value {ascii_val}")
+                raise ValueError(f"No character with ascii value {ascii_val!r}")
         ref = t.add_ref(label)
         t.absorb(ref)
         yoffset -= 1500 * scaling
@@ -66,39 +65,25 @@ def text(
 
 
 @gf.cell
-def githash(
-    text: Tuple[str, ...] = ("",),
+def text_lines(
+    text: Tuple[str, ...] = ("Chip", "01"),
     size: float = 0.4,
-    hash_length: int = 6,
-    layer: Layer = LAYER.WG,
+    layer: LayerSpec = "WG",
 ) -> Component:
-    """Returns the repo git hash
-    allows a list of text, that will print on separate lines
+    """Returns a Component from a text lines.
 
     Args:
-        text:
-        size:
-        hash_length:
-        layer:
+        text: list of strings.
+        size: text size.
+        layer: text layer.
 
     """
-    try:
-
-        git_hash = gf.CONFIG["repo"][:hash_length]
-        git_hash = f"gf_{git_hash}"
-    except Exception:
-        git_hash = f"gf_{gf.__version__}"
-
     c = gf.Component()
-    t = text_rectangular(text=git_hash, size=size, layer=layer)
-    tref = c.add_ref(t)
-    c.absorb(tref)
 
     for i, texti in enumerate(text):
         t = text_rectangular(text=texti, size=size, layer=layer)
         tref = c.add_ref(t)
         tref.movey(-6 * size * (i + 1))
-        c.absorb(tref)
     return c
 
 
@@ -109,5 +94,7 @@ if __name__ == "__main__":
         justify="right",
         position=(120.5, 3),
     )
-    # c = githash(text=["a", "b"], size=10)
-    c.show()
+    # c = text_lines(text=["a", "b"], size=10)
+    # c = text_lines()
+    c.show(show_ports=True)
+    c.plot()
