@@ -2,7 +2,7 @@ from typing import Optional, Tuple
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.tech import LAYER
+from gdsfactory.types import LayerSpec
 
 
 @gf.cell
@@ -10,19 +10,19 @@ def via(
     size: Tuple[float, float] = (0.7, 0.7),
     spacing: Tuple[float, float] = (2.0, 2.0),
     enclosure: float = 1.0,
-    layer: Tuple[int, int] = LAYER.VIAC,
-    layers_cladding: Optional[Tuple[Tuple[int, int], ...]] = None,
-    cladding_offset: float = 0,
+    layer: LayerSpec = "VIAC",
+    bbox_layers: Optional[Tuple[Tuple[int, int], ...]] = None,
+    bbox_offset: float = 0,
 ) -> Component:
     """Rectangular via. Defaults to a square via.
 
     Args:
-        size: in x, y direction
-        spacing: pitch_x, pitch_y
-        enclosure: inclusion of via
-        layer: via layer
-        layers_cladding:
-        cladding_offset
+        size: in x, y direction.
+        spacing: pitch_x, pitch_y.
+        enclosure: inclusion of via.
+        layer: via layer.
+        bbox_layers: layers for the bounding box.
+        bbox_offset: in um.
 
     .. code::
 
@@ -50,18 +50,18 @@ def via(
     b = height / 2
     c.add_polygon([(-a, -b), (a, -b), (a, b), (-a, b)], layer=layer)
 
-    layers_cladding = layers_cladding or []
-    a = (width + cladding_offset) / 2
-    b = (height + cladding_offset) / 2
-    for layer in layers_cladding:
+    bbox_layers = bbox_layers or []
+    a = (width + bbox_offset) / 2
+    b = (height + bbox_offset) / 2
+    for layer in bbox_layers:
         c.add_polygon([(-a, -b), (a, -b), (a, b), (-a, b)], layer=layer)
 
     return c
 
 
-viac = gf.partial(via, layer=LAYER.VIAC)
-via1 = gf.partial(via, layer=LAYER.VIA1, enclosure=2)
-via2 = gf.partial(via, layer=LAYER.VIA2)
+viac = gf.partial(via, layer="VIAC")
+via1 = gf.partial(via, layer="VIA1", enclosure=2)
+via2 = gf.partial(via, layer="VIA2")
 
 
 if __name__ == "__main__":
@@ -69,4 +69,4 @@ if __name__ == "__main__":
     c = via()
     # c.pprint()
     print(c)
-    c.show()
+    c.show(show_ports=True)
