@@ -4,24 +4,23 @@
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.components.straight import straight
-from gdsfactory.cross_section import metal3
-from gdsfactory.types import CrossSectionFactory
+from gdsfactory.types import CrossSectionSpec
 
-wire_straight = gf.partial(straight, with_cladding_box=False, cross_section=metal3)
+wire_straight = gf.partial(straight, cross_section="metal3")
 
 
 @gf.cell
-def wire_corner(cross_section: CrossSectionFactory = metal3, **kwargs) -> Component:
-    """90 degrees electrical corner
+def wire_corner(cross_section: CrossSectionSpec = "metal3", **kwargs) -> Component:
+    """Returns 90 degrees electrical corner wire.
 
     Args:
-        waveguide:
-        kwargs: cross_section settings
+        cross_section: spec.
+        kwargs: cross_section settings.
 
     """
-    x = cross_section(**kwargs)
-    layer = x.info["layer"]
-    width = x.info["width"]
+    x = gf.get_cross_section(cross_section, **kwargs)
+    layer = x.layer
+    width = x.width
 
     c = Component()
     a = width / 2
@@ -31,7 +30,7 @@ def wire_corner(cross_section: CrossSectionFactory = metal3, **kwargs) -> Compon
     c.add_polygon([xpts, ypts], layer=layer)
     c.add_port(
         name="e1",
-        midpoint=(-a, 0),
+        center=(-a, 0),
         width=width,
         orientation=180,
         layer=layer,
@@ -39,13 +38,13 @@ def wire_corner(cross_section: CrossSectionFactory = metal3, **kwargs) -> Compon
     )
     c.add_port(
         name="e2",
-        midpoint=(0, a),
+        center=(0, a),
         width=width,
         orientation=90,
         layer=layer,
         port_type="electrical",
     )
-    c.info.length = width
+    c.info["length"] = width
     return c
 
 
@@ -53,5 +52,8 @@ if __name__ == "__main__":
 
     # c = wire_straight()
     c = wire_corner()
-    c.show(show_ports=True)
-    c.pprint_ports()
+    # c.show(show_ports=True)
+    # c.pprint_ports()
+    c.pprint()
+
+    # print(yaml.dump(c.to_dict()))
