@@ -5,12 +5,12 @@ from gdsfactory.components.wire import wire_corner, wire_straight
 
 @gf.cell
 def wire_sbend(dx: float = 20.0, dy: float = 10.0, **kwargs) -> Component:
-    """Sbend corner with manhattan wires
+    """Sbend corner with manhattan wires.
 
     Args:
-        dx: length
-        dy: height
-        **kwargs: cross_section settings
+        dx: xsize.
+        dy: ysize.
+        kwargs: cross_section settings.
     """
     sx = wire_straight(length=dx / 2, **kwargs)
     sy = wire_straight(length=dy, **kwargs)
@@ -27,6 +27,7 @@ def wire_sbend(dx: float = 20.0, dy: float = 10.0, **kwargs) -> Component:
     c = gf.components.component_sequence(
         sequence=sequence, symbol_to_component=symbol_to_component
     )
+    c.unlock()
     c.auto_rename_ports()
     return c
 
