@@ -11,7 +11,8 @@ You can access the config dictionary with `print_config`
 
 """
 
-__version__ = "3.9.8"
+__version__ = "5.15.2"
+import io
 import json
 import os
 import pathlib
@@ -25,8 +26,8 @@ from typing import Any, Iterable, Optional, Union
 import omegaconf
 from loguru import logger
 from omegaconf import OmegaConf
-from phidl.quickplotter import set_quickplot_options
 
+from gdsfactory.quickplotter import set_quickplot_options
 from gdsfactory.tech import TECH
 
 PathType = Union[str, pathlib.Path]
@@ -48,14 +49,21 @@ dirpath_build = pathlib.Path(tempfile.TemporaryDirectory().name)
 dirpath_test = pathlib.Path(tempfile.TemporaryDirectory().name)
 MAX_NAME_LENGTH = 32
 
-logger.info(__version__)
+logger.info(f"Load {str(module_path)!r} {__version__}")
 logger.add(sink=logpath)
 
 
+default_config = io.StringIO(
+    """
+plotter: matplotlib
+sparameters_path: ${oc.env:HOME}/.gdsfactory/sparameters/generic
+"""
+)
+
+
 class Paths:
     module = module_path
     repo = repo_path
-    sparameters = repo_path / "sparameters"
     results_tidy3d = home / ".tidy3d"
     klayout = module / "klayout"
     klayout_tech = klayout / "tech"
@@ -65,8 +73,9 @@ class Paths:
 def read_config(
     yamlpaths: Iterable[PathType] = (yamlpath_default, yamlpath_home, yamlpath_cwd),
 ) -> omegaconf.DictConfig:
-    CONFIG = OmegaConf.create()
+    CONFIG = OmegaConf.load(default_config)
     for yamlpath in set(yamlpaths):
+        yamlpath = pathlib.Path(yamlpath)
         if os.access(yamlpath, os.R_OK) and yamlpath.exists():
             logger.info(f"loading tech config from {yamlpath}")
             CONFIG_NEW = OmegaConf.load(yamlpath)
@@ -106,7 +115,11 @@ else:
 
 # CONFIG["custom_components"] = TECH.custom_components
 CONFIG["gdslib"] = repo_path / "gdslib"
+CONFIG["gdsdiff"] = repo_path / "gdslib" / "gds"
+CONFIG["modes"] = repo_path / "gdslib" / "modes"
 CONFIG["sparameters"] = CONFIG["gdslib"] / "sp"
+sparameters_path = CONFIG["sparameters"]
+CONFIG["interconnect"] = CONFIG["gdslib"] / "interconnect"
 
 CONFIG["build_directory"] = build_directory
 CONFIG["gds_directory"] = build_directory / "devices"
@@ -114,11 +127,13 @@ CONFIG["cache_directory"] = CONF.get("cache", build_directory / "cache")
 CONFIG["cache_doe_directory"] = build_directory / "cache_doe"
 CONFIG["doe_directory"] = build_directory / "sweep"
 CONFIG["mask_directory"] = build_directory / "mask"
-CONFIG["mask_gds"] = build_directory / "mask" / (mask_name + ".gds")
+CONFIG["mask_gds"] = build_directory / "mask" / f"{mask_name}.gds"
 CONFIG["mask_config_directory"] = mask_config_directory
 CONFIG["samples_path"] = module_path / "samples"
 CONFIG["netlists"] = module_path / "samples" / "netlists"
 CONFIG["components_path"] = module_path / "components"
+CONFIG["schemas"] = module_path / "schemas"
+CONFIG["schema_netlist"] = module_path / "schemas" / "netlist.json"
 
 if "gds_resources" in CONFIG:
     CONFIG["gds_resources"] = CONFIG["masks_path"] / CONFIG["gds_resources"]
@@ -191,7 +206,7 @@ def set_plot_options(
     new_window: bool = False,
     blocking: bool = False,
     zoom_factor: float = 1.4,
-):
+) -> None:
     """Set plot options for matplotlib"""
     set_quickplot_options(
         show_ports=show_ports,
@@ -203,12 +218,16 @@ def set_plot_options(
     )
 
 
+__all__ = ["logger", "PATH", "CONFIG", "get_git_hash", "write_tech"]
+
+
 if __name__ == "__main__":
     # print(TECH.layer.WG)
     # print(TECH)
     # print_config("gdslib")
     # print(CONFIG["git_hash"])
     # print(CONFIG["sparameters"])
-    print(CONFIG)
+    # print(CONFIG)
+    print(CONF["sparameters_path"])
     # print_config()
     # write_tech("tech.json")
