@@ -28,7 +28,7 @@ def cleandir(request: SubRequest) -> None:
 @pytest.fixture(scope="session")
 def show_diffs(request: SubRequest) -> None:
     c = gf.read.from_gdspaths(diff_path.glob("*.gds"))
-    c.show()
+    c.show(show_ports=True)
 
 
 collect_ignore = ["difftest.py"]
