@@ -1,41 +1,40 @@
-from typing import Tuple
+from typing import Tuple, Union
 
 import numpy as np
-from numpy import float64
 
 
 class Coord2:
-    def __init__(self, x: float64, y: float64) -> None:
+    def __init__(self, x: float, y: float) -> None:
         self.point = np.array([x, y])
 
-    def __getitem__(self, i: int) -> float64:
+    def __getitem__(self, i: int) -> float:
         return self.point[i]
 
     @property
-    def x(self) -> float64:
+    def x(self) -> float:
         return self.point[0]
 
     @property
-    def y(self) -> float64:
+    def y(self) -> float:
         return self.point[1]
 
     @property
-    def xy(self) -> Tuple[float64, float64]:
+    def xy(self) -> Tuple[float, float]:
         return self.x, self.y
 
-    def __add__(self, c2):
+    def __add__(self, c2: Union[Tuple[float, float], "Coord2"]) -> "Coord2":
         return Coord2(self[0] + c2[0], self[1] + c2[1])
 
-    def __mul__(self, a):
+    def __mul__(self, a: float) -> "Coord2":
         return Coord2(self[0] * a, self[1] * a)
 
-    def __rmul__(self, a):
+    def __rmul__(self, a: float) -> "Coord2":
         return Coord2(self[0] * a, self[1] * a)
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"Coord2({self[0]}, {self[1]})"
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"Coord2({self[0]}, {self[1]})"
 
 
