@@ -1,12 +1,8 @@
 import pathlib
 from typing import Optional, Tuple
 
-import matplotlib.colors
-import shapely
-from trimesh.creation import extrude_polygon
-
 from gdsfactory.component import Component
-from gdsfactory.layers import LayerSet
+from gdsfactory.layers import LayerColors
 from gdsfactory.tech import LAYER_STACK, LayerStack
 from gdsfactory.types import Layer
 
@@ -14,20 +10,24 @@ from gdsfactory.types import Layer
 def to_stl(
     component: Component,
     filepath: str,
-    layer_set: LayerSet,
+    layer_colors: LayerColors,
     layer_stack: LayerStack = LAYER_STACK,
     exclude_layers: Optional[Tuple[Layer, ...]] = None,
 ) -> None:
     """Exports a Component into STL.
 
     Args:
-        component:
-        filepath:
-        layer_set: layer colors from Klayout Layer Properties file
-        layer_stack: contains thickness and zmin for each layer
-        exclude_layers: layers to exclude
+        component: to export.
+        filepath: to write STL to.
+        layer_colors: layer colors from Klayout Layer Properties file.
+        layer_stack: contains thickness and zmin for each layer.
+        exclude_layers: layers to exclude.
 
     """
+    import matplotlib.colors
+    import shapely
+    from trimesh.creation import extrude_polygon
+
     layer_to_thickness = layer_stack.get_layer_to_thickness()
     layer_to_zmin = layer_stack.get_layer_to_zmin()
     filepath = pathlib.Path(filepath)
@@ -41,7 +41,7 @@ def to_stl(
         ):
             height = layer_to_thickness[layer]
             zmin = layer_to_zmin[layer]
-            color_hex = layer_set.get_from_tuple(layer).color
+            color_hex = layer_colors.get_from_tuple(layer).color
             color_rgb = matplotlib.colors.to_rgb(color_hex)
             filepath_layer = (
                 filepath.parent
@@ -61,4 +61,4 @@ if __name__ == "__main__":
     import gdsfactory as gf
 
     c = gf.components.taper_strip_to_ridge()
-    to_stl(c, layer_set=gf.layers.LAYER_SET, filepath="a.stl")
+    to_stl(c, layer_colors=gf.layers.LAYER_COLORS, filepath="a.stl")
