@@ -13,19 +13,20 @@ def xor_diff(A, B, precision: float = 1e-4) -> Component:
     gdsfactory wrapper for phidl.geometry.xor_diff
 
     Args:
-        A: Component(/Reference) or list of Component(/References)
-        B: Component(/Reference) or list of Component(/References)
+        A: Component(/Reference) or list of Component(/References).
+        B: Component(/Reference) or list of Component(/References).
         precision: Desired precision for rounding vertex coordinates.
 
     Returns
         Component: containing a polygon(s) defined by the XOR difference result
         between A and B.
     """
-    return gf.read.from_phidl(component=pg.xor_diff(A, B, precision=precision))
+    phidl_component = pg.xor_diff(A, B, precision=precision)
+    return gf.read.from_phidl(phidl_component)
 
 
 if __name__ == "__main__":
     e1 = gf.components.ellipse(radii=(6, 6))
     e2 = gf.components.ellipse(radii=(10, 4))
     c = xor_diff(A=e1, B=e2)
-    c.show()
+    c.show(show_ports=True)
