@@ -15,30 +15,34 @@ Assumes two ports are connected when they have same width, x, y
 
 """
 
-from typing import Tuple
+from typing import Callable, Dict
 
 import omegaconf
 
 from gdsfactory.component import Component, ComponentReference
 from gdsfactory.name import clean_name
+from gdsfactory.pdk import get_layer
+from gdsfactory.serialization import clean_value_json
 from gdsfactory.snap import snap_to_grid
-from gdsfactory.tech import LAYER
+from gdsfactory.types import LayerSpec
 
 
 def get_instance_name(
     component: Component,
     reference: ComponentReference,
-    layer_label: Tuple[int, int] = LAYER.LABEL_INSTANCE,
+    layer_label: LayerSpec = "LABEL_INSTANCE",
 ) -> str:
     """Returns the instance name from the label.
     If no label returns to instanceName_x_y
 
     Args:
-        component: with labels
-        reference: reference that needs naming
-        layer_label: ignores layer_label[1]
+        component: with labels.
+        reference: reference that needs naming.
+        layer_label: ignores layer_label[1].
     """
 
+    layer_label = get_layer(layer_label)
+
     x = snap_to_grid(reference.x)
     y = snap_to_grid(reference.y)
     labels = component.labels
@@ -63,30 +67,30 @@ def get_instance_name(
 def get_netlist(
     component: Component,
     full_settings: bool = False,
-    layer_label: Tuple[int, int] = LAYER.LABEL_INSTANCE,
+    layer_label: LayerSpec = "LABEL_INSTANCE",
     tolerance: int = 1,
 ) -> omegaconf.DictConfig:
     """From a component returns instances, connections and placements dict. It
     assumes that ports with same width, x, y are connected.
 
      Args:
-         component: to Extract netlist
-         full_settings: True returns all settings, false only the ones that have changed
-         layer_label: label to read instanceNames from (if any)
-         tolerance: tolerance in nm to consider two ports the same
+         component: to extract netlist.
+         full_settings: True returns all, false changed settings.
+         layer_label: label to read instanceNames from (if any).
+         tolerance: tolerance in nm to consider two ports connected.
 
      Returns:
-         connections: Dict of Instance1Name,portName: Instace2Name,portName
-         instances: Dict of instances and settings
-         placements: Dict of instances and placements (x, y, rotation)
-         port: Dict portName: CompoentName,port
-         name: name of component
-
+         instances: Dict of instance name and settings.
+         connections: Dict of Instance1Name,portName: Instace2Name,portName.
+         placements: Dict of instance names and placements (x, y, rotation).
+         port: Dict portName: ComponentName,port.
+         name: name of component.
     """
     placements = {}
     instances = {}
     connections = {}
     top_ports = {}
+    layer_label = get_layer(layer_label)
 
     for reference in component.references:
         c = reference.parent
@@ -97,18 +101,27 @@ def get_netlist(
             component, reference, layer_label=layer_label
         )
 
-        settings = (
-            c.info.get("full", {}) if full_settings else c.info.get("changed", {})
-        )
-        instances[reference_name] = dict(
-            component=getattr(c.info, "function_name", c.name),
-            settings=settings,
-        )
+        instance = {}
+
+        if c.info:
+            instance.update(component=c.name, info=clean_value_json(c.info))
+
+        # Prefer name from settings over c.name
+        if c.settings:
+            settings = c.settings.full if full_settings else c.settings.changed
+
+            instance.update(
+                component=getattr(c.settings, "function_name", c.name),
+                settings=clean_value_json(settings),
+            )
+
+        instances[reference_name] = instance
+
         placements[reference_name] = dict(
             x=x,
             y=y,
-            rotation=int(reference.rotation),
-            mirror=reference.x_reflection,
+            rotation=int(reference.rotation or 0),
+            mirror=reference.x_reflection or 0,
         )
 
     # store where ports are located
@@ -137,8 +150,8 @@ def get_netlist(
     # build connectivity port_locations = Dict[Tuple(x,y,width), set of portNames]
     for name, port in name2port.items():
         xyw = tuple(
-            round(1000 * v)
-            for v in snap_to_grid((port.x, port.y, port.width), nm=tolerance)
+            round(1000 * snap_to_grid(v, nm=tolerance))
+            for v in (port.x, port.y, port.width)
         )
         if xyw not in port_locations:
             port_locations[xyw] = set()
@@ -176,14 +189,60 @@ def get_netlist(
     )
 
 
-def demo_ring_single_array() -> None:
+def get_netlist_recursive(
+    component: Component,
+    component_suffix: str = ".ba",
+    get_netlist_func: Callable = get_netlist,
+    **kwargs,
+) -> Dict[str, omegaconf.DictConfig]:
+    """Returns recursive netlist for a component and subcomponents.
+
+    Args:
+        component: to extract netlist.
+        component_suffix: suffix to append to each component name.
+            useful if to save and reload a back-annotated netlist.
+        get_netlist_func: function to extract individual netlists.
+
+    Keyword Args:
+        full_settings: True returns all, false changed settings.
+        layer_label: label to read instanceNames from (if any).
+        tolerance: tolerance in nm to consider two ports connected.
+
+    Returns:
+        Dictionary of netlists, keyed by the name of each component.
+    """
+    all_netlists = {}
+
+    # only components with references (subcomponents) warrant a netlist
+    if component.references:
+        netlist = get_netlist_func(component, **kwargs)
+        all_netlists[f"{component.name}{component_suffix}"] = netlist
+
+        # for each reference, expand the netlist
+        for ref in component.references:
+            rcell = ref.parent
+            grandchildren = get_netlist_recursive(rcell)
+            all_netlists.update(grandchildren)
+            if ref.ref_cell.references:
+                inst_name = get_instance_name(component, ref)
+                netlist_dict = {"component": f"{rcell.name}{component_suffix}"}
+                if hasattr(rcell, "settings") and hasattr(rcell.settings, "full"):
+                    netlist_dict.update(settings=rcell.settings.full)
+                if hasattr(rcell, "info"):
+                    netlist_dict.update(info=rcell.info)
+                netlist["instances"][inst_name] = netlist_dict
+
+    return all_netlists
+
+
+def _demo_ring_single_array() -> None:
     import gdsfactory as gf
 
     c = gf.components.ring_single_array()
     c.get_netlist()
 
 
-def demo_mzi_lattice() -> None:
+def _demo_mzi_lattice() -> None:
     import gdsfactory as gf
 
     coupler_lengths = [10, 20, 30, 40]
@@ -200,19 +259,30 @@ def demo_mzi_lattice() -> None:
 
 
 if __name__ == "__main__":
-    from pprint import pprint
+    # from pprint import pprint
+    # from omegaconf import OmegaConf
+    # import gdsfactory as gf
+    # from gdsfactory.tests.test_component_from_yaml import sample_2x2_connections
 
-    from omegaconf import OmegaConf
+    # c = gf.read.from_yaml(sample_2x2_connections)
+    # c = gf.components.ring_single()
+    # c.show(show_ports=True)
+    # pprint(c.get_netlist())
+
+    # n = c.get_netlist()
+    # yaml_str = OmegaConf.to_yaml(n, sort_keys=True)
+    # c2 = gf.read.from_yaml(yaml_str)
+    # gf.show(c2)
 
     import gdsfactory as gf
-    from gdsfactory.tests.test_component_from_yaml import sample_2x2_connections
 
-    c = gf.read.from_yaml(sample_2x2_connections)
-    c = gf.components.ring_single()
-    c.show()
-    pprint(c.get_netlist())
+    coupler_lengths = [10, 20, 30, 40]
+    coupler_gaps = [0.1, 0.2, 0.4, 0.5]
+    delta_lengths = [10, 100, 200]
 
-    n = c.get_netlist()
-    yaml_str = OmegaConf.to_yaml(n, sort_keys=True)
-    c2 = gf.read.from_yaml(yaml_str)
-    gf.show(c2)
+    c = gf.components.mzi_lattice(
+        coupler_lengths=coupler_lengths,
+        coupler_gaps=coupler_gaps,
+        delta_lengths=delta_lengths,
+    )
+    n = c.get_netlist_recursive()
