@@ -9,25 +9,16 @@ import click
 from click.core import Context, Option
 
 import gdsfactory
-import gdsfactory.build as pb
-from gdsfactory.config import CONFIG, print_config
+from gdsfactory.config import CONFIG, cwd, print_config
 from gdsfactory.gdsdiff.gdsdiff import gdsdiff
-from gdsfactory.install import install_gdsdiff, install_generic_tech, install_klive
+from gdsfactory.install import install_gdsdiff, install_klayout_package
 from gdsfactory.layers import lyp_to_dataclass
-from gdsfactory.mask.merge_json import merge_json
-from gdsfactory.mask.merge_markdown import merge_markdown
-from gdsfactory.mask.merge_test_metadata import merge_test_metadata
-from gdsfactory.mask.write_labels import write_labels
-
-# from gdsfactory.write_doe_from_yaml import write_doe_from_yaml
-from gdsfactory.sweep.write_sweep_from_yaml import import_custom_doe_factories
 from gdsfactory.tech import LAYER
 from gdsfactory.types import PathType
 from gdsfactory.write_cells import write_cells as write_cells_to_separate_gds
 
-VERSION = "3.9.8"
+VERSION = "5.15.2"
 log_directory = CONFIG.get("log_directory")
-cwd = pathlib.Path.cwd()
 LAYER_LABEL = LAYER.LABEL
 
 
@@ -47,7 +38,7 @@ def log_delete(logfile: str) -> None:
         print("No logs found.")
         return
 
-    filename = os.path.join(log_directory, "{}.log".format(logfile))
+    filename = os.path.join(log_directory, f"{logfile}.log")
     subprocess.check_output(["rm", filename])
 
 
@@ -92,87 +83,63 @@ def layermap_to_dataclass(filepath, force: bool) -> None:
 
 @click.command(name="write_cells")
 @click.argument("gdspath")
-def write_cells(gdspath) -> None:
+@click.argument("dirpath", required=False, default=None)
+def write_cells(gdspath, dirpath) -> None:
     """Write each all level cells into separate GDS files."""
-    write_cells_to_separate_gds(gdspath)
+    write_cells_to_separate_gds(gdspath=gdspath, dirpath=dirpath)
 
 
-@click.command(name="merge_gds_from_directory")
+@click.command(name="merge_gds")
 @click.argument("dirpath", required=False, default=None)
 @click.argument("gdspath", required=False, default=None)
-def merge_gds_from_directory(
+def merge_gds(
     dirpath: Optional[PathType] = None, gdspath: Optional[PathType] = None
 ) -> None:
     """Merges GDS cells from a directory into a single GDS."""
     dirpath = dirpath or pathlib.Path.cwd()
     gdspath = gdspath or pathlib.Path.cwd() / "merged.gds"
-    c = gdsfactory.read.gdsdir(dirpath=dirpath)
+
+    dirpath = pathlib.Path(dirpath)
+
+    c = gdsfactory.read.from_gdsdir(dirpath=dirpath)
     c.write_gds(gdspath=gdspath)
-    c.show()
+    c.show(show_ports=True)
 
 
-# MASKS
+# netlist driven flow in YAML
 
 
 @click.group()
-def mask() -> None:
-    """Commands for building masks"""
+def yaml() -> None:
+    """define components/circuits/masks in YAML"""
     pass
 
 
-@click.command(name="clean")
-@click.option("--force", "-f", default=False, help="Force deletion", is_flag=True)
-def build_clean(force: bool) -> None:
-    """Deletes the build folder and contents"""
-    message = "Delete {}. Are you sure?".format(CONFIG["build_directory"])
-    if force or click.confirm(message, default=True):
-        pb.build_clean()
+# @click.option("--debug", "-d", default=False, help="debug", is_flag=True)
+# @click.command()
+# def webapp(debug: bool = False) -> None:
+#     """Opens YAML based webapp."""
+#     from gdsfactory.icyaml import app
+
+#     if debug:
+#         app.run_debug()
+
+#     else:
+#         app.run()
 
 
-@click.command(name="build_devices")
-@click.argument("regex", required=False, default=".*")
-def build_devices(regex) -> None:
-    """Build all devices described in devices/"""
-    pb.build_devices(regex)
+@click.argument("path", type=click.Path(exists=True), required=False, default=cwd)
+@click.command()
+def watch(path=cwd) -> None:
+    """Filewatch YAML file."""
+    from gdsfactory.watch import watch
 
-
-@click.command(name="build_does")
-@click.argument("yamlpath")
-def build_does(yamlpath: str) -> None:
-    """Build does defined in sweep.yml"""
-    print("this is deprecated")
-    import_custom_doe_factories()
-    # write_doe_from_yaml()
-    pb.build_does(yamlpath)
-
-
-@click.command(name="write_metadata")
-@click.argument("label_layer", required=False, default=LAYER_LABEL)
-def mask_merge(label_layer) -> None:
-    """merge JSON/Markdown from build/devices into build/mask"""
-
-    gdspath = CONFIG["mask_gds"]
-    write_labels(gdspath=gdspath, label_layer=label_layer)
-
-    merge_json()
-    merge_markdown()
-    merge_test_metadata(gdspath=gdspath)
-
-
-@click.command(name="write_labels")
-@click.argument("gdspath", default=None)
-@click.argument("label_layer", required=False, default=LAYER_LABEL)
-def write_mask_labels(gdspath: str, label_layer) -> None:
-    """Find test and measurement labels."""
-    if gdspath is None:
-        gdspath = CONFIG["mask_gds"]
-
-    write_labels(gdspath=gdspath, label_layer=label_layer)
+    path = pathlib.Path(path)
+    path = path.parent if path.is_dir() else path
+    watch(str(path))
 
 
 # EXTRA
-
-
 @click.command()
 @click.argument("filename")
 def show(filename: str) -> None:
@@ -186,20 +153,19 @@ def show(filename: str) -> None:
 @click.option("--xor", "-x", default=False, help="include xor", is_flag=True)
 def diff(gdspath1: str, gdspath2: str, xor: bool = False) -> None:
     """Show boolean difference between two GDS files."""
-    diff = gdsdiff(str(gdspath1), str(gdspath2), xor=xor)
+    diff = gdsdiff(gdspath1, gdspath2, xor=xor)
     diff.show()
 
 
 @click.command()
 def install() -> None:
     """Install Klive and generic tech layermap."""
-    install_generic_tech()
-    install_klive()
+    install_klayout_package()
     install_gdsdiff()
 
 
-@click.command()
-def test() -> None:
+@click.command(name="test")
+def run_tests() -> None:
     """Run tests using pytest.
     You can also just run `pytest` directly."""
 
@@ -217,32 +183,26 @@ def test() -> None:
     is_eager=True,
     help="Show the version number.",
 )
-def gf():
-    """`gf` is the command line tool for gdsfactory.
-    It helps you work with GDS files.
-    """
-    pass
+def gf() -> None:
+    """`gf` is the gdsfactory command line tool."""
 
 
-mask.add_command(build_clean)
-mask.add_command(build_devices)
-mask.add_command(build_does)
-mask.add_command(mask_merge)
-mask.add_command(write_mask_labels)
-
 gds.add_command(layermap_to_dataclass)
 gds.add_command(write_cells)
-gds.add_command(merge_gds_from_directory)
+gds.add_command(merge_gds)
 gds.add_command(show)
 gds.add_command(diff)
 
 tool.add_command(config_get)
-tool.add_command(test)
+tool.add_command(run_tests)
 tool.add_command(install)
 
+# yaml.add_command(webapp)
+yaml.add_command(watch)
+
 gf.add_command(gds)
 gf.add_command(tool)
-gf.add_command(mask)
+gf.add_command(yaml)
 
 
 if __name__ == "__main__":
