@@ -1,4 +1,3 @@
-import dataclasses
 import os
 from glob import glob
 from pathlib import Path
@@ -18,7 +17,7 @@ def merge_markdown(
     """
     logger.info("Merging Markdown files:")
     configpath = mdpath.with_suffix(".yml")
-    tech = dataclasses.asdict(TECH)
+    tech = dict(TECH)
     tech.pop("library", "")
 
     with open(configpath, "w") as f:
@@ -28,7 +27,7 @@ def merge_markdown(
 
     with open(mdpath, "w") as f:
 
-        def wl(line="", eol="\n"):
+        def wl(line="", eol="\n") -> None:
             f.write(line + eol)
 
         reports = sorted(glob(os.path.join(reports_directory, "*.md")))
