@@ -5,8 +5,10 @@ dn_dt_si = 1.87e-4
 dn_dt_sio2 = 8.5e-6
 
 
-def delta_temperature_pi(length: float, wavelength: float = 1.55, dndT=1.8e-4):
-    return wavelength / (2 * length * dndT)
+def delta_temperature_pi(
+    length: float, wavelength: float = 1.55, dndT: float = 1.8e-4
+) -> float:
+    return wavelength / (2.0 * length * dndT)
 
 
 if __name__ == "__main__":
