@@ -1,6 +1,5 @@
 """
-For port naming we follow start from the bottom left and name the ports
-counter-clock-wise
+we follow start from the bottom left and name the ports counter-clock-wise
 
 .. code::
 
@@ -13,7 +12,7 @@ counter-clock-wise
          8   7
 
 
-You can also rename them W,E,S,N prefix (west, east, south, north)
+You can also rename them with W,E,S,N prefix (west, east, south, north).
 
     .. code::
 
@@ -27,21 +26,38 @@ You can also rename them W,E,S,N prefix (west, east, south, north)
 
 
 """
+from __future__ import annotations
+
 import csv
 import functools
+import typing
+import warnings
 from copy import deepcopy
 from functools import partial
-from typing import Callable, Dict, List, Optional, Tuple
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 import numpy as np
 import phidl.geometry as pg
 from numpy import ndarray
-from phidl.device_layout import Device
-from phidl.device_layout import Port as PortPhidl
+from omegaconf import OmegaConf
+from phidl.device_layout import _rotate_points
 
+from gdsfactory.cross_section import CrossSection
+from gdsfactory.serialization import clean_value_json
 from gdsfactory.snap import snap_to_grid
 
+if typing.TYPE_CHECKING:
+    from gdsfactory.component import Component
+
 Layer = Tuple[int, int]
+Layers = Tuple[Layer, ...]
+LayerSpec = Union[Layer, int, str, None]
+LayerSpecs = Tuple[LayerSpec, ...]
+Float2 = Tuple[float, float]
+
+midpoint_deprecation = "Port.midpoint is deprecated. Find and replace 'midpoint' by 'center' in all your code."
+# position_deprecation = "Port.position is deprecated. Change to Port.center to continue using it in the future."
+# angle_deprecation = "Port.angle is deprecated. Change to Port.orientation to continue using it in the future."
 
 
 class PortNotOnGridError(ValueError):
@@ -56,51 +72,115 @@ class PortOrientationError(ValueError):
     pass
 
 
-class Port(PortPhidl):
+class Port:
     """Ports are useful to connect Components with each other.
-    Extends phidl port with layer
+    Extends phidl port with layer and cross_section
 
     Args:
-        name: we name ports according to orientation starting from bottom, left
-        midpoint: (0, 0)
-        width: of the port
-        orientation: in degrees (0: east, 90: north, 180: west, 270: south)
-        parent: parent component (component to which this port belong to)
-        layer: (1, 0)
-        port_type: str (optical, electrical, vertical_te, vertical_tm)
-
+        name: we name ports clock-wise starting from bottom left.
+        center: (x, y) port center coordinate.
+        width: of the port in um.
+        orientation: in degrees (0: east, 90: north, 180: west, 270: south).
+        parent: parent component (component to which this port belong to).
+        layer: layer tuple.
+        port_type: str (optical, electrical, vertical_te, vertical_tm).
+        parent: Component that port belongs to.
+        cross_section: cross_section spec.
+        shear_angle: an optional angle to shear port face in degrees.
     """
 
     _next_uid = 0
 
     def __init__(
         self,
-        name: Optional[str] = None,
-        midpoint: Tuple[float, float] = (0.0, 0.0),
-        width: float = 0.5,
-        orientation: int = 0,
-        layer: Tuple[int, int] = (1, 0),
+        name: str,
+        orientation: Optional[float],
+        center: Optional[Tuple[float, float]] = None,
+        midpoint: Optional[Tuple[float, float]] = None,
+        width: Optional[float] = None,
+        layer: Optional[Tuple[int, int]] = None,
         port_type: str = "optical",
-        parent: Optional[object] = None,
-        cross_section: Optional[object] = None,
+        parent: Optional[Component] = None,
+        cross_section: Optional[CrossSection] = None,
+        shear_angle: Optional[float] = None,
     ) -> None:
+
+        if midpoint:
+            warnings.warn(midpoint_deprecation, DeprecationWarning, stacklevel=2)
+            center = midpoint
+        if midpoint is None and center is None:
+            raise ValueError("You need to define port center.")
+
         self.name = name
-        self.midpoint = np.array(midpoint, dtype="float64")
-        self.width = width
-        self.orientation = np.mod(orientation, 360)
+        self.center = np.array(center, dtype="float64")
+        self.orientation = np.mod(orientation, 360) if orientation else orientation
         self.parent = parent
-        self.info = {}
+        self.info: Dict[str, Any] = {}
         self.uid = Port._next_uid
-        self.layer = layer
         self.port_type = port_type
         self.cross_section = cross_section
+        self.shear_angle = shear_angle
+
+        if cross_section is None and layer is None:
+            raise ValueError("You need Port to define cross_section or layer")
+
+        if cross_section is None and width is None:
+            raise ValueError("You need Port to define cross_section or width")
+
+        if layer is None:
+            layer = cross_section.layer
+
+        if width is None:
+            width = cross_section.width
+
+        self.layer = layer
+        self.width = width
 
         if self.width < 0:
-            raise ValueError("[PHIDL] Port creation error: width must be >=0")
+            raise ValueError(f"Port width must be >=0. Got {self.width}")
         Port._next_uid += 1
 
+    @property
+    def midpoint(self) -> Float2:
+        warnings.warn(midpoint_deprecation, DeprecationWarning, stacklevel=2)
+        return self.center
+
+    @midpoint.setter
+    def midpoint(self, value: Float2):
+        warnings.warn(midpoint_deprecation, DeprecationWarning, stacklevel=2)
+        self.center = value
+
+    def to_dict(self) -> Dict[str, Any]:
+        d = dict(
+            name=self.name,
+            width=self.width,
+            center=tuple(np.round(self.center, 3)),
+            orientation=int(self.orientation) if self.orientation else self.orientation,
+            layer=self.layer,
+            port_type=self.port_type,
+        )
+        if self.shear_angle:
+            d["shear_angle"] = self.shear_angle
+        return clean_value_json(d)
+
+    def to_yaml(self) -> str:
+        d = dict(
+            name=self.name,
+            width=float(self.width),
+            center=[float(self.center[0]), float(self.center[1])],
+            orientation=float(self.orientation)
+            if self.orientation
+            else self.orientation,
+            layer=self.layer,
+            port_type=self.port_type,
+        )
+        d = OmegaConf.create(d)
+        return OmegaConf.to_yaml(d)
+
     def __repr__(self) -> str:
-        return f"Port (name {self.name}, midpoint {self.midpoint}, width {self.width}, orientation {self.orientation}, layer {self.layer}, port_type {self.port_type})"
+        s = f"Port (name {self.name}, center {self.center}, width {self.width}, orientation {self.orientation}, layer {self.layer}, port_type {self.port_type})"
+        s += f" shear_angle {self.shear_angle}" if self.shear_angle else ""
+        return s
 
     @classmethod
     def __get_validators__(cls):
@@ -108,73 +188,142 @@ class Port(PortPhidl):
 
     @classmethod
     def validate(cls, v):
-        """For pydantic assumes Port is valid if has a name and a valid type
-
-        - has a name
-        """
+        """For pydantic assumes Port is valid if has a name and a valid type."""
         assert v.name, f"Port has no name, got `{v.name}`"
-        # assert v.assert_on_grid(), f"port.midpoint = {v.midpoint} has off-grid points"
+        # assert v.assert_on_grid(), f"port.center = {v.center} has off-grid points"
         assert isinstance(v, Port), f"TypeError, Got {type(v)}, expecting Port"
         return v
 
     @property
     def settings(self):
+        """TODO! delete this. Use to_dict instead"""
         return dict(
             name=self.name,
-            midpoint=self.midpoint,
+            center=self.center,
             width=self.width,
-            orientation=float(self.orientation),
+            orientation=self.orientation,
             layer=self.layer,
             port_type=self.port_type,
         )
 
-    @property
-    def angle(self):
-        """convenient alias"""
-        return self.orientation
+    # @property
+    # def angle(self):
+    #     """convenient alias for orientation."""
+    #     warnings.warn(angle_deprecation, DeprecationWarning, stacklevel=2)
+    #     return self.orientation
 
-    @angle.setter
-    def angle(self, a):
-        self.orientation = a
+    # @angle.setter
+    # def angle(self, a) -> None:
+    #     warnings.warn(angle_deprecation, DeprecationWarning, stacklevel=2)
+    #     self.orientation = a
 
-    @property
-    def position(self):
-        return self.midpoint
+    # @property
+    # def position(self) -> Tuple[float, float]:
+    #     warnings.warn(position_deprecation, DeprecationWarning, stacklevel=2)
+    #     return self.center
 
-    @position.setter
-    def position(self, p):
-        self.midpoint = np.array(p, dtype="float64")
+    # @position.setter
+    # def position(self, p) -> None:
+    #     warnings.warn(position_deprecation, DeprecationWarning, stacklevel=2)
+    #     self.center = np.array(p, dtype="float64")
 
-    def move(self, vector):
-        self.midpoint = self.midpoint + np.array(vector)
+    def move(self, vector) -> None:
+        self.center = self.center + np.array(vector)
 
-    def move_polar_copy(self, d, angle) -> PortPhidl:
+    def move_polar_copy(self, d: float, angle: float) -> Port:
+        """Returns a copy of the port with a distance (d) in um and angle (deg)."""
         port = self.copy()
         DEG2RAD = np.pi / 180
         dp = np.array((d * np.cos(DEG2RAD * angle), d * np.sin(DEG2RAD * angle)))
-        self.move(dp)
+        port.move(dp)
         return port
 
-    def flip(self):
+    def flip(self, **kwargs) -> Port:
         """flips port"""
-        port = self.copy()
-        port.angle = (port.angle + 180) % 360
+        port = self.copy(**kwargs)
+        if port.orientation is None:
+            raise ValueError(f"port {self.name!r} has None orientation")
+        port.orientation = (port.orientation + 180) % 360
         return port
 
-    def _copy(self, new_uid: bool = True) -> PortPhidl:
+    def _copy(self, new_uid: bool = True) -> Port:
         """Keep this case for phidl compatibility"""
         return self.copy(new_uid=new_uid)
 
-    def copy(self, new_uid: bool = True) -> PortPhidl:
+    @property
+    def endpoints(self) -> None:
+        """Returns the endpoints of the Port."""
+        dxdy = (
+            np.array(
+                [
+                    self.width / 2 * np.cos((self.orientation - 90) * np.pi / 180),
+                    self.width / 2 * np.sin((self.orientation - 90) * np.pi / 180),
+                ]
+            )
+            if self.orientation is not None
+            else np.array([self.width, self.width])
+        )
+        left_point = self.center - dxdy
+        right_point = self.center + dxdy
+        return np.array([left_point, right_point])
+
+    @endpoints.setter
+    def endpoints(self, points: Float2) -> None:
+        """Sets the endpoints of a Port."""
+        p1, p2 = np.array(points[0]), np.array(points[1])
+        self.center = (p1 + p2) / 2
+        dx, dy = p2 - p1
+        self.orientation = np.arctan2(dx, -dy) * 180 / np.pi
+        self.width = np.sqrt(dx**2 + dy**2)
+
+    @property
+    def normal(self) -> ndarray:
+        """Returns a vector normal to the Port."""
+        dx = np.cos((self.orientation) * np.pi / 180)
+        dy = np.sin((self.orientation) * np.pi / 180)
+        return np.array([self.center, self.center + np.array([dx, dy])])
+
+    @property
+    def x(self) -> float:
+        """Returns the x-coordinate of the Port center."""
+        return self.center[0]
+
+    @property
+    def y(self) -> float:
+        """Returns the y-coordinate of the Port center."""
+        return self.center[1]
+
+    def rotate(self, angle: float = 45, center: Optional[Float2] = None) -> Port:
+        """Rotates a Port around the specified center point,
+        if no centerpoint specified will rotate around (0,0).
+
+        Args:
+            angle: Angle to rotate the Port in degrees.
+            center: array-like[2] or None center of the Port.
+        """
+        self.orientation = np.mod(self.orientation + angle, 360)
+        if center is None:
+            center = self.center
+        self.center = _rotate_points(self.center, angle=angle, center=center)
+        return self
+
+    def copy(self, name: Optional[str] = None, new_uid: bool = True) -> Port:
+        """Returns a copy of the port.
+
+        Args:
+            name: optional new name.
+            new_uid: True creates a new port id.
+        """
         new_port = Port(
-            name=self.name,
-            midpoint=self.midpoint,
+            name=name or self.name,
+            center=self.center,
             width=self.width,
             orientation=self.orientation,
             parent=self.parent,
             layer=self.layer,
             port_type=self.port_type,
             cross_section=self.cross_section,
+            shear_angle=self.shear_angle,
         )
         new_port.info = deepcopy(self.info)
         if not new_uid:
@@ -182,15 +331,16 @@ class Port(PortPhidl):
             Port._next_uid -= 1
         return new_port
 
-    def get_extended_midpoint(self, length: float = 1.0) -> ndarray:
-        """Returns an extended midpoint"""
+    def get_extended_center(self, length: float = 1.0) -> ndarray:
+        """Returns an extended port center."""
         angle = self.orientation
         c = np.cos(angle)
         s = np.sin(angle)
-        return self.midpoint + length * np.array([c, s])
+        return self.center + length * np.array([c, s])
 
     def snap_to_grid(self, nm: int = 1) -> None:
-        self.midpoint = nm * np.round(np.array(self.midpoint) * 1e3 / nm) / 1e3
+        """Snap port center to nm grid."""
+        self.center = nm * np.round(np.array(self.center) * 1e3 / nm) / 1e3
 
     def assert_on_grid(self, nm: int = 1) -> None:
         """Ensures ports edges are on grid to avoid snap_to_grid errors."""
@@ -199,14 +349,17 @@ class Port(PortPhidl):
         component_name = self.parent.name
         if not np.isclose(half_width, half_width_correct):
             raise PortNotOnGridError(
-                f"{component_name}, port = {self.name}, midpoint = {self.midpoint} width = {self.width} will create off-grid points",
+                f"{component_name}, port = {self.name!r}, center = {self.center} width = {self.width} will create off-grid points",
                 f"you can fix it by changing width to {2*half_width_correct}",
             )
 
         if self.port_type.startswith("vertical"):
             return
 
-        if self.orientation in [0, 180]:
+        if self.orientation is None:
+            return
+
+        elif self.orientation in [0, 180]:
             x = self.y + self.width / 2
             if not np.isclose(snap_to_grid(x, nm=nm), x):
                 raise PortNotOnGridError(
@@ -227,29 +380,33 @@ class Port(PortPhidl):
             )
 
 
+PortsMap = Dict[str, List[Port]]
+
+
 def port_array(
-    midpoint: Tuple[int, int] = (0, 0),
+    center: Tuple[float, float] = (0.0, 0.0),
     width: float = 0.5,
-    orientation: int = 0,
-    pitch: Tuple[int, int] = (10, 0),
+    orientation: float = 0,
+    pitch: Tuple[float, float] = (10.0, 0.0),
     n: int = 2,
     **kwargs,
 ) -> List[Port]:
-    """Returns a list of ports placed in an array
+    """Returns a list of ports placed in an array.
 
     Args:
-        midpoint: center point of the port
-        width: port width
-        orientation: angle in degrees
-        pitch: period of the port array
-        n: number of ports in the array
+        center: center point of the port.
+        width: port width.
+        orientation: angle in degrees.
+        pitch: period of the port array.
+        n: number of ports in the array.
 
     """
     pitch = np.array(pitch)
     return [
         Port(
             name=str(i),
-            midpoint=np.array(midpoint) + i * pitch - (n - 1) / 2 * pitch,
+            width=width,
+            center=np.array(center) + i * pitch - (n - 1) / 2 * pitch,
             orientation=orientation,
             **kwargs,
         )
@@ -257,22 +414,22 @@ def port_array(
     ]
 
 
-def read_port_markers(
-    component: object, layers: Tuple[Tuple[int, int], ...] = ((1, 10),)
-) -> Device:
+def read_port_markers(component: object, layers: LayerSpecs = ((1, 10),)) -> Component:
     """Loads a GDS and returns the extracted ports from layer markers
 
     Args:
         component: or Component
         layers: Iterable of GDS layers
     """
-    return pg.extract(component, layers=layers)
+    from gdsfactory.pdk import get_layer
+
+    return pg.extract(component, layers=[get_layer(layer) for layer in layers])
 
 
 def csv2port(csvpath) -> Dict[str, Port]:
     """Reads ports from a CSV file and returns a Dict"""
     ports = {}
-    with open(csvpath, "r") as csvfile:
+    with open(csvpath) as csvfile:
         rows = csv.reader(csvfile, delimiter=",", quotechar="|")
         for row in rows:
             ports[row[0]] = row[1:]
@@ -294,10 +451,10 @@ def sort_ports_clockwise(ports: Dict[str, Port]) -> Dict[str, Port]:
              8   7
     """
     port_list = list(ports.values())
-    direction_ports = {x: [] for x in ["E", "N", "W", "S"]}
+    direction_ports: PortsMap = {x: [] for x in ["E", "N", "W", "S"]}
 
     for p in port_list:
-        angle = p.orientation % 360
+        angle = p.orientation % 360 if p.orientation is not None else 0
         if angle <= 45 or angle >= 315:
             direction_ports["E"].append(p)
         elif angle <= 135 and angle >= 45:
@@ -337,10 +494,10 @@ def sort_ports_counter_clockwise(ports: Dict[str, Port]) -> Dict[str, Port]:
              7   8
     """
     port_list = list(ports.values())
-    direction_ports = {x: [] for x in ["E", "N", "W", "S"]}
+    direction_ports: PortsMap = {x: [] for x in ["E", "N", "W", "S"]}
 
     for p in port_list:
-        angle = p.orientation % 360
+        angle = p.orientation % 360 if p.orientation is not None else 0
         if angle <= 45 or angle >= 315:
             direction_ports["E"].append(p)
         elif angle <= 135 and angle >= 45:
@@ -370,33 +527,34 @@ def select_ports(
     ports: Dict[str, Port],
     layer: Optional[Tuple[int, int]] = None,
     prefix: Optional[str] = None,
+    suffix: Optional[str] = None,
     orientation: Optional[int] = None,
     width: Optional[float] = None,
     layers_excluded: Optional[Tuple[Tuple[int, int], ...]] = None,
     port_type: Optional[str] = None,
     clockwise: bool = True,
 ) -> Dict[str, Port]:
-    """Returns a dict of ports from a dict of ports
+    """Returns a dict of ports from a dict of ports.
 
     Args:
-        ports: Dict[str, Port] a port dict {port name: port}
-        layer: port GDS layer
-        prefix: with in port name
-        orientation: in degrees
-        width:
-        layers_excluded: List of layers to exclude
-        port_type: optical, electrical, ...
-        clockwise: if True, sort ports clockwise, False: counter-clockwise
+        ports: Dict[str, Port] a port dict {port name: port}.
+        layer: select ports with port GDS layer.
+        prefix: select ports with port name prefix.
+        suffix: select ports with port name suffix.
+        orientation: select ports with orientation in degrees.
+        width: select ports with port width.
+        layers_excluded: List of layers to exclude.
+        port_type: select ports with port type (optical, electrical, vertical_te).
+        clockwise: if True, sort ports clockwise, False: counter-clockwise.
 
     Returns:
-        Dictionary containing only the ports with the wanted type(s)
-        {port name: port}
+        Dict containing the selected ports {port name: port}.
     """
 
     from gdsfactory.component import Component, ComponentReference
 
     # Make it accept Component or ComponentReference
-    if isinstance(ports, Component) or isinstance(ports, ComponentReference):
+    if isinstance(ports, (Component, ComponentReference)):
         ports = ports.ports
 
     if layer:
@@ -405,6 +563,10 @@ def select_ports(
         ports = {
             p_name: p for p_name, p in ports.items() if str(p_name).startswith(prefix)
         }
+    if suffix:
+        ports = {
+            p_name: p for p_name, p in ports.items() if str(p_name).endswith(suffix)
+        }
     if orientation is not None:
         ports = {
             p_name: p for p_name, p in ports.items() if p.orientation == orientation
@@ -435,14 +597,16 @@ def select_ports_list(**kwargs) -> List[Port]:
 
 
 def flipped(port: Port) -> Port:
+    if port.orientation is None:
+        raise ValueError(f"port {port.name!r} has None orientation")
     _port = port.copy()
     _port.orientation = (_port.orientation + 180) % 360
     return _port
 
 
-def move_copy(port, x=0, y=0):
+def move_copy(port, x=0, y=0) -> Port:
     _port = port.copy()
-    _port.midpoint += (x, y)
+    _port.center += (x, y)
     return _port
 
 
@@ -456,13 +620,13 @@ def get_ports_facing(ports: List[Port], direction: str = "W") -> List[Port]:
 
     if isinstance(ports, dict):
         ports = list(ports.values())
-    elif isinstance(ports, Component) or isinstance(ports, ComponentReference):
+    elif isinstance(ports, (Component, ComponentReference)):
         ports = list(ports.ports.values())
 
     direction_ports: Dict[str, List[Port]] = {x: [] for x in ["E", "N", "W", "S"]}
 
     for p in ports:
-        angle = p.orientation % 360
+        angle = p.orientation % 360 if p.orientation is not None else 0
         if angle <= 45 or angle >= 315:
             direction_ports["E"].append(p)
         elif angle <= 135 and angle >= 45:
@@ -525,7 +689,7 @@ def _rename_ports_facing_side_ccw(
             p.name = prefix + direction + str(i)
 
 
-def _rename_ports_counter_clockwise(direction_ports, prefix=""):
+def _rename_ports_counter_clockwise(direction_ports, prefix="") -> None:
     east_ports = direction_ports["E"]
     east_ports.sort(key=lambda p: +p.y)  # sort south to north
 
@@ -544,7 +708,7 @@ def _rename_ports_counter_clockwise(direction_ports, prefix=""):
         p.name = f"{prefix}{i+1}" if prefix else i + 1
 
 
-def _rename_ports_clockwise(direction_ports, prefix: str = ""):
+def _rename_ports_clockwise(direction_ports: PortsMap, prefix: str = "") -> None:
     """Rename ports in the clockwise direction starting from the bottom left (west) corner."""
     east_ports = direction_ports["E"]
     east_ports.sort(key=lambda p: -p.y)  # sort north to south
@@ -565,7 +729,9 @@ def _rename_ports_clockwise(direction_ports, prefix: str = ""):
         p.name = f"{prefix}{i+1}" if prefix else i + 1
 
 
-def _rename_ports_clockwise_top_right(direction_ports, prefix: str = ""):
+def _rename_ports_clockwise_top_right(
+    direction_ports: PortsMap, prefix: str = ""
+) -> None:
     """Rename ports in the clockwise direction starting from the top right corner."""
     east_ports = direction_ports["E"]
     east_ports.sort(key=lambda p: -p.y)  # sort north to south
@@ -586,20 +752,20 @@ def _rename_ports_clockwise_top_right(direction_ports, prefix: str = ""):
 
 
 def rename_ports_by_orientation(
-    component: Device,
-    layers_excluded: Tuple[Tuple[int, int], ...] = None,
-    select_ports: Optional[Callable] = None,
+    component: Component,
+    layers_excluded: LayerSpec = None,
+    select_ports: Optional[Callable[..., List[Port]]] = None,
     function=_rename_ports_facing_side,
     prefix: str = "o",
-) -> Device:
-    """Returns Component with port names based on port orientation (E, N, W, S)
+) -> Component:
+    """Returns Component with port names based on port orientation (E, N, W, S).
 
     Args:
-        component:
-        layers_excluded:
-        select_ports:
-        function: to rename ports
-        prefix: to add on each port name
+        component: to rename ports.
+        layers_excluded: to exclude.
+        select_ports: function to select_ports.
+        function: to rename ports.
+        prefix: to add on each port name.
 
     .. code::
 
@@ -614,7 +780,7 @@ def rename_ports_by_orientation(
     """
 
     layers_excluded = layers_excluded or []
-    direction_ports = {x: [] for x in ["E", "N", "W", "S"]}
+    direction_ports: PortsMap = {x: [] for x in ["E", "N", "W", "S"]}
 
     ports = component.ports
     ports = select_ports(ports) if select_ports else ports
@@ -625,13 +791,16 @@ def rename_ports_by_orientation(
         # Make sure we can backtrack the parent component from the port
         p.parent = component
 
-        angle = p.orientation % 360
-        if angle <= 45 or angle >= 315:
-            direction_ports["E"].append(p)
-        elif angle <= 135 and angle >= 45:
-            direction_ports["N"].append(p)
-        elif angle <= 225 and angle >= 135:
-            direction_ports["W"].append(p)
+        if p.orientation:
+            angle = p.orientation % 360
+            if angle <= 45 or angle >= 315:
+                direction_ports["E"].append(p)
+            elif angle <= 135 and angle >= 45:
+                direction_ports["N"].append(p)
+            elif angle <= 225 and angle >= 135:
+                direction_ports["W"].append(p)
+            else:
+                direction_ports["S"].append(p)
         else:
             direction_ports["S"].append(p)
 
@@ -641,23 +810,23 @@ def rename_ports_by_orientation(
 
 
 def auto_rename_ports(
-    component: Device,
+    component: Component,
     function=_rename_ports_clockwise,
     select_ports_optical=select_ports_optical,
     select_ports_electrical=select_ports_electrical,
     prefix_optical: str = "o",
     prefix_electrical: str = "e",
     **kwargs,
-) -> Device:
-    """Adds prefix for optical and electical.
+) -> Component:
+    """Adds prefix for optical and electrical.
 
     Args:
-        component:
-        function: to rename ports
-        select_ports_optical:
-        select_ports_electrical:
-        prefix_optical:
-        prefix_electrical:
+        component: to auto_rename_ports.
+        function: to rename ports.
+        select_ports_optical: to select optical ports.
+        select_ports_electrical: to select electrical ports.
+        prefix_optical: prefix of optical ports.
+        prefix_electrical: prefix of electrical ports.
     """
     rename_ports_by_orientation(
         component=component,
@@ -702,7 +871,7 @@ def map_ports_layer_to_orientation(
     """
 
     m = {}
-    direction_ports = {x: [] for x in ["E", "N", "W", "S"]}
+    direction_ports: PortsMap = {x: [] for x in ["E", "N", "W", "S"]}
     layers = {port.layer for port in ports.values()}
 
     for layer in layers:
@@ -710,15 +879,16 @@ def map_ports_layer_to_orientation(
 
         for p in ports_on_layer:
             p.name_original = p.name
-            angle = p.orientation % 360
-            if angle <= 45 or angle >= 315:
-                direction_ports["E"].append(p)
-            elif angle <= 135 and angle >= 45:
-                direction_ports["N"].append(p)
-            elif angle <= 225 and angle >= 135:
-                direction_ports["W"].append(p)
-            else:
-                direction_ports["S"].append(p)
+            if p.orientation:
+                angle = p.orientation % 360
+                if angle <= 45 or angle >= 315:
+                    direction_ports["E"].append(p)
+                elif angle <= 135 and angle >= 45:
+                    direction_ports["N"].append(p)
+                elif angle <= 225 and angle >= 135:
+                    direction_ports["W"].append(p)
+                else:
+                    direction_ports["S"].append(p)
         function(direction_ports, prefix=f"{layer[0]}_{layer[1]}_")
         m.update({p.name: p.name_original for p in ports_on_layer})
     return m
@@ -727,8 +897,13 @@ def map_ports_layer_to_orientation(
 def map_ports_to_orientation_cw(
     ports: Dict[str, Port], function=_rename_ports_facing_side, **kwargs
 ) -> Dict[str, str]:
-    """Returns component or reference port mapping clockwise
-    **kwargs
+    """Returns component or reference port mapping clockwise.
+
+    Args:
+        ports: dict of ports.
+        function: to rename ports.
+        kwargs: for the function to rename ports.
+
 
     .. code::
 
@@ -742,8 +917,7 @@ def map_ports_to_orientation_cw(
 
     """
 
-    m = {}
-    direction_ports = {x: [] for x in ["E", "N", "W", "S"]}
+    direction_ports: PortsMap = {x: [] for x in ["E", "N", "W", "S"]}
 
     ports = select_ports(ports, **kwargs)
     ports_on_layer = [p.copy() for p in ports.values()]
@@ -760,8 +934,7 @@ def map_ports_to_orientation_cw(
         else:
             direction_ports["S"].append(p)
     function(direction_ports)
-    m.update({p.name: p.name_original for p in ports_on_layer})
-    return m
+    return dict({p.name: p.name_original for p in ports_on_layer})
 
 
 map_ports_to_orientation_ccw = partial(
@@ -770,11 +943,12 @@ map_ports_to_orientation_ccw = partial(
 
 
 def auto_rename_ports_layer_orientation(
-    component: Device,
+    component: Component,
     function=_rename_ports_facing_side,
     prefix: str = "",
 ) -> None:
-    """Renames port names with layer_orientation  (1_0_W0)
+    """Renames port names with layer_orientation  (1_0_W0).
+
     port orientation (E, N, W, S) numbering is clockwise
 
     .. code::
@@ -790,7 +964,7 @@ def auto_rename_ports_layer_orientation(
     """
     new_ports = {}
     ports = component.ports
-    direction_ports = {x: [] for x in ["E", "N", "W", "S"]}
+    direction_ports: PortsMap = {x: [] for x in ["E", "N", "W", "S"]}
     layers = {port.layer for port in ports.values()}
 
     for layer in layers:
@@ -809,7 +983,7 @@ def auto_rename_ports_layer_orientation(
                 direction_ports["S"].append(p)
 
         function(direction_ports, prefix=f"{layer[0]}_{layer[1]}_")
-        new_ports.update({p.name: p for p in ports_on_layer})
+        new_ports |= {p.name: p for p in ports_on_layer}
 
     component.ports = new_ports
 
@@ -843,7 +1017,9 @@ if __name__ == "__main__":
     # auto_rename_ports_layer_orientation(c)
     # m = map_ports_layer_to_orientation(c.ports)
     # pprint(m)
-    # c.show()
+    # c.show(show_ports=True)
     # print(p0)
-    p0 = c.get_ports_list(orientation=90, clockwise=False)[0]
-    print(p0)
+    # p0 = c.get_ports_list(orientation=0, clockwise=False)[0]
+    # print(p0)
+    # print(type(p0.to_dict()["center"][0]))
+    p = Port("o1", orientation=0, midpoint=(9, 0), layer=(1, 0), width=10)
