@@ -1,16 +1,20 @@
+from gdsfactory.read.from_dphox import from_dphox
 from gdsfactory.read.from_gdspaths import from_gdsdir, from_gdspaths
 from gdsfactory.read.from_np import from_np
 from gdsfactory.read.from_phidl import from_phidl
 from gdsfactory.read.from_picwriter import from_picwriter
 from gdsfactory.read.from_yaml import from_yaml
 from gdsfactory.read.import_gds import import_gds
+from gdsfactory.read.import_oas import import_oas
 
 __all__ = [
+    "from_dphox",
+    "from_gdsdir",
+    "from_gdspaths",
+    "from_np",
     "from_phidl",
     "from_picwriter",
-    "import_gds",
-    "from_gdspaths",
-    "from_gdsdir",
-    "from_np",
     "from_yaml",
+    "import_gds",
+    "import_oas",
 ]
