@@ -1,24 +1,26 @@
 import pathlib
 from typing import Tuple
 
-from gdsfactory.cell import cell
 from gdsfactory.component import Component
+from gdsfactory.config import logger
 from gdsfactory.read.import_gds import import_gds
 from gdsfactory.types import ComponentOrPath, PathType
 
 
-@cell
 def from_gdspaths(cells: Tuple[ComponentOrPath, ...]) -> Component:
     """Combine all GDS files or gf.components into a gf.component.
 
     Args:
-        cells: List of gdspaths or Components
+        cells: List of gdspaths or Components.
     """
-    component = Component()
+    component = Component("merged")
 
     for c in cells:
-        if not isinstance(c, Component):
+        if isinstance(c, (str, pathlib.Path)):
+            logger.info(f"Loading {c!r}")
             c = import_gds(c)
+
+        assert isinstance(c, Component)
         component << c
 
     return component
@@ -27,7 +29,8 @@ def from_gdspaths(cells: Tuple[ComponentOrPath, ...]) -> Component:
 def from_gdsdir(dirpath: PathType) -> Component:
     """Merges GDS cells from a directory into a single Component"""
     dirpath = pathlib.Path(dirpath)
-    return from_gdspaths(dirpath.glob("*.gds"))
+    assert dirpath.exists(), f"{dirpath} does not exist"
+    return from_gdspaths(list(dirpath.glob("*.gds")))
 
 
 if __name__ == "__main__":
@@ -36,4 +39,4 @@ if __name__ == "__main__":
     # c = gdspaths([gf.components.straight(), gf.components.bend_circular()])
     # leave these two lines to end up tests showing the diff
     c = from_gdspaths(diff_path.glob("*.gds"))
-    c.show()
+    c.show(show_ports=True)
