@@ -1,9 +1,9 @@
 """Routes bundles of ports (river routing).
 """
-from typing import Callable, List, Optional
+from typing import Callable, List, Optional, Union
 
 from gdsfactory.components.bend_euler import bend_euler
-from gdsfactory.components.straight import straight
+from gdsfactory.components.straight import straight as _straight
 from gdsfactory.components.taper import taper as taper_function
 from gdsfactory.cross_section import strip
 from gdsfactory.port import Port
@@ -14,7 +14,12 @@ from gdsfactory.routing.get_bundle import (
 from gdsfactory.routing.get_route import get_route_from_waypoints
 from gdsfactory.routing.path_length_matching import path_length_matched_points
 from gdsfactory.routing.sort_ports import sort_ports as sort_ports_function
-from gdsfactory.types import ComponentFactory, CrossSectionFactory, Route
+from gdsfactory.types import (
+    ComponentSpec,
+    CrossSectionSpec,
+    MultiCrossSectionAngleSpec,
+    Route,
+)
 
 
 def get_bundle_path_length_match(
@@ -25,35 +30,35 @@ def get_bundle_path_length_match(
     extra_length: float = 0.0,
     nb_loops: int = 1,
     modify_segment_i: int = -2,
-    bend: ComponentFactory = bend_euler,
-    straight: Callable = straight,
-    taper: Optional[Callable] = taper_function,
+    bend: ComponentSpec = bend_euler,
+    straight: ComponentSpec = _straight,
+    taper: Optional[ComponentSpec] = taper_function,
     start_straight_length: float = 0.0,
     route_filter: Callable = get_route_from_waypoints,
     sort_ports: bool = True,
-    cross_section: CrossSectionFactory = strip,
+    cross_section: Union[CrossSectionSpec, MultiCrossSectionAngleSpec] = strip,
     **kwargs
 ) -> List[Route]:
     """Returns list of routes that are path length matched.
 
     Args:
-        ports1: list of ports
-        ports2: list of ports
-        separation: between the loops
-        end_straight_length: if None tries to determine it
+        ports1: list of ports.
+        ports2: list of ports.
+        separation: between the loops.
+        end_straight_length: if None tries to determine it.
         extra_length: distance added to all path length compensation.
-            Useful is we want to add space for extra taper on all branches
-        nb_loops: number of extra loops added in the path
-        modify_segment_i: index of the segment that accomodates the new turns
-            default is next to last segment
-        bend: for bends
-        straight: for straights
-        taper:
-        start_straight_length:
-        route_filter: get_route_from_waypoints
-        sort_ports: sorts ports before routing
-        cross_section: factory
-        **kwargs: cross_section settings
+            Useful is we want to add space for extra taper on all branches.
+        nb_loops: number of extra loops added in the path.
+        modify_segment_i: index of the segment that accommodates the new turns
+            default is next to last segment.
+        bend: for bends.
+        straight: for straights.
+        taper: spec.
+        start_straight_length: in um.
+        route_filter: get_route_from_waypoints.
+        sort_ports: sorts ports before routing.
+        cross_section: factory.
+        kwargs: cross_section settings.
 
     Tips:
 
@@ -77,18 +82,18 @@ def get_bundle_path_length_match(
 
       a1 = 90
       a2 = a1 + 180
-      ports1 = [gf.Port(f"top_{i}", (xs1[i], 0), 0.5, a1) for i in range(N)]
-      ports2 = [gf.Port(f"bottom_{i}", (xs2[i], dy), 0.5, a2) for i in range(N)]
+      ports1 = [gf.Port(f"top_{i}", (xs1[i], +0), 0.5, a1, layer="WG") for i in range(N)]
+      ports2 = [gf.Port(f"bot_{i}", (xs2[i], dy), 0.5, a2, layer="WG") for i in range(N)]
 
-      routes = gf.routing.get_bundle_path_length_match(
-          ports1, ports2, extra_length=44
-      )
+      routes = gf.routing.get_bundle_path_length_match(ports1, ports2, extra_length=44)
       for route in routes:
           c.add(route.references)
+
+      gf.config.set_plot_options(show_subports=False)
       c.plot()
 
     """
-    extra_length = extra_length / 2
+    extra_length /= 2
 
     # Heuristic to get a correct default end_straight_offset to leave
     # enough space for path-length compensation
@@ -158,4 +163,4 @@ if __name__ == "__main__":
 
     for route in routes:
         c.add(route.references)
-    c.show()
+    c.show(show_ports=True)
