@@ -6,34 +6,32 @@ from gdsfactory.components.grating_coupler_elliptical_trenches import grating_co
 from gdsfactory.cross_section import strip
 from gdsfactory.port import select_ports_optical
 from gdsfactory.routing.route_fiber_array import route_fiber_array
-from gdsfactory.types import CrossSectionFactory, Label
+from gdsfactory.types import ComponentSpec, CrossSectionSpec, Label
 
 
 def route_fiber_single(
     component: Component,
     fiber_spacing: float = 50.0,
-    grating_coupler: Callable = grating_coupler_te,
+    grating_coupler: ComponentSpec = grating_coupler_te,
     min_input_to_output_spacing: float = 200.0,
     optical_routing_type: int = 1,
     optical_port_labels: Optional[Tuple[str, ...]] = None,
     excluded_ports: Optional[Tuple[str, ...]] = None,
-    auto_widen: bool = False,
     component_name: Optional[str] = None,
     select_ports: Callable = select_ports_optical,
-    cross_section: CrossSectionFactory = strip,
+    cross_section: CrossSectionSpec = strip,
     **kwargs,
 ) -> Tuple[List[Union[ComponentReference, Label]], List[ComponentReference]]:
     """Returns route Tuple(references, grating couplers) for single fiber input/output.
 
     Args:
-        component: to add grating couplers
-        fiber_spacing: between grating couplers
-        grating_coupler:
+        component: to add grating couplers.
+        fiber_spacing: between grating couplers.
+        grating_coupler: grating coupler Spec
         min_input_to_output_spacing: so opposite fibers do not touch
         optical_routing_type: 0 (basic), 1 (standard), 2 (looks at ports)
         optical_port_labels: port labels that need connection
         excluded_ports: ports excluded from routing
-        auto_widen: for long routes
         component_name:
         select_ports:
         cross_section:
@@ -125,7 +123,6 @@ def route_fiber_single(
             fanout_length=fanout_length,
             grating_coupler=grating_couplers[0],
             optical_routing_type=optical_routing_type,
-            auto_widen=auto_widen,
             component_name=component_name,
             cross_section=cross_section,
             select_ports=select_ports,
@@ -149,7 +146,6 @@ def route_fiber_single(
         fanout_length=fanout_length,
         grating_coupler=grating_couplers[1:],
         optical_routing_type=optical_routing_type,
-        auto_widen=auto_widen,
         component_name=component_name,
         cross_section=cross_section,
         select_ports=select_ports,
@@ -179,7 +175,7 @@ if __name__ == "__main__":
     c = gf.components.rectangle()
 
     # elements, gc = route_fiber_single(
-    #     c, grating_coupler=[gcte, gctm, gcte, gctm], auto_widen=False
+    #     c, grating_coupler=[gcte, gctm, gcte, gctm],
     # )
 
     layer = (2, 0)
@@ -188,13 +184,12 @@ if __name__ == "__main__":
     c = gf.components.ring_single(length_x=167)
     c = gf.components.mmi2x2()
     c = gf.components.spiral(direction="NORTH")
-    c = gf.c.spiral_inner_io_fiber_single()
+    c = gf.components.spiral_inner_io_fiber_single()
 
     gc = gf.components.grating_coupler_elliptical_te(layer=layer)
     elements, gc = route_fiber_single(
         c,
         grating_coupler=[gc, gc, gc, gc],
-        auto_widen=False,
         radius=10,
         layer=layer,
     )
@@ -207,7 +202,7 @@ if __name__ == "__main__":
         cc.add(e)
     for e in gc:
         cc.add(e)
-    cc.show()
+    cc.show(show_ports=True)
 
     # layer = (31, 0)
     # c = gf.components.mmi2x2()
@@ -216,7 +211,6 @@ if __name__ == "__main__":
     # elements, gc = route_fiber_single(
     #     c,
     #     grating_coupler=[gc, gc, gc, gc],
-    #     auto_widen=False,
     #     radius=10,
     #     layer=layer,
     # )
@@ -226,4 +220,4 @@ if __name__ == "__main__":
     #     cc.add(e)
     # for e in gc:
     #     cc.add(e)
-    # cc.show()
+    # cc.show(show_ports=True)
