@@ -1,9 +1,10 @@
 """Group references. Distribute them as you want
 
-Lets distribute different references in the X direction
+Distribute different references in the X direction.
 
 """
 
+
 if __name__ == "__main__":
 
     import gdsfactory as gf
@@ -18,5 +19,4 @@ if __name__ == "__main__":
     t6 = D << gf.components.text("6")
 
     D.distribute(direction="x", spacing=3)
-
-    gf.show(D)
+    D.show()
