@@ -4,12 +4,9 @@ from gdsfactory.add_pins import add_pins_triangle
 from gdsfactory.component import Component
 
 
-def test_pins_custom() -> Component:
+def test_pins_custom(**kwargs) -> Component:
     """You can define the `pins_function` that we use to add markers to each port"""
-    c = gf.components.straight(length=11.1)
-    c = c.copy()
-    add_pins_triangle(component=c)
-    return c
+    return gf.components.straight(**kwargs, decorator=add_pins_triangle)
 
 
 if __name__ == "__main__":
