@@ -18,11 +18,11 @@ def big_device(
     """Big component with N ports on each side
 
     Args:
-        size:
-        nports: number of ports
-        spacing:
-        layer:
-        wg_width: waveguide width
+        size: x, y.
+        nports: number of ports.
+        spacing: in um.
+        layer: spec.
+        wg_width: waveguide width in um.
     """
     component = gf.Component()
     p0 = np.array((0, 0))
@@ -34,10 +34,11 @@ def big_device(
 
     points = [[dx, dy], [dx, -dy], [-dx, -dy], [-dx, dy]]
     component.add_polygon(points, layer=layer)
+
     for i in range(N):
         port = Port(
             name=f"W{i}",
-            midpoint=p0 + (-dx, (i - N / 2) * spacing),
+            center=p0 + (-dx, (i - N / 2) * spacing),
             orientation=180,
             layer=layer,
             width=wg_width,
@@ -47,7 +48,7 @@ def big_device(
     for i in range(N):
         port = Port(
             name=f"E{i}",
-            midpoint=p0 + (dx, (i - N / 2) * spacing),
+            center=p0 + (dx, (i - N / 2) * spacing),
             orientation=0,
             layer=layer,
             width=wg_width,
@@ -57,7 +58,7 @@ def big_device(
     for i in range(N):
         port = Port(
             name=f"N{i}",
-            midpoint=p0 + ((i - N / 2) * spacing, dy),
+            center=p0 + ((i - N / 2) * spacing, dy),
             orientation=90,
             layer=layer,
             width=wg_width,
@@ -67,7 +68,7 @@ def big_device(
     for i in range(N):
         port = Port(
             name=f"S{i}",
-            midpoint=p0 + ((i - N / 2) * spacing, -dy),
+            center=p0 + ((i - N / 2) * spacing, -dy),
             orientation=-90,
             layer=layer,
             width=wg_width,
@@ -78,4 +79,5 @@ def big_device(
 
 if __name__ == "__main__":
     c = big_device()
-    c.show()
+    c = gf.routing.add_fiber_array(c)
+    c.show(show_ports=True)
