@@ -2,9 +2,9 @@ import os
 import sys
 
 
-def disable_print():
+def disable_print() -> None:
     sys.stdout = open(os.devnull, "w")
 
 
-def enable_print():
+def enable_print() -> None:
     sys.stdout = sys.__stdout__
