@@ -1,4 +1,4 @@
-from typing import Tuple, Union
+"""snaps values and coordinates to the GDS grid in nm"""
 
 import numpy as np
 
@@ -17,13 +17,11 @@ def assert_on_2nm_grid(x: float) -> None:
     assert np.isclose(x_grid, x), f"{x} needs to be on 2nm grid, try {x_grid}"
 
 
-def snap_to_grid(
-    x: Union[float, Tuple[float, ...], np.array], nm: int = 1
-) -> Union[float, np.array, Tuple[float, ...]]:
+def snap_to_grid(x: float, nm: int = 1) -> float:
     y = nm * np.round(np.array(x, dtype=float) * 1e3 / nm) / 1e3
     if isinstance(x, tuple):
         return tuple(y)
-    elif type(x) in [int, float, str, np.float64]:
+    elif isinstance(x, (int, float, str, np.float_)):
         return float(y)
     return y
 
