@@ -1,4 +1,4 @@
-import itertools as it
+from pprint import pprint
 
 import jsondiff
 import numpy as np
@@ -8,7 +8,7 @@ from pytest_regressions.data_regression import DataRegressionFixture
 
 from gdsfactory.component import Component
 from gdsfactory.difftest import difftest
-from gdsfactory.read.from_yaml import from_yaml, sample_mmis
+from gdsfactory.read.from_yaml import from_yaml, sample_doe_function, sample_mmis
 
 sample_connections = """
 name: sample_connections
@@ -103,7 +103,10 @@ routes:
             mmi_bottom,o3: mmi_top,o2
 
         settings:
-            layer: [2, 0]
+            cross_section:
+                cross_section: strip
+                settings:
+                    layer: [2, 0]
 
 """
 
@@ -114,7 +117,7 @@ def test_connections_2x2() -> Component:
     assert len(c.ports) == 0, len(c.ports)
 
     length = c.routes["mmi_bottom,o3:mmi_top,o2"]
-    assert np.isclose(length, 165.774), length
+    assert np.isclose(length, 168.274), length
     return c
 
 
@@ -148,14 +151,20 @@ routes:
     electrical:
         settings:
             separation: 20
-            layer: [31, 0]
-            width: 10
+            cross_section:
+                cross_section: metal3
+                settings:
+                    layer: [31, 0]
+                    width: 10
         links:
             tl,e3: tr,e1
             bl,e3: br,e1
     optical:
         settings:
-            radius: 100
+            cross_section:
+                cross_section: strip
+                settings:
+                    radius: 100
         links:
             bl,e4: br,e3
 
@@ -441,6 +450,37 @@ placements:
         dy: 10
 """
 
+sample_doe = """
+name: mask
+
+instances:
+    mmi1x2_sweep:
+       component: pack_doe
+       settings:
+         doe: mmi1x2
+         do_permutations: True
+         spacing: 100
+         settings:
+           length_mmi: [2, 100]
+           width_mmi: [4, 10]
+"""
+
+sample_doe_grid = """
+name: mask_grid
+
+instances:
+    mmi1x2_sweep:
+       component: pack_doe_grid
+       settings:
+         doe: mmi1x2
+         do_permutations: True
+         spacing: [100, 100]
+         shape: [2, 2]
+         settings:
+           length_mmi: [2, 100]
+           width_mmi: [4, 10]
+"""
+
 # FIXME: Fix both unconmmented cases
 # yaml_fail should actually fail
 # sample_different_factory: returns a zero length straight that gives an error
@@ -458,6 +498,9 @@ yaml_strings = dict(
     sample_mirror_simple=sample_mirror_simple,
     sample_connections=sample_connections,
     sample_mmis=sample_mmis,
+    sample_doe=sample_doe,
+    # sample_doe_grid=sample_doe_grid,
+    sample_doe_function=sample_doe_function,
 )
 
 
@@ -482,49 +525,50 @@ def test_settings(
     return c
 
 
-@pytest.mark.parametrize(
-    "yaml_key,full_settings", it.product(yaml_strings.keys(), [True, False])
-)
+@pytest.mark.parametrize("yaml_key", yaml_strings.keys())
 def test_netlists(
     yaml_key: str,
-    full_settings: bool,
     data_regression: DataRegressionFixture,
     check: bool = True,
 ) -> None:
     """Write netlists for hierarchical circuits.
     Checks that both netlists are the same
     jsondiff does a hierarchical diff
-
     Component -> netlist -> Component -> netlist
+
+    Args:
+        yaml_key: to test.
+        data_regression: for regression test.
+        check: False, skips test.
     """
     yaml_string = yaml_strings[yaml_key]
     c = from_yaml(yaml_string)
-    n = c.get_netlist(full_settings=full_settings)
+    n = c.get_netlist()
     if check:
         data_regression.check(OmegaConf.to_container(n))
 
     yaml_str = OmegaConf.to_yaml(n, sort_keys=True)
+
     # print(yaml_str)
-    c2 = from_yaml(yaml_str)
-    n2 = c2.get_netlist(full_settings=full_settings)
-    d = jsondiff.diff(n, n2)
-    assert len(d) == 0, print(d)
-    return c2
+    c2 = from_yaml(yaml_str, name=c.name)
+    n2 = c2.get_netlist()
+    # pprint(d)
+    # assert len(d) == 0, pprint(d)
+    return jsondiff.diff(n, n2)
 
 
-def _demo_netlist():
+def _demo_netlist() -> None:
     """path on the route"""
     import gdsfactory as gf
 
     # c = from_yaml(sample_2x2_connections)
     c = from_yaml(sample_waypoints)
     c = from_yaml(sample_different_factory)
-    c.show()
-    full_settings = True
-    n = c.get_netlist(full_settings=full_settings)
+    c.show(show_ports=True)
+    n = c.get_netlist()
     yaml_str = OmegaConf.to_yaml(n, sort_keys=True)
     c2 = from_yaml(yaml_str)
-    n2 = c2.get_netlist(full_settings=full_settings)
+    n2 = c2.get_netlist()
     d = jsondiff.diff(n, n2)
     assert len(d) == 0
     gf.show(c2)
@@ -534,7 +578,9 @@ if __name__ == "__main__":
     # c = from_yaml(sample_2x2_connections)
     # c = from_yaml(sample_different_factory)
     # c = test_sample()
-    # c = test_netlists("sample_mmis", True, None, check=False)
+    # c = test_netlists("sample_docstring", None, check=False)
+    # c.show(show_ports=True)
+
     # c = test_connections_regex()
     # c = test_connections_regex_backwargs()
     # c = test_mirror()
@@ -547,14 +593,14 @@ if __name__ == "__main__":
     # c = test_connections_different_link_factory()
     # c = test_connections_waypoints()
     # c = test_docstring_sample()
+
     # c = test_settings("yaml_anchor", None, False)
-    # c = test_netlists("yaml_anchor", True, None, False)
-    # c = test_netlists("sample_waypoints", True, None, False)
+    # c = test_netlists("yaml_anchor", None, False)
+    # c = test_netlists("sample_waypoints", None, False)
     # c = from_yaml(sample_docstring)
     # c = from_yaml(sample_different_link_factory)
     # c = from_yaml(sample_mirror_simple)
     # c = from_yaml(sample_waypoints)
-    c = test_netlists("sample_different_link_factory", True, None, check=False)
 
     # c = from_yaml(sample_different_factory)
     # c = from_yaml(sample_different_link_factory)
@@ -562,4 +608,22 @@ if __name__ == "__main__":
     # c = from_yaml(sample_docstring)
     # c = from_yaml(sample_regex_connections)
     # c = from_yaml(sample_regex_connections_backwards)
-    c.show()
+
+    # c = test_netlists("sample_doe", None, check=False)
+
+    # c = from_yaml(sample_different_factory)
+    # c.show(show_ports=True)
+
+    # yaml_key = "sample_mmis"
+    yaml_key = "sample_doe"
+    yaml_string = yaml_strings[yaml_key]
+    c = from_yaml(yaml_string)
+    n = c.get_netlist()
+
+    yaml_str = OmegaConf.to_yaml(n, sort_keys=True)
+    print(yaml_str)
+    c2 = from_yaml(yaml_str)
+    n2 = c2.get_netlist()
+    d = jsondiff.diff(n, n2)
+    pprint(d)
+    c2.show()
