@@ -2,12 +2,12 @@ import gdsfactory as gf
 from gdsfactory.component import Component
 
 yaml = """
-name:
-    test_component_yaml_without_cell
+name: test_bezier
 
 instances:
     mmi:
       component: mmi1x2
+
     bend:
       component: bend_s
 
@@ -17,16 +17,16 @@ connections:
 """
 
 
-def test_component_from_yaml_without_cell() -> Component:
+def test_component_from_yaml_bezier() -> Component:
     """bezier does not have cell"""
     c = gf.read.from_yaml(yaml)
-    assert c.name == "test_component_yaml_without_cell", c.name
+    assert c.name == "test_bezier_03405c97", c.name
     assert len(c.get_dependencies()) == 2, len(c.get_dependencies())
     assert len(c.ports) == 0, len(c.ports)
     return c
 
 
 if __name__ == "__main__":
-    c = test_component_from_yaml_without_cell()
+    c = test_component_from_yaml_bezier()
     print(c.name)
-    c.show()
+    c.show(show_ports=True)
