@@ -1,9 +1,7 @@
-import pathlib
-
 import pytest
 from pytest_regressions.data_regression import DataRegressionFixture
 
-from gdsfactory.components import factory
+from gdsfactory.components import cells
 from gdsfactory.difftest import difftest
 
 skip_test = {
@@ -12,38 +10,32 @@ skip_test = {
     "extend_port",
     "component_sequence",
     "mzi_arm",
+    "pack_doe",
+    "pack_doe_grid",
+    "crossing",
 }
 
-components_to_test = set(factory.keys()) - skip_test
-dirpath = pathlib.Path(__file__).absolute().with_suffix(".gds")
+cells_to_test = set(cells.keys()) - skip_test
 
 
-@pytest.fixture(params=components_to_test, scope="function")
+@pytest.fixture(params=cells_to_test, scope="function")
 def component_name(request) -> str:
     return request.param
 
 
 def test_gds(component_name: str) -> None:
     """Avoid regressions in GDS geometry shapes and layers."""
-    component = factory[component_name]()
-    difftest(component, test_name=component_name, dirpath=dirpath)
+    component = cells[component_name]()
+    difftest(component, test_name=component_name)
 
 
 def test_settings(component_name: str, data_regression: DataRegressionFixture) -> None:
     """Avoid regressions when exporting settings."""
-    component = factory[component_name]()
+    component = cells[component_name]()
     data_regression.check(component.to_dict())
 
 
-def test_assert_ports_on_grid(component_name: str):
+def test_assert_ports_on_grid(component_name: str) -> None:
     """Ensure ports are on grid."""
-    component = factory[component_name]()
+    component = cells[component_name]()
     component.assert_ports_on_grid()
-
-
-if __name__ == "__main__":
-    # c = gf.components.coupler(length=1.0 + 1e-4)
-    # c = gf.components.coupler()
-    # c.assert_ports_on_grid()
-    # print(c.ports)
-    print(dirpath)
