@@ -17,8 +17,14 @@ def demo_get_bundle_sbend_routing(
     N = len(ys_left)
     ys_right = [(i - N / 2) * pitch for i in range(N)]
 
-    right_ports = [gf.Port(f"R_{i}", (0, ys_right[i]), 0.5, 180) for i in range(N)]
-    left_ports = [gf.Port(f"L_{i}", (-50, ys_left[i]), 0.5, 0) for i in range(N)]
+    right_ports = [
+        gf.Port(f"R_{i}", center=(0, ys_right[i]), width=0.5, orientation=180)
+        for i in range(N)
+    ]
+    left_ports = [
+        gf.Port(f"L_{i}", center=(-50, ys_left[i]), width=0.5, orientation=0)
+        for i in range(N)
+    ]
     left_ports.reverse()
     routes = gf.routing.get_bundle(right_ports, left_ports, bend_radius=5)
 
@@ -33,4 +39,4 @@ def demo_get_bundle_sbend_routing(
 
 if __name__ == "__main__":
     c = demo_get_bundle_sbend_routing(None, check=False)
-    c.show()
+    c.show(show_ports=True)
