@@ -10,7 +10,7 @@ def test_get_bundle_udirect(
 
     c = gf.Component("test_get_bundle_udirect")
 
-    pad = gf.partial(gf.c.pad, size=(10, 10))
+    pad = gf.partial(gf.components.pad, size=(10, 10))
     pad_south = gf.components.pad_array(orientation=270, spacing=(15.0, 0), pad=pad)
     pt = c << pad_south
     pb = c << pad_south
@@ -37,4 +37,4 @@ def test_get_bundle_udirect(
 
 if __name__ == "__main__":
     c = test_get_bundle_udirect(None, check=False)
-    c.show()
+    c.show(show_ports=True)
