@@ -2,6 +2,7 @@ from pytest_regressions.data_regression import DataRegressionFixture
 
 import gdsfactory as gf
 from gdsfactory.component import Component
+from gdsfactory.port import port_array
 
 
 def test_get_bundle_west_to_north(
@@ -11,7 +12,7 @@ def test_get_bundle_west_to_north(
     lengths = {}
 
     c = gf.Component("test_get_bundle_west_to_north")
-    pad = gf.partial(gf.c.pad, size=(10, 10))
+    pad = gf.partial(gf.components.pad, size=(10, 10))
     c = gf.Component()
     pad_south = gf.components.pad_array(orientation=270, spacing=(15.0, 0.0), pad=pad)
     pad_north = gf.components.pad_array(orientation=90, spacing=(15.0, 0.0), pad=pad)
@@ -44,13 +45,15 @@ def test_get_bundle_west_to_north2(
     data_regression: DataRegressionFixture, check: bool = True
 ) -> Component:
 
+    layer = (1, 0)
+
     lengths = {}
     c = gf.Component("test_get_bundle_west_to_north2")
-    pbottom_facing_north = gf.port.port_array(
-        midpoint=(0, 0), orientation=90, pitch=(30, 0)
+    pbottom_facing_north = port_array(
+        center=(0, 0), orientation=90, pitch=(30, 0), layer=layer
     )
-    ptop_facing_west = gf.port.port_array(
-        midpoint=(100, 100), orientation=180, pitch=(0, -30)
+    ptop_facing_west = port_array(
+        center=(100, 100), orientation=180, pitch=(0, -30), layer=layer
     )
 
     routes = gf.routing.get_bundle(
@@ -69,6 +72,6 @@ def test_get_bundle_west_to_north2(
 
 
 if __name__ == "__main__":
-    c = test_get_bundle_west_to_north(None, check=False)
-    # c = test_get_bundle_west_to_north2(None, check=False)
-    c.show()
+    # c = test_get_bundle_west_to_north(None, check=False)
+    c = test_get_bundle_west_to_north2(None, check=False)
+    c.show(show_ports=True)
