@@ -1,7 +1,7 @@
 import gdsfactory as gf
 
 
-def test_route():
+def test_route() -> None:
     c = gf.Component("sample_connect")
     mmi1 = c << gf.components.mmi1x2()
     mmi2 = c << gf.components.mmi1x2()
@@ -10,7 +10,7 @@ def test_route():
         mmi1.ports["o3"], mmi2.ports["o1"], cross_section=gf.cross_section.metal1
     )
     c.add(route.references)
-    c.show()
+    c.show(show_ports=True)
 
 
 if __name__ == "__main__":
@@ -22,4 +22,4 @@ if __name__ == "__main__":
         mmi1.ports["o3"], mmi2.ports["o1"], cross_section=gf.cross_section.metal1
     )
     c.add(route.references)
-    c.show()
+    c.show(show_ports=True)
