@@ -4,8 +4,8 @@ import gdsfactory as gf
 def test_route_error2():
     """Ensures that an impossible route raises value Error"""
     c = gf.Component("pads_route_from_steps")
-    pt = c << gf.c.pad_array(orientation=270, columns=3)
-    pb = c << gf.c.pad_array(orientation=90, columns=3)
+    pt = c << gf.components.pad_array(orientation=270, columns=3)
+    pb = c << gf.components.pad_array(orientation=90, columns=3)
     pt.move((100, 200))
     route = gf.routing.get_route_from_steps(
         pt.ports["e11"],
@@ -22,4 +22,4 @@ def test_route_error2():
 
 if __name__ == "__main__":
     c = test_route_error2()
-    c.show()
+    c.show(show_ports=True)
