@@ -1,6 +1,6 @@
 from typing import Any, Dict, List, Union
 
-from gdsfactory.components import factory
+from gdsfactory.components import cells
 
 skip_test = {
     "version_stamp",
@@ -15,7 +15,7 @@ skip_test = {
     "mzi_phase_shifter_top_heater_metal",
 }
 
-components_to_test = set(factory.keys()) - skip_test
+components_to_test = set(cells.keys()) - skip_test
 
 
 def tuplify(iterable: Union[List, Dict]) -> Any:
@@ -33,7 +33,7 @@ def sort_dict(d: Dict[str, Any]) -> Dict[str, Any]:
 
 # @pytest.mark.parametrize("component_type", components_to_test)
 # def test_properties_components(component_type: str) -> Component:
-#     """Write component to GDS with setttings written on a label.
+#     """Write component to GDS with settings written on a label.
 #     Then import the GDS and check that the settings imported match the original settings.
 #     """
 #     cnew = gf.Component()
@@ -62,17 +62,16 @@ def sort_dict(d: Dict[str, Any]) -> Dict[str, Any]:
 #     return c2
 
 
-if __name__ == "__main__":
-    pass
-    # c = test_properties_components(component_type=list(component_names)[0])
-    # c = test_properties_components(component_type="ring_single")
-    # c = test_properties_components(component_type="mzit")
-    # c = test_properties_components(component_type="bezier")
-    # c = test_properties_components(component_type="wire_straight")
-    # c = test_properties_components(component_type="straight")
-    # c = test_properties_components(component_type="grating_coupler_tree")
-    # c = test_properties_components(component_type="wire")
-    # c = test_properties_components(component_type="bend_circular")
-    # c = test_properties_components(component_type="mzi_arm")
-    # c = test_properties_components(component_type="straight_pin")
-    # c.show()
+pass
+# c = test_properties_components(component_type=list(component_names)[0])
+# c = test_properties_components(component_type="ring_single")
+# c = test_properties_components(component_type="mzit")
+# c = test_properties_components(component_type="bezier")
+# c = test_properties_components(component_type="wire_straight")
+# c = test_properties_components(component_type="straight")
+# c = test_properties_components(component_type="grating_coupler_tree")
+# c = test_properties_components(component_type="wire")
+# c = test_properties_components(component_type="bend_circular")
+# c = test_properties_components(component_type="mzi_arm")
+# c = test_properties_components(component_type="straight_pin")
+# c.show(show_ports=True)
