@@ -16,10 +16,10 @@ def test_label_move() -> Component:
     ref = c << gf.components.rectangle()
     ref.movex(10)
     assert ref.origin[0] == 10
-    # assert ref.labels[0].position[0] == 10
+    # assert ref.labels[0].center[0] == 10
     return c
 
 
 if __name__ == "__main__":
     c = test_label_move()
-    c.show()
+    c.show(show_ports=True)
