@@ -8,7 +8,8 @@ from gdsfactory.component import Component
 from gdsfactory.geometry import check_inclusion
 
 
-def get_device(
+@gf.cell
+def component_min_inclusion(
     inclusion: float,
     width: float = 0.5,
     layer1: Tuple[int, int] = (1, 0),
@@ -30,7 +31,7 @@ def get_device(
     "inclusion,min_inclusion,area_expected", [(0.1, 0.11, 16e4), (0.1, 0.01, 0)]
 )
 def test_inclusion(inclusion: float, min_inclusion: float, area_expected: int) -> None:
-    c = get_device(inclusion=inclusion)
+    c = component_min_inclusion(inclusion=inclusion)
     area = check_inclusion(c, min_inclusion=min_inclusion)
     # print(area, area_expected)
     assert np.isclose(area, area_expected)
