@@ -16,21 +16,11 @@ def test_netlist_read() -> Component:
     return c
 
 
-def test_netlist_read_full() -> Component:
-    filepath = gf.CONFIG["netlists"] / "mzi_full.yml"
-    c = gf.read.from_yaml(filepath)
-
-    assert len(c.get_dependencies()) == 5, len(c.get_dependencies())
-    return c
-
-
-def regenerate_regression_test():
+def regenerate_regression_test() -> None:
     c = gf.components.mzi()
-    filepath = gf.CONFIG["netlists"] / "mzi_full.yml"
-    c.write_netlist(filepath, full_settings=True)
 
     filepath = gf.CONFIG["netlists"] / "mzi.yml"
-    c.write_netlist(filepath, full_settings=False)
+    c.write_netlist(filepath)
 
 
 if __name__ == "__main__":
@@ -39,11 +29,11 @@ if __name__ == "__main__":
     # regenerate_regression_test()
 
     # c = test_netlist_read_full()
-    c.show()
+    c.show(show_ports=True)
 
     # n = c.get_netlist()
     # i = n["instances"]
     # b = i["bend_circular_R10_17.873_-5.5"]
     # layer = b["settings"]["layer"]
     # print(type(layer))
-    # c.show()
+    # c.show(show_ports=True)
